@@ -1,17 +1,17 @@
 /*
  *  ConfigDSN.c
  *
- *  $Id: ConfigDSN.c,v 1.4 2003/09/04 13:43:14 source Exp $
+ *  $Id: ConfigDSN.c,v 1.5 2004/06/22 11:25:48 source Exp $
  *
  *  The iODBC driver manager.
- *  
+ *
  *  Copyright (C) 1999-2002 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
  *  licenses:
  *
- *      - GNU Library General Public License (see LICENSE.LGPL) 
+ *      - GNU Library General Public License (see LICENSE.LGPL)
  *      - The BSD License (see LICENSE.BSD).
  *
  *  While not mandated by the BSD license, any patches you make to the
@@ -77,8 +77,11 @@
 #include "gui.h"
 
 BOOL INSTAPI
-ConfigDSN (HWND hwndParent,
-    WORD fRequest, LPCSTR lpszDriver, LPCSTR lpszAttributes)
+ConfigDSN (
+    HWND	  hwndParent,
+    WORD	  fRequest,
+    LPCSTR	  lpszDriver,
+    LPCSTR	  lpszAttributes)
 {
   char *dsn = NULL, *connstr = NULL, *curr, *cour = NULL;
   char dsnread[4096] = { 0 };
