@@ -1,17 +1,17 @@
 /*
  *  ConfigDriver.c
  *
- *  $Id: ConfigDriver.c,v 1.5 2003/09/04 13:43:14 source Exp $
+ *  $Id: ConfigDriver.c,v 1.7 2004/06/22 11:25:48 source Exp $
  *
  *  The iODBC driver manager.
- *  
+ *
  *  Copyright (C) 1999-2002 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
  *  licenses:
  *
- *      - GNU Library General Public License (see LICENSE.LGPL) 
+ *      - GNU Library General Public License (see LICENSE.LGPL)
  *      - The BSD License (see LICENSE.BSD).
  *
  *  While not mandated by the BSD license, any patches you make to the
@@ -75,10 +75,14 @@
 #include "gui.h"
 
 BOOL INSTAPI
-ConfigDriver (HWND hwndParent,
-    WORD fRequest,
-    LPCSTR lpszDriver,
-    LPCSTR lpszArgs, LPSTR lpszMsg, WORD cbMsgMax, WORD FAR * pcbMsgOut)
+ConfigDriver (
+    HWND	  hwndParent,
+    WORD	  fRequest,
+    LPCSTR	  lpszDriver,
+    LPCSTR	  lpszArgs,
+    LPSTR	  lpszMsg,
+    WORD	  cbMsgMax,
+    WORD	* pcbMsgOut)
 {
   char *curr, *cour;
   char driverread[4096] = { 0 };
