@@ -1,19 +1,19 @@
 /*
  *  drvconn.c
  *
- *  $Id: drvconn.c,v 1.4 2003/08/22 14:28:40 source Exp $
+ *  $Id: drvconn.c,v 1.6 2004/06/22 11:25:48 source Exp $
  *
  *  The data_sources dialog for SQLDriverConnect and a login box procedures
  *
  *  The iODBC driver manager.
- *  
+ *
  *  Copyright (C) 1999-2002 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
  *  licenses:
  *
- *      - GNU Library General Public License (see LICENSE.LGPL) 
+ *      - GNU Library General Public License (see LICENSE.LGPL)
  *      - The BSD License (see LICENSE.BSD).
  *
  *  While not mandated by the BSD license, any patches you make to the
@@ -76,10 +76,15 @@
 #include <herr.h>
 #include <dlproc.h>
 
+
 SQLRETURN SQL_API
-_iodbcdm_drvconn_dialbox (HWND hwnd,
-    LPSTR szInOutConnStr, DWORD cbInOutConnStr, int FAR * sqlStat,
-	 SQLUSMALLINT fDriverCompletion, UWORD *config)
+_iodbcdm_drvconn_dialbox (
+    HWND	  hwnd,
+    LPSTR	  szInOutConnStr,
+    DWORD	  cbInOutConnStr,
+    int	 	* sqlStat,
+    SQLUSMALLINT  fDriverCompletion,
+    UWORD	* config)
 {
   RETCODE retcode = SQL_ERROR;
   char *szDSN = NULL, *szDriver = NULL, *szUID = NULL, *szPWD = NULL, *curr;
@@ -93,71 +98,72 @@ _iodbcdm_drvconn_dialbox (HWND hwnd,
   for (curr = szInOutConnStr; *curr; curr += (STRLEN (curr) + 1))
     {
       if (!strncasecmp (curr, "DSN=", STRLEN ("DSN=")))
-		  {
-	       szDSN = curr + STRLEN ("DSN=");
-			 continue;
-		  }
+	{
+	  szDSN = curr + STRLEN ("DSN=");
+	  continue;
+	}
       if (!strncasecmp (curr, "DRIVER=", STRLEN ("DRIVER=")))
-		  {
-	       szDriver = curr + STRLEN ("DRIVER=");
-			 continue;
-		  }
+	{
+	  szDriver = curr + STRLEN ("DRIVER=");
+	  continue;
+	}
       if (!strncasecmp (curr, "UID=", STRLEN ("UID=")))
-		  {
-	       szUID = curr + STRLEN ("UID=");
-			 continue;
-		  }
+	{
+	  szUID = curr + STRLEN ("UID=");
+	  continue;
+	}
       if (!strncasecmp (curr, "UserName=", STRLEN ("UserName=")))
-		  {
-	       szUID = curr + STRLEN ("UserName=");
-			 continue;
-		  }
+	{
+	  szUID = curr + STRLEN ("UserName=");
+	  continue;
+	}
       if (!strncasecmp (curr, "LastUser=", STRLEN ("LastUser=")))
-		  {
-	       szUID = curr + STRLEN ("LastUser=");
-			 continue;
-		  }
+	{
+	  szUID = curr + STRLEN ("LastUser=");
+	  continue;
+	}
       if (!strncasecmp (curr, "PWD=", STRLEN ("PWD=")))
-		  {
-	       szPWD = curr + STRLEN ("PWD=");
-			 continue;
-		  }
+	{
+	  szPWD = curr + STRLEN ("PWD=");
+	  continue;
+	}
       if (!strncasecmp (curr, "Password=", STRLEN ("Password=")))
-		  {
-	       szPWD = curr + STRLEN ("Password=");
-			 continue;
-		  }
+	{
+	  szPWD = curr + STRLEN ("Password=");
+	  continue;
+	}
     }
 
   if (fDriverCompletion != SQL_DRIVER_NOPROMPT && (!szUID || !szPWD))
     {
-	   create_login (hwnd, szUID, szPWD, szDSN ? szDSN : "(File DSN)", &log_t);
-		
-		if (log_t.user && !szUID)
-		  {
-		    sprintf(curr, "UID=%s", log_t.user);
-			 curr += STRLEN (curr);
-			 *curr = '\0';
-			 free (log_t.user);
-		  }
+      create_login (hwnd, szUID, szPWD, szDSN ? szDSN : "(File DSN)", &log_t);
 
-		if (log_t.pwd && !szPWD)
-		  {
-		    sprintf(curr, "PWD=%s", log_t.pwd);
-			 curr += STRLEN (curr);
-			 *curr = '\0';
-			 free (log_t.pwd);
-		  }
-	 }
+      if (log_t.user && !szUID)
+	{
+	  sprintf (curr, "UID=%s", log_t.user);
+	  curr += STRLEN (curr);
+	  *curr = '\0';
+	  free (log_t.user);
+	}
+
+      if (log_t.pwd && !szPWD)
+	{
+	  sprintf (curr, "PWD=%s", log_t.pwd);
+	  curr += STRLEN (curr);
+	  *curr = '\0';
+	  free (log_t.pwd);
+	}
+    }
 
   retcode = log_t.ok ? SQL_SUCCESS : SQL_NO_DATA_FOUND;
 
 quit:
-  for( curr = szInOutConnStr ; *curr ; curr = szDSN + 1 )
+  for (curr = szInOutConnStr; *curr; curr = szDSN + 1)
     {
-	   szDSN = curr + STRLEN(curr);
-		if(szDSN[1]) szDSN[0] = ';';
-	 }
+      szDSN = curr + STRLEN (curr);
+      if (szDSN[1])
+	szDSN[0] = ';';
+    }
 
   return retcode;
 }
