@@ -1,17 +1,17 @@
 /*
  *  gui.h
  *
- *  $Id: gui.h,v 1.5 2003/09/04 13:43:14 source Exp $
+ *  $Id: gui.h,v 1.6 2004/06/22 11:25:48 source Exp $
  *
  *  The iODBC driver manager.
- *  
+ *
  *  Copyright (C) 1999-2002 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
  *  licenses:
  *
- *      - GNU Library General Public License (see LICENSE.LGPL) 
+ *      - GNU Library General Public License (see LICENSE.LGPL)
  *      - The BSD License (see LICENSE.BSD).
  *
  *  While not mandated by the BSD license, any patches you make to the
@@ -95,6 +95,7 @@ extern "C" {
 
 LPSTR create_gensetup (HWND hwnd, LPCSTR dsn, LPCSTR attrs, BOOL add);
 void create_login (HWND hwnd, LPCSTR username, LPCSTR password, LPCSTR dsn, TLOGIN *log_t);
+BOOL create_confirm (HWND hwnd, LPCSTR dsn, LPCSTR text);
 
 #ifdef __cplusplus
 }
