@@ -1,7 +1,7 @@
 /*
  *  iodbcinst.h
  *
- *  $Id: iodbcinst.h,v 1.5 2003/09/04 13:33:45 source Exp $
+ *  $Id: iodbcinst.h,v 1.6 2004/06/18 23:53:48 source Exp $
  *
  *  iODBC Installer defines
  *
@@ -272,11 +272,11 @@ BOOL INSTAPI SQLGetTranslator (
     HWND hwnd,
     LPSTR lpszName,
     WORD cbNameMax,
-    WORD FAR * pcbNameOut,
+    WORD * pcbNameOut,
     LPSTR lpszPath,
     WORD cbPathMax,
-    WORD FAR * pcbPathOut,
-    DWORD FAR * pvOption);
+    WORD * pcbPathOut,
+    DWORD * pvOption);
 
 /*  Low level APIs
  *  NOTE: The high-level APIs should always be used. These APIs
@@ -287,23 +287,23 @@ BOOL INSTAPI SQLInstallDriver (
     LPCSTR lpszDriver,
     LPSTR lpszPath,
     WORD cbPathMax,
-    WORD FAR * pcbPathOut);
+    WORD * pcbPathOut);
 
 BOOL INSTAPI SQLInstallDriverManager (
     LPSTR lpszPath,
     WORD cbPathMax,
-    WORD FAR * pcbPathOut);
+    WORD * pcbPathOut);
 
 BOOL INSTAPI SQLGetInstalledDrivers (
     LPSTR lpszBuf,
     WORD cbBufMax,
-    WORD FAR * pcbBufOut);
+    WORD * pcbBufOut);
 
 BOOL INSTAPI SQLGetAvailableDrivers (
     LPCSTR lpszInfFile,
     LPSTR lpszBuf,
     WORD cbBufMax,
-    WORD FAR * pcbBufOut);
+    WORD * pcbBufOut);
 
 BOOL INSTAPI SQLConfigDataSource (
     HWND hwndParent,
@@ -343,7 +343,7 @@ BOOL INSTAPI SQLInstallTranslator (
     LPCSTR lpszPathIn,
     LPSTR lpszPathOut,
     WORD cbPathOutMax,
-    WORD FAR * pcbPathOut,
+    WORD * pcbPathOut,
     WORD fRequest,
     LPDWORD lpdwUsageCount);
 
@@ -363,7 +363,7 @@ BOOL INSTAPI SQLConfigDriver (
     LPCSTR lpszArgs,
     LPSTR lpszMsg,
     WORD cbMsgMax,
-    WORD FAR * pcbMsgOut);
+    WORD * pcbMsgOut);
 
 /* Driver specific Setup APIs called by installer */
 
@@ -380,7 +380,7 @@ typedef BOOL INSTAPI (*pConfigDriverFunc) (
     LPCSTR lpszArgs,
     LPSTR lpszMsg,
     WORD cbMsgMax,
-    WORD FAR * pcbMsgOut);
+    WORD * pcbMsgOut);
 
 typedef BOOL INSTAPI (*pConfigTranslatorFunc) (
     HWND hwndParent,
@@ -393,7 +393,7 @@ BOOL INSTAPI ConfigDSN (
     LPCSTR lpszAttributes);
 
 BOOL INSTAPI ConfigTranslator (HWND hwndParent,
-    DWORD FAR * pvOption);
+    DWORD * pvOption);
 
 BOOL INSTAPI ConfigDriver (
     HWND hwndParent,
@@ -402,7 +402,7 @@ BOOL INSTAPI ConfigDriver (
     LPCSTR lpszArgs,
     LPSTR lpszMsg,
     WORD cbMsgMax,
-    WORD FAR * pcbMsgOut);
+    WORD * pcbMsgOut);
 
 #ifdef __cplusplus
 } 
