@@ -1,7 +1,7 @@
 /*
  *  catalog.c
  *
- *  $Id: catalog.c,v 1.13 2003/09/02 14:44:22 source Exp $
+ *  $Id: catalog.c,v 1.15 2004/06/21 13:34:28 source Exp $
  *
  *  Catalog functions
  *
@@ -92,10 +92,10 @@
  */
 static SQLRETURN
 _iodbcdm_cata_state_ok (
-    STMT_t FAR * pstmt,
+    STMT_t * pstmt,
     int fidx)
 {
-  int sqlstat = en_00000;
+  sqlstcode_t sqlstat = en_00000;
 
   if (pstmt->asyn_on == en_NullProc)
     {
@@ -137,7 +137,7 @@ _iodbcdm_cata_state_ok (
  */
 static SQLRETURN
 _iodbcdm_cata_state_tr (
-    STMT_t FAR * pstmt,
+    STMT_t * pstmt,
     int fidx,
     SQLRETURN result)
 {
@@ -193,10 +193,12 @@ SQLGetTypeInfo_Internal (
 {
   STMT (pstmt, hstmt);
   CONN (pdbc, pstmt->hdbc);
-  ENV_t FAR *penv = pdbc->henv;
+  ENVR (penv, pdbc->henv);
   HPROC hproc = SQL_NULL_HPROC;
   SQLRETURN retcode = SQL_SUCCESS;
-  int sqlstat = en_00000;
+  sqlstcode_t sqlstat = en_00000;
+
+  waMode = waMode;	/*NOTUSED*/
 
   for (;;)
     {
@@ -308,10 +310,10 @@ SQLSpecialColumns_Internal (
 {
   STMT (pstmt, hstmt);
   CONN (pdbc, pstmt->hdbc);
-  ENV_t FAR *penv = pdbc->henv;
+  ENVR (penv, pdbc->henv);
   HPROC hproc = SQL_NULL_HPROC;
   SQLRETURN retcode = SQL_SUCCESS;
-  int sqlstat = en_00000;
+  sqlstcode_t sqlstat = en_00000;
   void * _TableQualifier = NULL;
   void * _TableOwner = NULL;
   void * _TableName = NULL;
@@ -359,16 +361,16 @@ SQLSpecialColumns_Internal (
           if (waMode != 'W')
             {
             /* ansi=>unicode*/
-              _TableQualifier = _iodbcdm_conv_param_A2W(pstmt, 0, szTableQualifier, cbTableQualifier);
-              _TableOwner = _iodbcdm_conv_param_A2W(pstmt, 1, szTableOwner, cbTableOwner);
-              _TableName = _iodbcdm_conv_param_A2W(pstmt, 2, szTableName, cbTableName);
+              _TableQualifier = _iodbcdm_conv_param_A2W(pstmt, 0, (SQLCHAR *) szTableQualifier, cbTableQualifier);
+              _TableOwner = _iodbcdm_conv_param_A2W(pstmt, 1, (SQLCHAR *) szTableOwner, cbTableOwner);
+              _TableName = _iodbcdm_conv_param_A2W(pstmt, 2, (SQLCHAR *) szTableName, cbTableName);
             }
           else
             {
             /* unicode=>ansi*/
-              _TableQualifier = _iodbcdm_conv_param_W2A(pstmt, 0, szTableQualifier, cbTableQualifier);
-              _TableOwner = _iodbcdm_conv_param_W2A(pstmt, 1, szTableOwner, cbTableOwner);
-              _TableName = _iodbcdm_conv_param_W2A(pstmt, 2, szTableName, cbTableName);
+              _TableQualifier = _iodbcdm_conv_param_W2A(pstmt, 0, (SQLWCHAR *)szTableQualifier, cbTableQualifier);
+              _TableOwner = _iodbcdm_conv_param_W2A(pstmt, 1, (SQLWCHAR *)szTableOwner, cbTableOwner);
+              _TableName = _iodbcdm_conv_param_W2A(pstmt, 2, (SQLWCHAR *)szTableName, cbTableName);
             }
           szTableQualifier = _TableQualifier;
           szTableOwner = _TableOwner;
@@ -420,11 +422,11 @@ SQLSpecialColumns_Internal (
 SQLRETURN SQL_API
 SQLSpecialColumns (SQLHSTMT hstmt,
     SQLUSMALLINT fColType,
-    SQLCHAR FAR * szTableQualifier,
+    SQLCHAR * szTableQualifier,
     SQLSMALLINT cbTableQualifier,
-    SQLCHAR FAR * szTableOwner,
+    SQLCHAR * szTableOwner,
     SQLSMALLINT cbTableOwner,
-    SQLCHAR FAR * szTableName,
+    SQLCHAR * szTableName,
     SQLSMALLINT cbTableName,
     SQLUSMALLINT fScope,
     SQLUSMALLINT fNullable)
@@ -464,11 +466,11 @@ SQLSpecialColumns (SQLHSTMT hstmt,
 SQLRETURN SQL_API
 SQLSpecialColumnsA (SQLHSTMT hstmt,
     SQLUSMALLINT fColType,
-    SQLCHAR FAR * szTableQualifier,
+    SQLCHAR * szTableQualifier,
     SQLSMALLINT cbTableQualifier,
-    SQLCHAR FAR * szTableOwner,
+    SQLCHAR * szTableOwner,
     SQLSMALLINT cbTableOwner,
-    SQLCHAR FAR * szTableName,
+    SQLCHAR * szTableName,
     SQLSMALLINT cbTableName,
     SQLUSMALLINT fScope,
     SQLUSMALLINT fNullable)
@@ -508,11 +510,11 @@ SQLSpecialColumnsA (SQLHSTMT hstmt,
 SQLRETURN SQL_API
 SQLSpecialColumnsW (SQLHSTMT hstmt,
     SQLUSMALLINT fColType,
-    SQLWCHAR FAR * szTableQualifier,
+    SQLWCHAR * szTableQualifier,
     SQLSMALLINT cbTableQualifier,
-    SQLWCHAR FAR * szTableOwner,
+    SQLWCHAR * szTableOwner,
     SQLSMALLINT cbTableOwner,
-    SQLWCHAR FAR * szTableName,
+    SQLWCHAR * szTableName,
     SQLSMALLINT cbTableName,
     SQLUSMALLINT fScope,
     SQLUSMALLINT fNullable)
@@ -564,10 +566,10 @@ SQLStatistics_Internal (
 {
   STMT (pstmt, hstmt);
   CONN (pdbc, pstmt->hdbc);
-  ENV_t FAR *penv = pdbc->henv;
+  ENVR (penv, pdbc->henv);
   HPROC hproc = SQL_NULL_HPROC;
   SQLRETURN retcode = SQL_SUCCESS;
-  int sqlstat = en_00000;
+  sqlstcode_t sqlstat = en_00000;
   void * _TableQualifier = NULL;
   void * _TableOwner = NULL;
   void * _TableName = NULL;
@@ -608,16 +610,16 @@ SQLStatistics_Internal (
           if (waMode != 'W')
             {
             /* ansi=>unicode*/
-              _TableQualifier = _iodbcdm_conv_param_A2W(pstmt, 0, szTableQualifier, cbTableQualifier);
-              _TableOwner = _iodbcdm_conv_param_A2W(pstmt, 1, szTableOwner, cbTableOwner);
-              _TableName = _iodbcdm_conv_param_A2W(pstmt, 2, szTableName, cbTableName);
+              _TableQualifier = _iodbcdm_conv_param_A2W(pstmt, 0, (SQLCHAR *)szTableQualifier, cbTableQualifier);
+              _TableOwner = _iodbcdm_conv_param_A2W(pstmt, 1, (SQLCHAR *)szTableOwner, cbTableOwner);
+              _TableName = _iodbcdm_conv_param_A2W(pstmt, 2, (SQLCHAR *)szTableName, cbTableName);
             }
           else
             {
             /* unicode=>ansi*/
-              _TableQualifier = _iodbcdm_conv_param_W2A(pstmt, 0, szTableQualifier, cbTableQualifier);
-              _TableOwner = _iodbcdm_conv_param_W2A(pstmt, 1, szTableOwner, cbTableOwner);
-              _TableName = _iodbcdm_conv_param_W2A(pstmt, 2, szTableName, cbTableName);
+              _TableQualifier = _iodbcdm_conv_param_W2A(pstmt, 0, (SQLWCHAR *)szTableQualifier, cbTableQualifier);
+              _TableOwner = _iodbcdm_conv_param_W2A(pstmt, 1, (SQLWCHAR *)szTableOwner, cbTableOwner);
+              _TableName = _iodbcdm_conv_param_W2A(pstmt, 2, (SQLWCHAR *)szTableName, cbTableName);
             }
           szTableQualifier = _TableQualifier;
           szTableOwner = _TableOwner;
@@ -668,11 +670,11 @@ SQLStatistics_Internal (
 
 SQLRETURN SQL_API
 SQLStatistics (SQLHSTMT hstmt,
-    SQLCHAR FAR * szTableQualifier,
+    SQLCHAR * szTableQualifier,
     SQLSMALLINT cbTableQualifier,
-    SQLCHAR FAR * szTableOwner,
+    SQLCHAR * szTableOwner,
     SQLSMALLINT cbTableOwner,
-    SQLCHAR FAR * szTableName,
+    SQLCHAR * szTableName,
     SQLSMALLINT cbTableName,
     SQLUSMALLINT fUnique,
     SQLUSMALLINT fAccuracy)
@@ -708,11 +710,11 @@ SQLStatistics (SQLHSTMT hstmt,
 
 SQLRETURN SQL_API
 SQLStatisticsA (SQLHSTMT hstmt,
-    SQLCHAR FAR * szTableQualifier,
+    SQLCHAR * szTableQualifier,
     SQLSMALLINT cbTableQualifier,
-    SQLCHAR FAR * szTableOwner,
+    SQLCHAR * szTableOwner,
     SQLSMALLINT cbTableOwner,
-    SQLCHAR FAR * szTableName,
+    SQLCHAR * szTableName,
     SQLSMALLINT cbTableName,
     SQLUSMALLINT fUnique,
     SQLUSMALLINT fAccuracy)
@@ -748,11 +750,11 @@ SQLStatisticsA (SQLHSTMT hstmt,
 
 SQLRETURN SQL_API
 SQLStatisticsW (SQLHSTMT hstmt,
-    SQLWCHAR FAR * szTableQualifier,
+    SQLWCHAR * szTableQualifier,
     SQLSMALLINT cbTableQualifier,
-    SQLWCHAR FAR * szTableOwner,
+    SQLWCHAR * szTableOwner,
     SQLSMALLINT cbTableOwner,
-    SQLWCHAR FAR * szTableName,
+    SQLWCHAR * szTableName,
     SQLSMALLINT cbTableName,
     SQLUSMALLINT fUnique,
     SQLUSMALLINT fAccuracy)
@@ -801,10 +803,10 @@ SQLTables_Internal (
 {
   STMT (pstmt, hstmt);
   CONN (pdbc, pstmt->hdbc);
-  ENV_t FAR *penv = pdbc->henv;
+  ENVR (penv, pdbc->henv);
   HPROC hproc = SQL_NULL_HPROC;
   SQLRETURN retcode = SQL_SUCCESS;
-  int sqlstat = en_00000;
+  sqlstcode_t sqlstat = en_00000;
   void * _TableQualifier = NULL;
   void * _TableOwner = NULL;
   void * _TableName = NULL;
@@ -834,18 +836,18 @@ SQLTables_Internal (
           if (waMode != 'W')
             {
             /* ansi=>unicode*/
-              _TableQualifier = _iodbcdm_conv_param_A2W(pstmt, 0, szTableQualifier, cbTableQualifier);
-              _TableOwner = _iodbcdm_conv_param_A2W(pstmt, 1, szTableOwner, cbTableOwner);
-              _TableName = _iodbcdm_conv_param_A2W(pstmt, 2, szTableName, cbTableName);
-              _TableType = _iodbcdm_conv_param_A2W(pstmt, 3, szTableType, cbTableType);
+              _TableQualifier = _iodbcdm_conv_param_A2W(pstmt, 0, (SQLCHAR *)szTableQualifier, cbTableQualifier);
+              _TableOwner = _iodbcdm_conv_param_A2W(pstmt, 1, (SQLCHAR *)szTableOwner, cbTableOwner);
+              _TableName = _iodbcdm_conv_param_A2W(pstmt, 2, (SQLCHAR *)szTableName, cbTableName);
+              _TableType = _iodbcdm_conv_param_A2W(pstmt, 3, (SQLCHAR *)szTableType, cbTableType);
             }
           else
             {
             /* unicode=>ansi*/
-              _TableQualifier = _iodbcdm_conv_param_W2A(pstmt, 0, szTableQualifier, cbTableQualifier);
-              _TableOwner = _iodbcdm_conv_param_W2A(pstmt, 1, szTableOwner, cbTableOwner);
-              _TableName = _iodbcdm_conv_param_W2A(pstmt, 2, szTableName, cbTableName);
-              _TableType = _iodbcdm_conv_param_W2A(pstmt, 3, szTableType, cbTableType);
+              _TableQualifier = _iodbcdm_conv_param_W2A(pstmt, 0, (SQLWCHAR *)szTableQualifier, cbTableQualifier);
+              _TableOwner = _iodbcdm_conv_param_W2A(pstmt, 1, (SQLWCHAR *)szTableOwner, cbTableOwner);
+              _TableName = _iodbcdm_conv_param_W2A(pstmt, 2, (SQLWCHAR *)szTableName, cbTableName);
+              _TableType = _iodbcdm_conv_param_W2A(pstmt, 3, (SQLWCHAR *)szTableType, cbTableType);
             }
           szTableQualifier = _TableQualifier;
           szTableOwner = _TableOwner;
@@ -898,13 +900,13 @@ SQLTables_Internal (
 
 SQLRETURN SQL_API
 SQLTables (SQLHSTMT hstmt,
-    SQLCHAR FAR * szTableQualifier,
+    SQLCHAR * szTableQualifier,
     SQLSMALLINT cbTableQualifier,
-    SQLCHAR FAR * szTableOwner,
+    SQLCHAR * szTableOwner,
     SQLSMALLINT cbTableOwner,
-    SQLCHAR FAR * szTableName,
+    SQLCHAR * szTableName,
     SQLSMALLINT cbTableName,
-    SQLCHAR FAR * szTableType,
+    SQLCHAR * szTableType,
     SQLSMALLINT cbTableType)
 {
   ENTER_STMT (hstmt,
@@ -935,13 +937,13 @@ SQLTables (SQLHSTMT hstmt,
 
 SQLRETURN SQL_API
 SQLTablesA (SQLHSTMT hstmt,
-    SQLCHAR FAR * szTableQualifier,
+    SQLCHAR * szTableQualifier,
     SQLSMALLINT cbTableQualifier,
-    SQLCHAR FAR * szTableOwner,
+    SQLCHAR * szTableOwner,
     SQLSMALLINT cbTableOwner,
-    SQLCHAR FAR * szTableName,
+    SQLCHAR * szTableName,
     SQLSMALLINT cbTableName,
-    SQLCHAR FAR * szTableType,
+    SQLCHAR * szTableType,
     SQLSMALLINT cbTableType)
 {
   ENTER_STMT (hstmt,
@@ -972,13 +974,13 @@ SQLTablesA (SQLHSTMT hstmt,
 
 SQLRETURN SQL_API
 SQLTablesW (SQLHSTMT hstmt,
-    SQLWCHAR FAR * szTableQualifier,
+    SQLWCHAR * szTableQualifier,
     SQLSMALLINT cbTableQualifier,
-    SQLWCHAR FAR * szTableOwner,
+    SQLWCHAR * szTableOwner,
     SQLSMALLINT cbTableOwner,
-    SQLWCHAR FAR * szTableName,
+    SQLWCHAR * szTableName,
     SQLSMALLINT cbTableName,
-    SQLWCHAR FAR * szTableType,
+    SQLWCHAR * szTableType,
     SQLSMALLINT cbTableType)
 {
   ENTER_STMT (hstmt,
@@ -1022,10 +1024,10 @@ SQLColumnPrivileges_Internal (
 {
   STMT (pstmt, hstmt);
   CONN (pdbc, pstmt->hdbc);
-  ENV_t FAR *penv = pdbc->henv;
+  ENVR (penv, pdbc->henv);
   HPROC hproc = SQL_NULL_HPROC;
   SQLRETURN retcode = SQL_SUCCESS;
-  int sqlstat = en_00000;
+  sqlstcode_t sqlstat = en_00000;
   void * _TableQualifier = NULL;
   void * _TableOwner = NULL;
   void * _TableName = NULL;
@@ -1056,18 +1058,18 @@ SQLColumnPrivileges_Internal (
           if (waMode != 'W')
             {
             /* ansi=>unicode*/
-              _TableQualifier = _iodbcdm_conv_param_A2W(pstmt, 0, szTableQualifier, cbTableQualifier);
-              _TableOwner = _iodbcdm_conv_param_A2W(pstmt, 1, szTableOwner, cbTableOwner);
-              _TableName = _iodbcdm_conv_param_A2W(pstmt, 2, szTableName, cbTableName);
-              _ColumnName = _iodbcdm_conv_param_A2W(pstmt, 3, szColumnName, cbColumnName);
+              _TableQualifier = _iodbcdm_conv_param_A2W(pstmt, 0, (SQLCHAR *)szTableQualifier, cbTableQualifier);
+              _TableOwner = _iodbcdm_conv_param_A2W(pstmt, 1, (SQLCHAR *)szTableOwner, cbTableOwner);
+              _TableName = _iodbcdm_conv_param_A2W(pstmt, 2, (SQLCHAR *)szTableName, cbTableName);
+              _ColumnName = _iodbcdm_conv_param_A2W(pstmt, 3, (SQLCHAR *)szColumnName, cbColumnName);
             }
           else
             {
             /* unicode=>ansi*/
-              _TableQualifier = _iodbcdm_conv_param_W2A(pstmt, 0, szTableQualifier, cbTableQualifier);
-              _TableOwner = _iodbcdm_conv_param_W2A(pstmt, 1, szTableOwner, cbTableOwner);
-              _TableName = _iodbcdm_conv_param_W2A(pstmt, 2, szTableName, cbTableName);
-              _ColumnName = _iodbcdm_conv_param_W2A(pstmt, 3, szColumnName, cbColumnName);
+              _TableQualifier = _iodbcdm_conv_param_W2A(pstmt, 0, (SQLWCHAR *)szTableQualifier, cbTableQualifier);
+              _TableOwner = _iodbcdm_conv_param_W2A(pstmt, 1, (SQLWCHAR *)szTableOwner, cbTableOwner);
+              _TableName = _iodbcdm_conv_param_W2A(pstmt, 2, (SQLWCHAR *)szTableName, cbTableName);
+              _ColumnName = _iodbcdm_conv_param_W2A(pstmt, 3, (SQLWCHAR *)szColumnName, cbColumnName);
             }
           szTableQualifier = _TableQualifier;
           szTableOwner = _TableOwner;
@@ -1120,13 +1122,13 @@ SQLColumnPrivileges_Internal (
 
 SQLRETURN SQL_API
 SQLColumnPrivileges (SQLHSTMT hstmt,
-    SQLCHAR FAR * szTableQualifier,
+    SQLCHAR * szTableQualifier,
     SQLSMALLINT cbTableQualifier,
-    SQLCHAR FAR * szTableOwner,
+    SQLCHAR * szTableOwner,
     SQLSMALLINT cbTableOwner,
-    SQLCHAR FAR * szTableName,
+    SQLCHAR * szTableName,
     SQLSMALLINT cbTableName,
-    SQLCHAR FAR * szColumnName,
+    SQLCHAR * szColumnName,
     SQLSMALLINT cbColumnName)
 {
   ENTER_STMT (hstmt,
@@ -1156,13 +1158,13 @@ SQLColumnPrivileges (SQLHSTMT hstmt,
 
 SQLRETURN SQL_API
 SQLColumnPrivilegesA (SQLHSTMT hstmt,
-    SQLCHAR FAR * szTableQualifier,
+    SQLCHAR * szTableQualifier,
     SQLSMALLINT cbTableQualifier,
-    SQLCHAR FAR * szTableOwner,
+    SQLCHAR * szTableOwner,
     SQLSMALLINT cbTableOwner,
-    SQLCHAR FAR * szTableName,
+    SQLCHAR * szTableName,
     SQLSMALLINT cbTableName,
-    SQLCHAR FAR * szColumnName,
+    SQLCHAR * szColumnName,
     SQLSMALLINT cbColumnName)
 {
   ENTER_STMT (hstmt,
@@ -1192,13 +1194,13 @@ SQLColumnPrivilegesA (SQLHSTMT hstmt,
 
 SQLRETURN SQL_API
 SQLColumnPrivilegesW (SQLHSTMT hstmt,
-    SQLWCHAR FAR * szTableQualifier,
+    SQLWCHAR * szTableQualifier,
     SQLSMALLINT cbTableQualifier,
-    SQLWCHAR FAR * szTableOwner,
+    SQLWCHAR * szTableOwner,
     SQLSMALLINT cbTableOwner,
-    SQLWCHAR FAR * szTableName,
+    SQLWCHAR * szTableName,
     SQLSMALLINT cbTableName,
-    SQLWCHAR FAR * szColumnName,
+    SQLWCHAR * szColumnName,
     SQLSMALLINT cbColumnName)
 {
   ENTER_STMT (hstmt,
@@ -1241,10 +1243,10 @@ SQLColumns_Internal (
 {
   STMT (pstmt, hstmt);
   CONN (pdbc, pstmt->hdbc);
-  ENV_t FAR *penv = pdbc->henv;
+  ENVR (penv, pdbc->henv);
   HPROC hproc = SQL_NULL_HPROC;
   SQLRETURN retcode = SQL_SUCCESS;
-  int sqlstat = en_00000;
+  sqlstcode_t sqlstat = en_00000;
   void * _TableQualifier = NULL;
   void * _TableOwner = NULL;
   void * _TableName = NULL;
@@ -1274,18 +1276,18 @@ SQLColumns_Internal (
           if (waMode != 'W')
             {
             /* ansi=>unicode*/
-              _TableQualifier = _iodbcdm_conv_param_A2W(pstmt, 0, szTableQualifier, cbTableQualifier);
-              _TableOwner = _iodbcdm_conv_param_A2W(pstmt, 1, szTableOwner, cbTableOwner);
-              _TableName = _iodbcdm_conv_param_A2W(pstmt, 2, szTableName, cbTableName);
-              _ColumnName = _iodbcdm_conv_param_A2W(pstmt, 3, szColumnName, cbColumnName);
+              _TableQualifier = _iodbcdm_conv_param_A2W(pstmt, 0, (SQLCHAR *)szTableQualifier, cbTableQualifier);
+              _TableOwner = _iodbcdm_conv_param_A2W(pstmt, 1, (SQLCHAR *)szTableOwner, cbTableOwner);
+              _TableName = _iodbcdm_conv_param_A2W(pstmt, 2, (SQLCHAR *)szTableName, cbTableName);
+              _ColumnName = _iodbcdm_conv_param_A2W(pstmt, 3, (SQLCHAR *)szColumnName, cbColumnName);
             }
           else
             {
             /* unicode=>ansi*/
-              _TableQualifier = _iodbcdm_conv_param_W2A(pstmt, 0, szTableQualifier, cbTableQualifier);
-              _TableOwner = _iodbcdm_conv_param_W2A(pstmt, 1, szTableOwner, cbTableOwner);
-              _TableName = _iodbcdm_conv_param_W2A(pstmt, 2, szTableName, cbTableName);
-              _ColumnName = _iodbcdm_conv_param_W2A(pstmt, 3, szColumnName, cbColumnName);
+              _TableQualifier = _iodbcdm_conv_param_W2A(pstmt, 0, (SQLWCHAR *) szTableQualifier, cbTableQualifier);
+              _TableOwner = _iodbcdm_conv_param_W2A(pstmt, 1, (SQLWCHAR *) szTableOwner, cbTableOwner);
+              _TableName = _iodbcdm_conv_param_W2A(pstmt, 2, (SQLWCHAR *) szTableName, cbTableName);
+              _ColumnName = _iodbcdm_conv_param_W2A(pstmt, 3, (SQLWCHAR *) szColumnName, cbColumnName);
             }
           szTableQualifier = _TableQualifier;
           szTableOwner = _TableOwner;
@@ -1338,13 +1340,13 @@ SQLColumns_Internal (
 
 SQLRETURN SQL_API
 SQLColumns (SQLHSTMT hstmt,
-    SQLCHAR FAR * szTableQualifier,
+    SQLCHAR * szTableQualifier,
     SQLSMALLINT cbTableQualifier,
-    SQLCHAR FAR * szTableOwner,
+    SQLCHAR * szTableOwner,
     SQLSMALLINT cbTableOwner,
-    SQLCHAR FAR * szTableName,
+    SQLCHAR * szTableName,
     SQLSMALLINT cbTableName,
-    SQLCHAR FAR * szColumnName,
+    SQLCHAR * szColumnName,
     SQLSMALLINT cbColumnName)
 {
   ENTER_STMT (hstmt,
@@ -1375,13 +1377,13 @@ SQLColumns (SQLHSTMT hstmt,
 
 SQLRETURN SQL_API
 SQLColumnsA (SQLHSTMT hstmt,
-    SQLCHAR FAR * szTableQualifier,
+    SQLCHAR * szTableQualifier,
     SQLSMALLINT cbTableQualifier,
-    SQLCHAR FAR * szTableOwner,
+    SQLCHAR * szTableOwner,
     SQLSMALLINT cbTableOwner,
-    SQLCHAR FAR * szTableName,
+    SQLCHAR * szTableName,
     SQLSMALLINT cbTableName,
-    SQLCHAR FAR * szColumnName,
+    SQLCHAR * szColumnName,
     SQLSMALLINT cbColumnName)
 {
   ENTER_STMT (hstmt,
@@ -1412,13 +1414,13 @@ SQLColumnsA (SQLHSTMT hstmt,
 
 SQLRETURN SQL_API
 SQLColumnsW (SQLHSTMT hstmt,
-    SQLWCHAR FAR * szTableQualifier,
+    SQLWCHAR * szTableQualifier,
     SQLSMALLINT cbTableQualifier,
-    SQLWCHAR FAR * szTableOwner,
+    SQLWCHAR * szTableOwner,
     SQLSMALLINT cbTableOwner,
-    SQLWCHAR FAR * szTableName,
+    SQLWCHAR * szTableName,
     SQLSMALLINT cbTableName,
-    SQLWCHAR FAR * szColumnName,
+    SQLWCHAR * szColumnName,
     SQLSMALLINT cbColumnName)
 {
   ENTER_STMT (hstmt,
@@ -1466,10 +1468,10 @@ SQLForeignKeys_Internal (
 {
   STMT (pstmt, hstmt);
   CONN (pdbc, pstmt->hdbc);
-  ENV_t FAR *penv = pdbc->henv;
+  ENVR (penv, pdbc->henv);
   HPROC hproc = SQL_NULL_HPROC;
   SQLRETURN retcode = SQL_SUCCESS;
-  int sqlstat = en_00000;
+  sqlstcode_t sqlstat = en_00000;
   void * _PkTableQualifier = NULL;
   void * _PkTableOwner = NULL;
   void * _PkTableName = NULL;
@@ -1503,22 +1505,22 @@ SQLForeignKeys_Internal (
           if (waMode != 'W')
             {
             /* ansi=>unicode*/
-              _PkTableQualifier = _iodbcdm_conv_param_A2W(pstmt, 0, szPkTableQualifier, cbPkTableQualifier);
-              _PkTableOwner = _iodbcdm_conv_param_A2W(pstmt, 1, szPkTableOwner, cbPkTableOwner);
-              _PkTableName = _iodbcdm_conv_param_A2W(pstmt, 2, szPkTableName, cbPkTableName);
-              _FkTableQualifier = _iodbcdm_conv_param_A2W(pstmt, 3, szFkTableQualifier, cbFkTableQualifier);
-              _FkTableOwner = _iodbcdm_conv_param_A2W(pstmt, 4, szFkTableOwner, cbFkTableOwner);
-              _FkTableName = _iodbcdm_conv_param_A2W(pstmt, 5, szFkTableName, cbFkTableName);
+              _PkTableQualifier = _iodbcdm_conv_param_A2W(pstmt, 0, (SQLCHAR *)szPkTableQualifier, cbPkTableQualifier);
+              _PkTableOwner = _iodbcdm_conv_param_A2W(pstmt, 1, (SQLCHAR *)szPkTableOwner, cbPkTableOwner);
+              _PkTableName = _iodbcdm_conv_param_A2W(pstmt, 2, (SQLCHAR *)szPkTableName, cbPkTableName);
+              _FkTableQualifier = _iodbcdm_conv_param_A2W(pstmt, 3, (SQLCHAR *)szFkTableQualifier, cbFkTableQualifier);
+              _FkTableOwner = _iodbcdm_conv_param_A2W(pstmt, 4, (SQLCHAR *)szFkTableOwner, cbFkTableOwner);
+              _FkTableName = _iodbcdm_conv_param_A2W(pstmt, 5, (SQLCHAR *)szFkTableName, cbFkTableName);
             }
           else
             {
             /* unicode=>ansi*/
-              _PkTableQualifier = _iodbcdm_conv_param_W2A(pstmt, 0, szPkTableQualifier, cbPkTableQualifier);
-              _PkTableOwner = _iodbcdm_conv_param_W2A(pstmt, 1, szPkTableOwner, cbPkTableOwner);
-              _PkTableName = _iodbcdm_conv_param_W2A(pstmt, 2, szPkTableName, cbPkTableName);
-              _FkTableQualifier = _iodbcdm_conv_param_W2A(pstmt, 3, szFkTableQualifier, cbFkTableQualifier);
-              _FkTableOwner = _iodbcdm_conv_param_W2A(pstmt, 4, szFkTableOwner, cbFkTableOwner);
-              _FkTableName = _iodbcdm_conv_param_W2A(pstmt, 5, szFkTableName, cbFkTableName);
+              _PkTableQualifier = _iodbcdm_conv_param_W2A(pstmt, 0, (SQLWCHAR *)szPkTableQualifier, cbPkTableQualifier);
+              _PkTableOwner = _iodbcdm_conv_param_W2A(pstmt, 1, (SQLWCHAR *)szPkTableOwner, cbPkTableOwner);
+              _PkTableName = _iodbcdm_conv_param_W2A(pstmt, 2, (SQLWCHAR *)szPkTableName, cbPkTableName);
+              _FkTableQualifier = _iodbcdm_conv_param_W2A(pstmt, 3, (SQLWCHAR *)szFkTableQualifier, cbFkTableQualifier);
+              _FkTableOwner = _iodbcdm_conv_param_W2A(pstmt, 4, (SQLWCHAR *)szFkTableOwner, cbFkTableOwner);
+              _FkTableName = _iodbcdm_conv_param_W2A(pstmt, 5, (SQLWCHAR *)szFkTableName, cbFkTableName);
             }
           szPkTableQualifier = _PkTableQualifier;
           szPkTableOwner = _PkTableOwner;
@@ -1579,17 +1581,17 @@ SQLForeignKeys_Internal (
 
 SQLRETURN SQL_API
 SQLForeignKeys (SQLHSTMT hstmt,
-    SQLCHAR FAR * szPkTableQualifier,
+    SQLCHAR * szPkTableQualifier,
     SQLSMALLINT cbPkTableQualifier,
-    SQLCHAR FAR * szPkTableOwner,
+    SQLCHAR * szPkTableOwner,
     SQLSMALLINT cbPkTableOwner,
-    SQLCHAR FAR * szPkTableName,
+    SQLCHAR * szPkTableName,
     SQLSMALLINT cbPkTableName,
-    SQLCHAR FAR * szFkTableQualifier,
+    SQLCHAR * szFkTableQualifier,
     SQLSMALLINT cbFkTableQualifier,
-    SQLCHAR FAR * szFkTableOwner,
+    SQLCHAR * szFkTableOwner,
     SQLSMALLINT cbFkTableOwner,
-    SQLCHAR FAR * szFkTableName,
+    SQLCHAR * szFkTableName,
     SQLSMALLINT cbFkTableName)
 {
   ENTER_STMT (hstmt,
@@ -1626,17 +1628,17 @@ SQLForeignKeys (SQLHSTMT hstmt,
 
 SQLRETURN SQL_API
 SQLForeignKeysA (SQLHSTMT hstmt,
-    SQLCHAR FAR * szPkTableQualifier,
+    SQLCHAR * szPkTableQualifier,
     SQLSMALLINT cbPkTableQualifier,
-    SQLCHAR FAR * szPkTableOwner,
+    SQLCHAR * szPkTableOwner,
     SQLSMALLINT cbPkTableOwner,
-    SQLCHAR FAR * szPkTableName,
+    SQLCHAR * szPkTableName,
     SQLSMALLINT cbPkTableName,
-    SQLCHAR FAR * szFkTableQualifier,
+    SQLCHAR * szFkTableQualifier,
     SQLSMALLINT cbFkTableQualifier,
-    SQLCHAR FAR * szFkTableOwner,
+    SQLCHAR * szFkTableOwner,
     SQLSMALLINT cbFkTableOwner,
-    SQLCHAR FAR * szFkTableName,
+    SQLCHAR * szFkTableName,
     SQLSMALLINT cbFkTableName)
 {
   ENTER_STMT (hstmt,
@@ -1673,17 +1675,17 @@ SQLForeignKeysA (SQLHSTMT hstmt,
 
 SQLRETURN SQL_API
 SQLForeignKeysW (SQLHSTMT hstmt,
-    SQLWCHAR FAR * szPkTableQualifier,
+    SQLWCHAR * szPkTableQualifier,
     SQLSMALLINT cbPkTableQualifier,
-    SQLWCHAR FAR * szPkTableOwner,
+    SQLWCHAR * szPkTableOwner,
     SQLSMALLINT cbPkTableOwner,
-    SQLWCHAR FAR * szPkTableName,
+    SQLWCHAR * szPkTableName,
     SQLSMALLINT cbPkTableName,
-    SQLWCHAR FAR * szFkTableQualifier,
+    SQLWCHAR * szFkTableQualifier,
     SQLSMALLINT cbFkTableQualifier,
-    SQLWCHAR FAR * szFkTableOwner,
+    SQLWCHAR * szFkTableOwner,
     SQLSMALLINT cbFkTableOwner,
-    SQLWCHAR FAR * szFkTableName,
+    SQLWCHAR * szFkTableName,
     SQLSMALLINT cbFkTableName)
 {
   ENTER_STMT (hstmt,
@@ -1731,10 +1733,10 @@ SQLPrimaryKeys_Internal (
 {
   STMT (pstmt, hstmt);
   CONN (pdbc, pstmt->hdbc);
-  ENV_t FAR *penv = pdbc->henv;
+  ENVR (penv, pdbc->henv);
   HPROC hproc = SQL_NULL_HPROC;
   SQLRETURN retcode = SQL_SUCCESS;
-  int sqlstat = en_00000;
+  sqlstcode_t sqlstat = en_00000;
   void * _TableQualifier = NULL;
   void * _TableOwner = NULL;
   void * _TableName = NULL;
@@ -1762,16 +1764,16 @@ SQLPrimaryKeys_Internal (
           if (waMode != 'W')
             {
             /* ansi=>unicode*/
-              _TableQualifier = _iodbcdm_conv_param_A2W(pstmt, 0, szTableQualifier, cbTableQualifier);
-              _TableOwner = _iodbcdm_conv_param_A2W(pstmt, 1, szTableOwner, cbTableOwner);
-              _TableName = _iodbcdm_conv_param_A2W(pstmt, 2, szTableName, cbTableName);
+              _TableQualifier = _iodbcdm_conv_param_A2W(pstmt, 0, (SQLCHAR *)szTableQualifier, cbTableQualifier);
+              _TableOwner = _iodbcdm_conv_param_A2W(pstmt, 1, (SQLCHAR *)szTableOwner, cbTableOwner);
+              _TableName = _iodbcdm_conv_param_A2W(pstmt, 2, (SQLCHAR *)szTableName, cbTableName);
             }
           else
             {
             /* unicode=>ansi*/
-              _TableQualifier = _iodbcdm_conv_param_W2A(pstmt, 0, szTableQualifier, cbTableQualifier);
-              _TableOwner = _iodbcdm_conv_param_W2A(pstmt, 1, szTableOwner, cbTableOwner);
-              _TableName = _iodbcdm_conv_param_W2A(pstmt, 2, szTableName, cbTableName);
+              _TableQualifier = _iodbcdm_conv_param_W2A(pstmt, 0, (SQLWCHAR *)szTableQualifier, cbTableQualifier);
+              _TableOwner = _iodbcdm_conv_param_W2A(pstmt, 1, (SQLWCHAR *)szTableOwner, cbTableOwner);
+              _TableName = _iodbcdm_conv_param_W2A(pstmt, 2, (SQLWCHAR *)szTableName, cbTableName);
             }
           szTableQualifier = _TableQualifier;
           szTableOwner = _TableOwner;
@@ -1820,11 +1822,11 @@ SQLPrimaryKeys_Internal (
 
 SQLRETURN SQL_API
 SQLPrimaryKeys (SQLHSTMT hstmt,
-    SQLCHAR FAR * szTableQualifier,
+    SQLCHAR * szTableQualifier,
     SQLSMALLINT cbTableQualifier,
-    SQLCHAR FAR * szTableOwner,
+    SQLCHAR * szTableOwner,
     SQLSMALLINT cbTableOwner,
-    SQLCHAR FAR * szTableName,
+    SQLCHAR * szTableName,
     SQLSMALLINT cbTableName)
 {
   ENTER_STMT (hstmt,
@@ -1852,11 +1854,11 @@ SQLPrimaryKeys (SQLHSTMT hstmt,
 
 SQLRETURN SQL_API
 SQLPrimaryKeysA (SQLHSTMT hstmt,
-    SQLCHAR FAR * szTableQualifier,
+    SQLCHAR * szTableQualifier,
     SQLSMALLINT cbTableQualifier,
-    SQLCHAR FAR * szTableOwner,
+    SQLCHAR * szTableOwner,
     SQLSMALLINT cbTableOwner,
-    SQLCHAR FAR * szTableName,
+    SQLCHAR * szTableName,
     SQLSMALLINT cbTableName)
 {
   ENTER_STMT (hstmt,
@@ -1884,11 +1886,11 @@ SQLPrimaryKeysA (SQLHSTMT hstmt,
 
 SQLRETURN SQL_API
 SQLPrimaryKeysW (SQLHSTMT hstmt,
-    SQLWCHAR FAR * szTableQualifier,
+    SQLWCHAR * szTableQualifier,
     SQLSMALLINT cbTableQualifier,
-    SQLWCHAR FAR * szTableOwner,
+    SQLWCHAR * szTableOwner,
     SQLSMALLINT cbTableOwner,
-    SQLWCHAR FAR * szTableName,
+    SQLWCHAR * szTableName,
     SQLSMALLINT cbTableName)
 {
   ENTER_STMT (hstmt,
@@ -1929,10 +1931,10 @@ SQLProcedureColumns_Internal (
 {
   STMT (pstmt, hstmt);
   CONN (pdbc, pstmt->hdbc);
-  ENV_t FAR *penv = pdbc->henv;
+  ENVR (penv, pdbc->henv);
   HPROC hproc = SQL_NULL_HPROC;
   SQLRETURN retcode = SQL_SUCCESS;
-  int sqlstat = en_00000;
+  sqlstcode_t sqlstat = en_00000;
   void * _ProcQualifier = NULL;
   void * _ProcOwner = NULL;
   void * _ProcName = NULL;
@@ -1962,18 +1964,18 @@ SQLProcedureColumns_Internal (
           if (waMode != 'W')
             {
             /* ansi=>unicode*/
-              _ProcQualifier = _iodbcdm_conv_param_A2W(pstmt, 0, szProcQualifier, cbProcQualifier);
-              _ProcOwner = _iodbcdm_conv_param_A2W(pstmt, 1, szProcOwner, cbProcOwner);
-              _ProcName = _iodbcdm_conv_param_A2W(pstmt, 2, szProcName, cbProcName);
-              _ColumnName = _iodbcdm_conv_param_A2W(pstmt, 3, szColumnName, cbColumnName);
+              _ProcQualifier = _iodbcdm_conv_param_A2W(pstmt, 0, (SQLCHAR *)szProcQualifier, cbProcQualifier);
+              _ProcOwner = _iodbcdm_conv_param_A2W(pstmt, 1, (SQLCHAR *)szProcOwner, cbProcOwner);
+              _ProcName = _iodbcdm_conv_param_A2W(pstmt, 2, (SQLCHAR *)szProcName, cbProcName);
+              _ColumnName = _iodbcdm_conv_param_A2W(pstmt, 3, (SQLCHAR *)szColumnName, cbColumnName);
             }
           else
             {
             /* unicode=>ansi*/
-              _ProcQualifier = _iodbcdm_conv_param_W2A(pstmt, 0, szProcQualifier, cbProcQualifier);
-              _ProcOwner = _iodbcdm_conv_param_W2A(pstmt, 1, szProcOwner, cbProcOwner);
-              _ProcName = _iodbcdm_conv_param_W2A(pstmt, 2, szProcName, cbProcName);
-              _ColumnName = _iodbcdm_conv_param_W2A(pstmt, 3, szColumnName, cbColumnName);
+              _ProcQualifier = _iodbcdm_conv_param_W2A(pstmt, 0, (SQLWCHAR *)szProcQualifier, cbProcQualifier);
+              _ProcOwner = _iodbcdm_conv_param_W2A(pstmt, 1, (SQLWCHAR *)szProcOwner, cbProcOwner);
+              _ProcName = _iodbcdm_conv_param_W2A(pstmt, 2, (SQLWCHAR *)szProcName, cbProcName);
+              _ColumnName = _iodbcdm_conv_param_W2A(pstmt, 3, (SQLWCHAR *)szColumnName, cbColumnName);
             }
           szProcQualifier = _ProcQualifier;
           szProcOwner = _ProcOwner;
@@ -2026,13 +2028,13 @@ SQLProcedureColumns_Internal (
 
 SQLRETURN SQL_API
 SQLProcedureColumns (SQLHSTMT hstmt,
-    SQLCHAR FAR * szProcQualifier,
+    SQLCHAR * szProcQualifier,
     SQLSMALLINT cbProcQualifier,
-    SQLCHAR FAR * szProcOwner,
+    SQLCHAR * szProcOwner,
     SQLSMALLINT cbProcOwner,
-    SQLCHAR FAR * szProcName,
+    SQLCHAR * szProcName,
     SQLSMALLINT cbProcName,
-    SQLCHAR FAR * szColumnName,
+    SQLCHAR * szColumnName,
     SQLSMALLINT cbColumnName)
 {
   ENTER_STMT (hstmt,
@@ -2063,13 +2065,13 @@ SQLProcedureColumns (SQLHSTMT hstmt,
 
 SQLRETURN SQL_API
 SQLProcedureColumnsA (SQLHSTMT hstmt,
-    SQLCHAR FAR * szProcQualifier,
+    SQLCHAR * szProcQualifier,
     SQLSMALLINT cbProcQualifier,
-    SQLCHAR FAR * szProcOwner,
+    SQLCHAR * szProcOwner,
     SQLSMALLINT cbProcOwner,
-    SQLCHAR FAR * szProcName,
+    SQLCHAR * szProcName,
     SQLSMALLINT cbProcName,
-    SQLCHAR FAR * szColumnName,
+    SQLCHAR * szColumnName,
     SQLSMALLINT cbColumnName)
 {
   ENTER_STMT (hstmt,
@@ -2100,13 +2102,13 @@ SQLProcedureColumnsA (SQLHSTMT hstmt,
 
 SQLRETURN SQL_API
 SQLProcedureColumnsW (SQLHSTMT hstmt,
-    SQLWCHAR FAR * szProcQualifier,
+    SQLWCHAR * szProcQualifier,
     SQLSMALLINT cbProcQualifier,
-    SQLWCHAR FAR * szProcOwner,
+    SQLWCHAR * szProcOwner,
     SQLSMALLINT cbProcOwner,
-    SQLWCHAR FAR * szProcName,
+    SQLWCHAR * szProcName,
     SQLSMALLINT cbProcName,
-    SQLWCHAR FAR * szColumnName,
+    SQLWCHAR * szColumnName,
     SQLSMALLINT cbColumnName)
 {
   ENTER_STMT (hstmt,
@@ -2148,10 +2150,10 @@ SQLProcedures_Internal (
 {
   STMT (pstmt, hstmt);
   CONN (pdbc, pstmt->hdbc);
-  ENV_t FAR *penv = pdbc->henv;
+  ENVR (penv, pdbc->henv);
   HPROC hproc = SQL_NULL_HPROC;
   SQLRETURN retcode = SQL_SUCCESS;
-  int sqlstat = en_00000;
+  sqlstcode_t sqlstat = en_00000;
   void * _ProcQualifier = NULL;
   void * _ProcOwner = NULL;
   void * _ProcName = NULL;
@@ -2179,16 +2181,16 @@ SQLProcedures_Internal (
           if (waMode != 'W')
             {
             /* ansi=>unicode*/
-              _ProcQualifier = _iodbcdm_conv_param_A2W(pstmt, 0, szProcQualifier, cbProcQualifier);
-              _ProcOwner = _iodbcdm_conv_param_A2W(pstmt, 1, szProcOwner, cbProcOwner);
-              _ProcName = _iodbcdm_conv_param_A2W(pstmt, 2, szProcName, cbProcName);
+              _ProcQualifier = _iodbcdm_conv_param_A2W(pstmt, 0, (SQLCHAR *)szProcQualifier, cbProcQualifier);
+              _ProcOwner = _iodbcdm_conv_param_A2W(pstmt, 1, (SQLCHAR *)szProcOwner, cbProcOwner);
+              _ProcName = _iodbcdm_conv_param_A2W(pstmt, 2, (SQLCHAR *)szProcName, cbProcName);
             }
           else
             {
             /* unicode=>ansi*/
-              _ProcQualifier = _iodbcdm_conv_param_W2A(pstmt, 0, szProcQualifier, cbProcQualifier);
-              _ProcOwner = _iodbcdm_conv_param_W2A(pstmt, 1, szProcOwner, cbProcOwner);
-              _ProcName = _iodbcdm_conv_param_W2A(pstmt, 2, szProcName, cbProcName);
+              _ProcQualifier = _iodbcdm_conv_param_W2A(pstmt, 0, (SQLWCHAR *)szProcQualifier, cbProcQualifier);
+              _ProcOwner = _iodbcdm_conv_param_W2A(pstmt, 1, (SQLWCHAR *)szProcOwner, cbProcOwner);
+              _ProcName = _iodbcdm_conv_param_W2A(pstmt, 2, (SQLWCHAR *)szProcName, cbProcName);
             }
           szProcQualifier = _ProcQualifier;
           szProcOwner = _ProcOwner;
@@ -2237,11 +2239,11 @@ SQLProcedures_Internal (
 
 SQLRETURN SQL_API
 SQLProcedures (SQLHSTMT hstmt,
-    SQLCHAR FAR * szProcQualifier,
+    SQLCHAR * szProcQualifier,
     SQLSMALLINT cbProcQualifier,
-    SQLCHAR FAR * szProcOwner,
+    SQLCHAR * szProcOwner,
     SQLSMALLINT cbProcOwner,
-    SQLCHAR FAR * szProcName,
+    SQLCHAR * szProcName,
     SQLSMALLINT cbProcName)
 {
   ENTER_STMT (hstmt,
@@ -2269,11 +2271,11 @@ SQLProcedures (SQLHSTMT hstmt,
 
 SQLRETURN SQL_API
 SQLProceduresA (SQLHSTMT hstmt,
-    SQLCHAR FAR * szProcQualifier,
+    SQLCHAR * szProcQualifier,
     SQLSMALLINT cbProcQualifier,
-    SQLCHAR FAR * szProcOwner,
+    SQLCHAR * szProcOwner,
     SQLSMALLINT cbProcOwner,
-    SQLCHAR FAR * szProcName,
+    SQLCHAR * szProcName,
     SQLSMALLINT cbProcName)
 {
   ENTER_STMT (hstmt,
@@ -2301,11 +2303,11 @@ SQLProceduresA (SQLHSTMT hstmt,
 
 SQLRETURN SQL_API
 SQLProceduresW (SQLHSTMT hstmt,
-    SQLWCHAR FAR * szProcQualifier,
+    SQLWCHAR * szProcQualifier,
     SQLSMALLINT cbProcQualifier,
-    SQLWCHAR FAR * szProcOwner,
+    SQLWCHAR * szProcOwner,
     SQLSMALLINT cbProcOwner,
-    SQLWCHAR FAR * szProcName,
+    SQLWCHAR * szProcName,
     SQLSMALLINT cbProcName)
 {
   ENTER_STMT (hstmt,
@@ -2344,10 +2346,10 @@ SQLTablePrivileges_Internal (
 {
   STMT (pstmt, hstmt);
   CONN (pdbc, pstmt->hdbc);
-  ENV_t FAR *penv = pdbc->henv;
+  ENVR (penv, pdbc->henv);
   HPROC hproc = SQL_NULL_HPROC;
   SQLRETURN retcode = SQL_SUCCESS;
-  int sqlstat = en_00000;
+  sqlstcode_t sqlstat = en_00000;
   void * _TableQualifier = NULL;
   void * _TableOwner = NULL;
   void * _TableName = NULL;
@@ -2375,16 +2377,16 @@ SQLTablePrivileges_Internal (
           if (waMode != 'W')
             {
             /* ansi=>unicode*/
-              _TableQualifier = _iodbcdm_conv_param_A2W(pstmt, 0, szTableQualifier, cbTableQualifier);
-              _TableOwner = _iodbcdm_conv_param_A2W(pstmt, 1, szTableOwner, cbTableOwner);
-              _TableName = _iodbcdm_conv_param_A2W(pstmt, 2, szTableName, cbTableName);
+              _TableQualifier = _iodbcdm_conv_param_A2W(pstmt, 0, (SQLCHAR *)szTableQualifier, cbTableQualifier);
+              _TableOwner = _iodbcdm_conv_param_A2W(pstmt, 1, (SQLCHAR *)szTableOwner, cbTableOwner);
+              _TableName = _iodbcdm_conv_param_A2W(pstmt, 2, (SQLCHAR *)szTableName, cbTableName);
             }
           else
             {
             /* unicode=>ansi*/
-              _TableQualifier = _iodbcdm_conv_param_W2A(pstmt, 0, szTableQualifier, cbTableQualifier);
-              _TableOwner = _iodbcdm_conv_param_W2A(pstmt, 1, szTableOwner, cbTableOwner);
-              _TableName = _iodbcdm_conv_param_W2A(pstmt, 2, szTableName, cbTableName);
+              _TableQualifier = _iodbcdm_conv_param_W2A(pstmt, 0, (SQLWCHAR *)szTableQualifier, cbTableQualifier);
+              _TableOwner = _iodbcdm_conv_param_W2A(pstmt, 1, (SQLWCHAR *)szTableOwner, cbTableOwner);
+              _TableName = _iodbcdm_conv_param_W2A(pstmt, 2, (SQLWCHAR *)szTableName, cbTableName);
             }
           szTableQualifier = _TableQualifier;
           szTableOwner = _TableOwner;
@@ -2433,11 +2435,11 @@ SQLTablePrivileges_Internal (
 
 SQLRETURN SQL_API
 SQLTablePrivileges (SQLHSTMT hstmt,
-    SQLCHAR FAR * szTableQualifier,
+    SQLCHAR * szTableQualifier,
     SQLSMALLINT cbTableQualifier,
-    SQLCHAR FAR * szTableOwner,
+    SQLCHAR * szTableOwner,
     SQLSMALLINT cbTableOwner,
-    SQLCHAR FAR * szTableName,
+    SQLCHAR * szTableName,
     SQLSMALLINT cbTableName)
 {
   ENTER_STMT (hstmt,
@@ -2465,11 +2467,11 @@ SQLTablePrivileges (SQLHSTMT hstmt,
 
 SQLRETURN SQL_API
 SQLTablePrivilegesA (SQLHSTMT hstmt,
-    SQLCHAR FAR * szTableQualifier,
+    SQLCHAR * szTableQualifier,
     SQLSMALLINT cbTableQualifier,
-    SQLCHAR FAR * szTableOwner,
+    SQLCHAR * szTableOwner,
     SQLSMALLINT cbTableOwner,
-    SQLCHAR FAR * szTableName,
+    SQLCHAR * szTableName,
     SQLSMALLINT cbTableName)
 {
   ENTER_STMT (hstmt,
@@ -2497,11 +2499,11 @@ SQLTablePrivilegesA (SQLHSTMT hstmt,
 
 SQLRETURN SQL_API
 SQLTablePrivilegesW (SQLHSTMT hstmt,
-    SQLWCHAR FAR * szTableQualifier,
+    SQLWCHAR * szTableQualifier,
     SQLSMALLINT cbTableQualifier,
-    SQLWCHAR FAR * szTableOwner,
+    SQLWCHAR * szTableOwner,
     SQLSMALLINT cbTableOwner,
-    SQLWCHAR FAR * szTableName,
+    SQLWCHAR * szTableName,
     SQLSMALLINT cbTableName)
 {
   ENTER_STMT (hstmt,
