@@ -1,7 +1,7 @@
 /*
  *  connect.c
  *
- *  $Id: connect.c,v 1.31 2004/09/10 12:09:28 source Exp $
+ *  $Id: connect.c,v 1.32 2004/12/15 15:39:04 source Exp $
  *
  *  Connect (load) driver
  *
@@ -126,11 +126,17 @@ _iodbcdm_SetConnectOption_init (
   ENVR (penv, pdbc->henv);
   HPROC hproc = SQL_NULL_HPROC;
   SQLRETURN retcode = SQL_SUCCESS;
+  int retinfo = 0;
 
   SQLINTEGER strLength = 0;
   void *ptr = (void *) vParam;
   void *_vParam = NULL;
 
+  if (fOption >= 1000)
+    {
+      retinfo = 1;		/* Change SQL_ERROR -> SQL_SUCCESS_WITH_INFO */
+    }
+
   if ((penv->unicode_driver && waMode != 'W')
       || (!penv->unicode_driver && waMode == 'W'))
     {
@@ -221,6 +227,9 @@ _iodbcdm_SetConnectOption_init (
       return SQL_SUCCESS_WITH_INFO;
     }
 
+  if (retcode != SQL_SUCCESS && retinfo)
+    return SQL_SUCCESS_WITH_INFO;
+
   return retcode;
 }
 
