@@ -1,7 +1,7 @@
 /*
  *  dlf.h
  *
- *  $Id: dlf.h,v 1.11 2003/09/03 10:08:53 source Exp $
+ *  $Id: dlf.h,v 1.13 2004/07/07 14:33:36 source Exp $
  *
  *  Dynamic Library Loader (mapping to SVR4)
  *
@@ -74,10 +74,10 @@
 #define _DLF_H
 #include <iodbc.h>
 
-#if defined(HAVE_LIBDL)
-#define DLDAPI_SVR4_DLFCN
-#elif defined(HAVE_SHL_LOAD)
+#if defined(HAVE_SHL_LOAD)
 #define DLDAPI_HP_SHL
+#elif defined(HAVE_LIBDL)
+#define DLDAPI_SVR4_DLFCN
 #elif defined(HAVE_DYLD)
 #define DLDAPI_MACX
 #endif
@@ -87,15 +87,15 @@
 #elif defined(DLDAPI_AIX_LOAD)
 #include <dlfcn.h>
 #elif defined(DLDAPI_VMS_IODBC)
-extern void FAR *iodbc_dlopen (char FAR * path, int mode);
-extern void FAR *iodbc_dlsym (void FAR * hdll, char FAR * sym);
-extern char FAR *iodbc_dlerror ();
-extern int iodbc_dlclose (void FAR * hdll);
+extern void *iodbc_dlopen (char * path, int mode);
+extern void *iodbc_dlsym (void * hdll, char * sym);
+extern char *iodbc_dlerror ();
+extern int iodbc_dlclose (void * hdll);
 #else
-extern void FAR *dlopen (char FAR * path, int mode);
-extern void FAR *dlsym (void FAR * hdll, char FAR * sym);
-extern char FAR *dlerror ();
-extern int dlclose (void FAR * hdll);
+extern void *dlopen (char * path, int mode);
+extern void *dlsym (void * hdll, char * sym);
+extern char *dlerror ();
+extern int dlclose (void * hdll);
 #endif
 
 
