@@ -1,7 +1,7 @@
 /*
  *  dlproc.c
  *
- *  $Id: dlproc.c,v 1.11 2003/08/22 14:28:41 source Exp $
+ *  $Id: dlproc.c,v 1.13 2004/09/10 12:09:28 source Exp $
  *
  *  Load driver and resolve driver's function entry point
  *
@@ -97,13 +97,13 @@ HPROC
 _iodbcdm_getproc (HDBC hdbc, int idx)
 {
   CONN (pdbc, hdbc);
-  ENV_t FAR *penv;
-  HPROC FAR *phproc;
+  ENV_t *penv;
+  HPROC *phproc;
 
   if (idx <= 0 || idx >= __LAST_API_FUNCTION__)
     return SQL_NULL_HPROC;
 
-  penv = (ENV_t FAR *) (pdbc->henv);
+  penv = (ENV_t *) (pdbc->henv);
 
   if (penv == NULL)
     return SQL_NULL_HPROC;
@@ -117,15 +117,64 @@ _iodbcdm_getproc (HDBC hdbc, int idx)
 }
 
 
+static dlproc_t *pRoot = NULL;
+
+
 HDLL
-_iodbcdm_dllopen (char FAR * path)
+_iodbcdm_dllopen (char *path)
 {
-  return (HDLL) DLL_OPEN (path);
+  dlproc_t *pDrv = NULL, *p;
+
+  /*
+   *  Check if we have already loaded the driver
+   */
+  for (p = pRoot; p; p = p->next)
+    {
+      if (STREQ (p->path, path))
+	{
+	  pDrv = p;
+	  break;
+	}
+    }
+
+  /*
+   *  If already loaded, increase ref counter
+   */
+  if (pDrv)
+    {
+      pDrv->refcount++;
+
+      /*
+       *  If the driver was unloaded, load it again
+       */
+      if (pDrv->dll == NULL)
+	pDrv->dll = (HDLL) DLL_OPEN (path);
+
+      return pDrv->dll;
+    }
+
+  /*
+   *  Initialize new structure
+   */
+  if ((pDrv = calloc (1, sizeof (dlproc_t))) == NULL)
+    return NULL;
+
+  pDrv->refcount = 1;
+  pDrv->path = STRDUP (path);
+  pDrv->dll = (HDLL) DLL_OPEN (path);
+
+  /*
+   *  Add to linked list
+   */
+  pDrv->next = pRoot;
+  pRoot = pDrv;
+
+  return pDrv->dll;
 }
 
 
 HPROC
-_iodbcdm_dllproc (HDLL hdll, char FAR * sym)
+_iodbcdm_dllproc (HDLL hdll, char *sym)
 {
   return (HPROC) DLL_PROC (hdll, sym);
 }
@@ -134,7 +183,43 @@ _iodbcdm_dllproc (HDLL hdll, char FAR * sym)
 int
 _iodbcdm_dllclose (HDLL hdll)
 {
-  DLL_CLOSE (hdll);
+  dlproc_t *pDrv = NULL, *p;
+
+  /*
+   *  Find loaded driver
+   */
+  for (p = pRoot; p; p = p->next)
+    {
+      if (p->dll == hdll)
+	{
+	  pDrv = p;
+	  break;
+	}
+    }
+
+  /*
+   *  Not found
+   */
+  if (!pDrv)
+    return -1;
+
+  /*
+   *  Decrease reference counter
+   */
+  pDrv->refcount--;
+
+  /*
+   *  Check if it is possible to unload the driver safely
+   * 
+   *  NOTE: Some drivers set explicit on_exit hooks, which makes it
+   *        impossible for the driver manager to unload the driver
+   *        as this would crash the executable at exit.
+   */
+  if (pDrv->refcount == 0 && pDrv->safe_unload)
+    {
+      DLL_CLOSE (pDrv->dll);
+      pDrv->dll = NULL;
+    }
 
   return 0;
 }
@@ -145,3 +230,34 @@ _iodbcdm_dllerror ()
 {
   return DLL_ERROR ();
 }
+
+
+/* 
+ *  If driver manager determines this driver is safe, flag the driver can
+ *  be unloaded if not used.
+ */
+void
+_iodbcdm_safe_unload (HDLL hdll)
+{
+  dlproc_t *pDrv = NULL, *p;
+
+  /*
+   *  Find loaded driver
+   */
+  for (p = pRoot; p; p = p->next)
+    {
+      if (p->dll == hdll)
+	{
+	  pDrv = p;
+	  break;
+	}
+    }
+
+  /*
+   *  Driver not found
+   */
+  if (!pDrv)
+    return;
+
+  pDrv->safe_unload = 1;
+}
