@@ -1,7 +1,7 @@
 /*
  *  dlproc.h
  *
- *  $Id: dlproc.h,v 1.13 2003/09/03 10:08:53 source Exp $
+ *  $Id: dlproc.h,v 1.16 2004/09/10 12:09:28 source Exp $
  *
  *  Load driver and resolve driver's function entry point
  *
@@ -75,10 +75,10 @@
 
 #include <dlf.h>
 
-#if defined(_MAC)
-typedef SQLRETURN (FAR * HPROC) (...);
+#if defined(_MAC) || defined (__cplusplus)
+typedef SQLRETURN (* HPROC) (...);
 #else
-typedef SQLRETURN (FAR * HPROC) ();
+typedef SQLRETURN (* HPROC) ();
 #endif
 
 #ifdef	DLDAPI_SVR4_DLFCN
@@ -101,11 +101,24 @@ typedef shl_t HDLL;
 typedef void *HDLL;
 #endif
 
-extern HPROC _iodbcdm_getproc (HDBC hdbc, int idx);
-extern HDLL _iodbcdm_dllopen (char FAR * dll);
-extern HPROC _iodbcdm_dllproc (HDLL hdll, char FAR * sym);
-extern char FAR *_iodbcdm_dllerror ();
-extern int _iodbcdm_dllclose (HDLL hdll);
+
+typedef struct _dl_s
+{
+  char		* path;
+  HDLL		  dll;
+  unsigned int    refcount;
+  int 		  safe_unload;
+  struct _dl_s	* next;
+} dlproc_t;
+
+
+/* dlproc.c */
+HPROC _iodbcdm_getproc (HDBC hdbc, int idx);
+HDLL _iodbcdm_dllopen (char *path);
+HPROC _iodbcdm_dllproc (HDLL hdll, char *sym);
+int _iodbcdm_dllclose (HDLL hdll);
+char *_iodbcdm_dllerror (void);
+void _iodbcdm_safe_unload (HDLL hdll);
 
 #define	SQL_NULL_HDLL	((HDLL)NULL)
 #define	SQL_NULL_HPROC	((HPROC)NULL)
