@@ -1,7 +1,7 @@
 /*
  *  execute.c
  *
- *  $Id: execute.c,v 1.16 2003/09/03 08:44:47 source Exp $
+ *  $Id: execute.c,v 1.19 2004/07/06 15:26:07 source Exp $
  *
  *  Invoke a query
  *
@@ -89,7 +89,7 @@
 #include <itrace.h>
 
 void
-_iodbcdm_do_cursoropen (STMT_t FAR * pstmt)
+_iodbcdm_do_cursoropen (STMT_t * pstmt)
 {
   SQLRETURN retcode;
   SWORD ncol;
@@ -120,8 +120,7 @@ SQLExecute_Internal (SQLHSTMT hstmt)
   STMT (pstmt, hstmt);
   HPROC hproc = SQL_NULL_HPROC;
   SQLRETURN retcode;
-
-  int sqlstat = en_00000;
+  sqlstcode_t sqlstat = en_00000;
 
   /* check state */
   if (pstmt->asyn_on == en_NullProc)
@@ -291,10 +290,10 @@ SQLExecDirect_Internal (SQLHSTMT hstmt,
 {
   STMT (pstmt, hstmt);
   CONN (pdbc, pstmt->hdbc);
-  ENV_t FAR *penv = pdbc->henv;
+  ENVR (penv, pdbc->henv);
   HPROC hproc = SQL_NULL_HPROC;
   SQLRETURN retcode = SQL_SUCCESS;
-  int sqlstat = en_00000;
+  sqlstcode_t sqlstat = en_00000;
   void * _SqlStr = NULL;
 
   /* check arguments */
@@ -352,12 +351,12 @@ SQLExecDirect_Internal (SQLHSTMT hstmt,
       if (waMode != 'W')
         {
         /* ansi=>unicode*/
-          _SqlStr = _iodbcdm_conv_param_A2W(pstmt, 0, szSqlStr, cbSqlStr);
+          _SqlStr = _iodbcdm_conv_param_A2W(pstmt, 0, (SQLCHAR *) szSqlStr, cbSqlStr);
         }
       else
         {
         /* unicode=>ansi*/
-          _SqlStr = _iodbcdm_conv_param_W2A(pstmt, 0, szSqlStr, cbSqlStr);
+          _SqlStr = _iodbcdm_conv_param_W2A(pstmt, 0, (SQLWCHAR *) szSqlStr, cbSqlStr);
         }
       szSqlStr = _SqlStr;
       cbSqlStr = SQL_NTS;
@@ -436,7 +435,7 @@ SQLExecDirect_Internal (SQLHSTMT hstmt,
 
 
 SQLRETURN SQL_API
-SQLExecDirect (SQLHSTMT hstmt, SQLCHAR FAR * szSqlStr, SQLINTEGER cbSqlStr)
+SQLExecDirect (SQLHSTMT hstmt, SQLCHAR * szSqlStr, SQLINTEGER cbSqlStr)
 {
   ENTER_STMT (hstmt,
     trace_SQLExecDirect (TRACE_ENTER, hstmt, szSqlStr, cbSqlStr));
@@ -449,7 +448,7 @@ SQLExecDirect (SQLHSTMT hstmt, SQLCHAR FAR * szSqlStr, SQLINTEGER cbSqlStr)
 
 
 SQLRETURN SQL_API
-SQLExecDirectA (SQLHSTMT hstmt, SQLCHAR FAR * szSqlStr, SQLINTEGER cbSqlStr)
+SQLExecDirectA (SQLHSTMT hstmt, SQLCHAR * szSqlStr, SQLINTEGER cbSqlStr)
 {
   ENTER_STMT (hstmt,
     trace_SQLExecDirect (TRACE_ENTER, hstmt, szSqlStr, cbSqlStr));
@@ -462,7 +461,7 @@ SQLExecDirectA (SQLHSTMT hstmt, SQLCHAR FAR * szSqlStr, SQLINTEGER cbSqlStr)
 
 
 SQLRETURN SQL_API
-SQLExecDirectW (SQLHSTMT hstmt, SQLWCHAR FAR * szSqlStr, SQLINTEGER cbSqlStr)
+SQLExecDirectW (SQLHSTMT hstmt, SQLWCHAR * szSqlStr, SQLINTEGER cbSqlStr)
 {
   ENTER_STMT (hstmt,
     trace_SQLExecDirectW (TRACE_ENTER, hstmt, szSqlStr, cbSqlStr));
@@ -475,7 +474,10 @@ SQLExecDirectW (SQLHSTMT hstmt, SQLWCHAR FAR * szSqlStr, SQLINTEGER cbSqlStr)
 
 
 static SQLRETURN
-SQLPutData_Internal (SQLHSTMT hstmt, SQLPOINTER rgbValue, SQLINTEGER cbValue)
+SQLPutData_Internal (
+  SQLHSTMT		  hstmt,
+  SQLPOINTER		  rgbValue, 
+  SQLLEN		  cbValue)
 {
   STMT (pstmt, hstmt);
   HPROC hproc;
@@ -584,7 +586,10 @@ SQLPutData_Internal (SQLHSTMT hstmt, SQLPOINTER rgbValue, SQLINTEGER cbValue)
 
 
 SQLRETURN SQL_API
-SQLPutData (SQLHSTMT hstmt, SQLPOINTER rgbValue, SQLINTEGER cbValue)
+SQLPutData (
+  SQLHSTMT		  hstmt, 
+  SQLPOINTER		  rgbValue, 
+  SQLLEN		  cbValue)
 {
   ENTER_STMT (hstmt,
     trace_SQLPutData (TRACE_ENTER, hstmt, rgbValue, cbValue));
@@ -597,7 +602,7 @@ SQLPutData (SQLHSTMT hstmt, SQLPOINTER rgbValue, SQLINTEGER cbValue)
 
 
 static SQLRETURN
-SQLParamData_Internal (SQLHSTMT hstmt, SQLPOINTER FAR * prgbValue)
+SQLParamData_Internal (SQLHSTMT hstmt, SQLPOINTER * prgbValue)
 {
   STMT (pstmt, hstmt);
   HPROC hproc;
@@ -726,7 +731,7 @@ SQLParamData_Internal (SQLHSTMT hstmt, SQLPOINTER FAR * prgbValue)
 
 
 SQLRETURN SQL_API
-SQLParamData (SQLHSTMT hstmt, SQLPOINTER FAR * prgbValue)
+SQLParamData (SQLHSTMT hstmt, SQLPOINTER * prgbValue)
 {
   ENTER_STMT (hstmt,
     trace_SQLParamData (TRACE_ENTER, hstmt, prgbValue));
@@ -739,7 +744,7 @@ SQLParamData (SQLHSTMT hstmt, SQLPOINTER FAR * prgbValue)
 
 
 static SQLRETURN
-SQLNumParams_Internal (SQLHSTMT hstmt, SQLSMALLINT FAR * pcpar)
+SQLNumParams_Internal (SQLHSTMT hstmt, SQLSMALLINT * pcpar)
 {
   STMT (pstmt, hstmt);
   HPROC hproc;
@@ -812,7 +817,7 @@ SQLNumParams_Internal (SQLHSTMT hstmt, SQLSMALLINT FAR * pcpar)
 
 
 SQLRETURN SQL_API
-SQLNumParams (SQLHSTMT hstmt, SQLSMALLINT FAR * pcpar)
+SQLNumParams (SQLHSTMT hstmt, SQLSMALLINT * pcpar)
 {
   ENTER_STMT (hstmt,
     trace_SQLNumParams (TRACE_ENTER, hstmt, pcpar));
@@ -825,15 +830,17 @@ SQLNumParams (SQLHSTMT hstmt, SQLSMALLINT FAR * pcpar)
 
 
 static SQLRETURN
-SQLDescribeParam_Internal (SQLHSTMT hstmt,
-    SQLUSMALLINT ipar,
-    SQLSMALLINT FAR * pfSqlType,
-    SQLUINTEGER FAR * pcbColDef,
-    SQLSMALLINT FAR * pibScale, SQLSMALLINT FAR * pfNullable)
+SQLDescribeParam_Internal (
+    SQLHSTMT		  hstmt,
+    SQLUSMALLINT	  ipar,
+    SQLSMALLINT		* pfSqlType,
+    SQLULEN		* pcbColDef,
+    SQLSMALLINT		* pibScale, 
+    SQLSMALLINT 	* pfNullable)
 {
   STMT (pstmt, hstmt);
   CONN (pdbc, pstmt->hdbc);
-  GENV_t FAR *genv = pdbc->genv;
+  GENV (genv, pdbc->genv);
 
   HPROC hproc;
   SQLRETURN retcode;
@@ -917,10 +924,10 @@ SQLRETURN SQL_API
 SQLDescribeParam (
   SQLHSTMT		  hstmt,
   SQLUSMALLINT		  ipar,
-  SQLSMALLINT FAR	* pfSqlType,
-  SQLUINTEGER FAR	* pcbColDef,
-  SQLSMALLINT FAR	* pibScale,
-  SQLSMALLINT FAR	* pfNullable)
+  SQLSMALLINT 		* pfSqlType,
+  SQLULEN 		* pcbColDef,
+  SQLSMALLINT 		* pibScale,
+  SQLSMALLINT 		* pfNullable)
 {
   ENTER_STMT (hstmt,
     trace_SQLDescribeParam (TRACE_ENTER,
