@@ -1,7 +1,7 @@
 /*
  *  fetch.c
  *
- *  $Id: fetch.c,v 1.16 2003/08/29 12:17:26 source Exp $
+ *  $Id: fetch.c,v 1.19 2004/07/06 15:26:07 source Exp $
  *
  *  Fetch query result
  *
@@ -122,9 +122,9 @@ SQLFetch_Internal (SQLHSTMT hstmt)
       return SQL_ERROR;
     }
 #if (ODBCVER >= 0x0300)
-  if (((ENV_t FAR *) ((DBC_t FAR *) pstmt->hdbc)->henv)->dodbc_ver ==
+  if (((ENV_t *) ((DBC_t *) pstmt->hdbc)->henv)->dodbc_ver ==
       SQL_OV_ODBC2
-      && ((GENV_t FAR *) ((DBC_t FAR *) pstmt->hdbc)->genv)->odbc_ver ==
+      && ((GENV_t *) ((DBC_t *) pstmt->hdbc)->genv)->odbc_ver ==
       SQL_OV_ODBC3)
     {				
 	/* 
@@ -235,11 +235,11 @@ SQLFetch (SQLHSTMT hstmt)
 
 SQLRETURN SQL_API
 _iodbcdm_ExtendedFetch (
-    SQLHSTMT hstmt,
-    SQLUSMALLINT fFetchType,
-    SQLINTEGER irow, 
-    SQLUINTEGER FAR * pcrow, 
-    SQLUSMALLINT FAR * rgfRowStatus)
+    SQLHSTMT		  hstmt,
+    SQLUSMALLINT	  fFetchType,
+    SQLLEN		  irow, 
+    SQLULEN	 	* pcrow, 
+    SQLUSMALLINT 	* rgfRowStatus)
 {
   STMT (pstmt, hstmt);
   HPROC hproc = SQL_NULL_HPROC;
@@ -353,9 +353,9 @@ SQLRETURN SQL_API
 SQLExtendedFetch (
   SQLHSTMT		  hstmt, 
   SQLUSMALLINT		  fFetchType, 
-  SQLINTEGER		  irow, 
-  SQLUINTEGER FAR	* pcrow, 
-  SQLUSMALLINT FAR	* rgfRowStatus)
+  SQLLEN		  irow, 
+  SQLULEN 		* pcrow, 
+  SQLUSMALLINT 		* rgfRowStatus)
 {
   ENTER_STMT (hstmt,
     trace_SQLExtendedFetch (TRACE_ENTER,
@@ -379,15 +379,15 @@ SQLGetData_Internal (
   SQLUSMALLINT		  icol,
   SQLSMALLINT		  fCType,
   SQLPOINTER		  rgbValue,
-  SQLINTEGER		  cbValueMax,
-  SQLINTEGER FAR	* pcbValue)
+  SQLLEN		  cbValueMax,
+  SQLLEN 		* pcbValue)
 {
   STMT (pstmt, hstmt);
   CONN (pdbc, pstmt->hdbc);
-  ENV_t FAR *penv = pdbc->henv;
+  ENVR (penv, pdbc->henv);
   HPROC hproc;
   SQLRETURN retcode = SQL_SUCCESS;
-  int sqlstat = en_00000;
+  sqlstcode_t sqlstat = en_00000;
   SQLSMALLINT nCType;
 
   /* check argument */
@@ -552,7 +552,7 @@ SQLGetData_Internal (
 
   if (!penv->unicode_driver && fCType == SQL_C_WCHAR)
     {
-      wchar_t *buf = dm_SQL_A2W(rgbValue, SQL_NTS);
+      wchar_t *buf = dm_SQL_A2W((SQLCHAR *) rgbValue, SQL_NTS);
 
       if (buf != NULL) 
         WCSCPY(rgbValue, buf);
@@ -567,12 +567,13 @@ SQLGetData_Internal (
 
 
 SQLRETURN SQL_API
-SQLGetData (SQLHSTMT hstmt,
-    SQLUSMALLINT icol,
-    SQLSMALLINT fCType,
-    SQLPOINTER rgbValue,
-    SQLINTEGER cbValueMax,
-    SQLINTEGER FAR * pcbValue)
+SQLGetData (
+    SQLHSTMT		  hstmt,
+    SQLUSMALLINT	  icol,
+    SQLSMALLINT		  fCType,
+    SQLPOINTER		  rgbValue,
+    SQLLEN		  cbValueMax,
+    SQLLEN 		* pcbValue)
 {
   ENTER_STMT (hstmt,
     trace_SQLGetData (TRACE_ENTER, 
@@ -745,13 +746,16 @@ SQLMoreResults (SQLHSTMT hstmt)
 
 
 SQLRETURN SQL_API
-_iodbcdm_SetPos (SQLHSTMT hstmt,
-    SQLUSMALLINT irow, SQLUSMALLINT fOption, SQLUSMALLINT fLock)
+_iodbcdm_SetPos (
+  SQLHSTMT		  hstmt,
+  SQLSETPOSIROW		  irow, 
+  SQLUSMALLINT		  fOption, 
+  SQLUSMALLINT		  fLock)
 {
   STMT (pstmt, hstmt);
   HPROC hproc;
   SQLRETURN retcode;
-  int sqlstat = en_00000;
+  sqlstcode_t sqlstat = en_00000;
 
   /* check argument value */
   if (fOption > SQL_ADD || fLock > SQL_LOCK_UNLOCK)
@@ -852,10 +856,10 @@ _iodbcdm_SetPos (SQLHSTMT hstmt,
 
 SQLRETURN SQL_API
 SQLSetPos (
-  SQLHSTMT	hstmt,
-  SQLUSMALLINT	irow, 
-  SQLUSMALLINT	fOption, 
-  SQLUSMALLINT	fLock)
+  SQLHSTMT		  hstmt,
+  SQLSETPOSIROW		  irow, 
+  SQLUSMALLINT		  fOption, 
+  SQLUSMALLINT		  fLock)
 {
   ENTER_STMT (hstmt,
     trace_SQLSetPos (TRACE_ENTER,
