@@ -1,7 +1,7 @@
 /*
  *  hdbc.h
  *
- *  $Id: hdbc.h,v 1.10 2003/08/22 14:28:41 source Exp $
+ *  $Id: hdbc.h,v 1.15 2004/08/26 12:12:54 source Exp $
  *
  *  Data source connect object management functions
  *
@@ -80,8 +80,8 @@
 typedef struct _drvopt
   {
     SQLUSMALLINT Option;
-    SQLUINTEGER  Param;
-    SQLCHAR      waMode;
+    SQLULEN Param;
+    SQLCHAR waMode;
 
     struct _drvopt *next;
   } 
@@ -93,7 +93,7 @@ typedef struct DBC
     HERR herr;
     SQLRETURN rc;
 
-    struct DBC FAR * next;
+    struct DBC * next;
 
     HENV genv;			/* back point to global env object */
 
@@ -118,7 +118,7 @@ typedef struct DBC
     SWORD cb_commit;
     SWORD cb_rollback;
 
-    wchar_t FAR * current_qualifier;
+    wchar_t * current_qualifier;
     char current_qualifier_WA;
 
     SWORD dbc_cip;			/* Call in Progess flag */
@@ -130,7 +130,7 @@ DBC_t;
 
 
 #define IS_VALID_HDBC(x) \
-	((x) != SQL_NULL_HDBC && ((DBC_t FAR *)(x))->type == SQL_HANDLE_DBC)
+	((x) != SQL_NULL_HDBC && ((DBC_t *)(x))->type == SQL_HANDLE_DBC)
 
 
 #define ENTER_HDBC(hdbc, holdlock, trace) \
@@ -152,7 +152,7 @@ DBC_t;
 	pdbc->dbc_cip = 1; \
 	CLEAR_ERRORS (pdbc); \
 	if (!holdlock) \
-	  ODBC_UNLOCK();
+	  ODBC_UNLOCK()
 
 
 #define LEAVE_HDBC(hdbc, holdlock, trace) \
@@ -162,7 +162,7 @@ DBC_t;
     done: \
     	TRACE(trace); \
 	ODBC_UNLOCK (); \
-	return (retcode);
+	return (retcode)
 
 
 /* 
@@ -199,7 +199,7 @@ enum
 SQLRETURN SQL_API _iodbcdm_SetConnectOption (
     SQLHDBC hdbc,
     SQLUSMALLINT fOption, 
-    SQLUINTEGER vParam,
+    SQLULEN vParam,
     SQLCHAR waMode);
 SQLRETURN SQL_API _iodbcdm_GetConnectOption (
     SQLHDBC hdbc,
