@@ -1,7 +1,7 @@
 /*
  *  hdesc.h
  *
- *  $Id: hdesc.h,v 1.6 2003/09/03 08:44:47 source Exp $
+ *  $Id: hdesc.h,v 1.8 2004/08/26 12:12:54 source Exp $
  *
  *  Descriptor object
  *
@@ -103,8 +103,8 @@ typedef struct DESC_s {
 
 #define IS_VALID_HDESC(x) \
 	((x) != SQL_NULL_HDESC && \
-	 ((DESC_t FAR *)(x))->type == SQL_HANDLE_DESC && \
-	 ((DESC_t FAR *)(x))->hdbc != SQL_NULL_HDBC)
+	 ((DESC_t *)(x))->type == SQL_HANDLE_DESC && \
+	 ((DESC_t *)(x))->hdbc != SQL_NULL_HDBC)
 
 
 #define ENTER_DESC(hdesc, trace) \
@@ -125,7 +125,7 @@ typedef struct DESC_s {
 	  } \
 	pdesc->desc_cip = 1; \
 	CLEAR_ERRORS (pdesc); \
-	ODBC_UNLOCK();
+	ODBC_UNLOCK()
 
 
 #define LEAVE_DESC(hdesc, trace) \
@@ -134,6 +134,6 @@ typedef struct DESC_s {
     	TRACE(trace); \
 	pdesc->desc_cip = 0; \
 	ODBC_UNLOCK (); \
-	return (retcode);
+	return (retcode)
 
 #endif /* __DESC_H */
