@@ -1,7 +1,7 @@
 /*
  *  henv.c
  *
- *  $Id: henv.c,v 1.15 2004/06/21 13:34:28 source Exp $
+ *  $Id: henv.c,v 1.17 2005/02/01 14:22:09 source Exp $
  *
  *  Environment object management functions
  *
@@ -95,8 +95,9 @@ SPINLOCK_DECLARE (iodbcdm_global_lock);
 #endif
 
 static int _iodbcdm_initialized = 0;
-static void Init_iODBC(void);
-static void Done_iODBC(void);
+
+void Init_iODBC(void);
+void Done_iODBC(void);
 
 
 static void
@@ -126,6 +127,7 @@ _iodbcdm_env_settracing (GENV_t *genv)
   return;
 }
 
+unsigned long _iodbc_env_counter = 0;
 
 SQLRETURN 
 SQLAllocEnv_Internal (SQLHENV * phenv, int odbc_ver)
@@ -133,12 +135,6 @@ SQLAllocEnv_Internal (SQLHENV * phenv, int odbc_ver)
   GENV (genv, NULL);
   int retcode = SQL_SUCCESS;
 
-  /* 
-   *  One time initialization
-   */
-  if (!_iodbcdm_initialized)
-      Init_iODBC();
-
   genv = (GENV_t *) MEM_ALLOC (sizeof (GENV_t));
 
   if (genv == NULL)
@@ -166,7 +162,8 @@ SQLAllocEnv_Internal (SQLHENV * phenv, int odbc_ver)
   /*
    * Initialize tracing 
    */
-  _iodbcdm_env_settracing (genv);
+  if (++_iodbc_env_counter == 1)
+    _iodbcdm_env_settracing (genv);
 
   return retcode;
 }
@@ -178,6 +175,12 @@ SQLAllocEnv (SQLHENV * phenv)
   GENV (genv, NULL);
   int retcode = SQL_SUCCESS;
 
+  /* 
+   *  One time initialization
+   */
+  Init_iODBC();
+
+  ODBC_LOCK ();
   retcode = SQLAllocEnv_Internal (phenv, SQL_OV_ODBC2);
 
   genv = (GENV_t *) *phenv;
@@ -188,6 +191,8 @@ SQLAllocEnv (SQLHENV * phenv)
   TRACE (trace_SQLAllocEnv (TRACE_ENTER, phenv));
   TRACE (trace_SQLAllocEnv (TRACE_LEAVE, phenv));
 
+  ODBC_UNLOCK ();
+
   return retcode;
 }
 
@@ -235,6 +240,12 @@ SQLFreeEnv (SQLHENV henv)
 
   MEM_FREE (genv);
 
+  /*
+   *  Close trace after last environment handle is freed
+   */
+  if (--_iodbc_env_counter == 0)
+    trace_stop();
+
   ODBC_UNLOCK ();
 
   return retcode;
@@ -245,7 +256,7 @@ SQLFreeEnv (SQLHENV henv)
  *  Initialize the system and let everyone wait until we have done so
  *  properly
  */
-static void
+void
 Init_iODBC (void)
 {
 #if !defined (PTHREAD_MUTEX_INITIALIZER) || defined (WINDOWS)
@@ -256,13 +267,13 @@ Init_iODBC (void)
   if (!_iodbcdm_initialized)
     {
       /*
-       *  Other one time initializations can be performed here
-       */
-
-      /*
-       *  OK, now flag we are not callable anymore and return
+       *  OK, now flag we are not callable anymore
        */
       _iodbcdm_initialized = 1;
+
+      /*
+       *  Other one time initializations can be performed here
+       */
     }
   SPINLOCK_UNLOCK (iodbcdm_global_lock);
 
@@ -273,7 +284,9 @@ Init_iODBC (void)
 static void 
 Done_iODBC(void)
 {
+#if !defined (PTHREAD_MUTEX_INITIALIZER) || defined (WINDOWS)
     SPINLOCK_DONE (iodbcdm_global_lock);
+#endif
 }
 
 
