@@ -1,7 +1,7 @@
 /*
  *  henv.h
  *
- *  $Id: henv.h,v 1.14 2003/08/22 14:28:41 source Exp $
+ *  $Id: henv.h,v 1.17 2004/08/26 12:12:54 source Exp $
  *
  *  Environment object management functions
  *
@@ -101,7 +101,7 @@ typedef struct
     HDBC hdbc;			/* driver's dbc list */
     int state;
 #if (ODBCVER >= 0x300)
-    SQLINTEGER odbc_ver;    /* ODBC version of the application */
+    SQLUINTEGER odbc_ver;    /* ODBC version of the application */
 #endif    
 
     SQLSMALLINT err_rec;
@@ -122,14 +122,14 @@ typedef struct
     MUTEX_DECLARE (drv_lock);	/* Used only when driver is not threadsafe */
 
 #if (ODBCVER >= 0x300)
-    SQLINTEGER dodbc_ver;	/* driver's ODBC version */
+    SQLUINTEGER dodbc_ver;	/* driver's ODBC version */
 #endif    
   }
 ENV_t;
 
 
 #define IS_VALID_HENV(x) \
-	((x) != SQL_NULL_HENV && ((GENV_t FAR *)(x))->type == SQL_HANDLE_ENV)
+	((x) != SQL_NULL_HENV && ((GENV_t *)(x))->type == SQL_HANDLE_ENV)
 
 
 #define ENTER_HENV(henv, trace) \
@@ -142,14 +142,14 @@ ENV_t;
 	    retcode = SQL_INVALID_HANDLE; \
 	    goto done; \
 	  } \
-	CLEAR_ERRORS (genv);
+	CLEAR_ERRORS (genv)
 
 
 #define LEAVE_HENV(henv, trace) \
     done: \
      	TRACE(trace); \
 	ODBC_UNLOCK (); \
-	return (retcode);
+	return (retcode)
   
 
 /*
