@@ -1,7 +1,7 @@
 /*
  *  herr.c
  *
- *  $Id: herr.c,v 1.18 2004/02/17 19:34:40 source Exp $
+ *  $Id: herr.c,v 1.21 2004/06/21 13:34:28 source Exp $
  *
  *  Error stack management functions
  *
@@ -144,7 +144,7 @@ _iodbcdm_pushsqlerr (
     /* overwrite the top entry to prevent error stack blow out */
     {
       perr->code = code;
-      perr->msg = msg;
+      perr->msg = (char *) msg;
 
       return herr;
     }
@@ -156,7 +156,7 @@ _iodbcdm_pushsqlerr (
       return NULL;
     }
 
-  ebuf->msg = msg;
+  ebuf->msg = (char *) msg;
   ebuf->code = code;
   ebuf->idx = idx;
   ebuf->next = (sqlerr_t *) herr;
@@ -164,45 +164,48 @@ _iodbcdm_pushsqlerr (
 }
 
 
-static char FAR *
+static char *
 _iodbcdm_getsqlstate (
     HERR herr,
-    void FAR * tab)
+    void * tab)
 {
   sqlerr_t *perr = (sqlerr_t *) herr;
   sqlerrmsg_t *ptr;
-  int perr_code;
+  sqlstcode_t perr_code;
 
   if (herr == SQL_NULL_HERR || tab == NULL)
     {
-      return (char FAR *) NULL;
+      return (char *) NULL;
     }
 
   perr_code = perr->code;
 #if (ODBCVER >= 0x0300)
   switch (perr_code)
     {
-      case en_S1009 : perr_code = en_HY009; break;
+    case en_S1009:
+      perr_code = en_HY009;
+      break;
+
+    default:
+      break;
     }
-#endif  
-  for (ptr = tab;
-      ptr->code != en_sqlstat_total;
-      ptr++)
+#endif
+  for (ptr = (sqlerrmsg_t *) tab; ptr->code != en_sqlstat_total; ptr++)
     {
       if (ptr->code == perr_code)
 	{
-	  return (char FAR *) (ptr->stat);
+	  return (char *) (ptr->stat);
 	}
     }
 
-  return (char FAR *) NULL;
+  return (char *) NULL;
 }
 
 
-static char FAR *
+static char *
 _iodbcdm_getsqlerrmsg (
     HERR herr,
-    void FAR * errtab)
+    void * errtab)
 {
   sqlerr_t *perr = (sqlerr_t *) herr;
   sqlerrmsg_t *ptr;
@@ -228,11 +231,11 @@ _iodbcdm_getsqlerrmsg (
     {
       if (ptr->code == perr->code)
 	{
-	  return (char FAR *) ptr->msg;
+	  return (char *) ptr->msg;
 	}
     }
 
-  return (char FAR *) NULL;
+  return (char *) NULL;
 }
 
 
@@ -242,10 +245,10 @@ _iodbcdm_sqlerror (
   SQLHDBC		  hdbc,
   SQLHSTMT		  hstmt,
   SQLPOINTER		  szSqlstate,
-  SQLINTEGER		  FAR * pfNativeError,
+  SQLINTEGER		* pfNativeError,
   SQLPOINTER		  szErrorMsg,
   SQLSMALLINT		  cbErrorMsgMax,
-  SQLSMALLINT FAR	* pcbErrorMsg,
+  SQLSMALLINT 		* pcbErrorMsg,
   int		  	  bDelete,
   SQLCHAR		  waMode)
 {
@@ -267,7 +270,7 @@ _iodbcdm_sqlerror (
   SQLSMALLINT *perr_rec = NULL;
 #endif
   SWORD unicode_driver = 0;
-  SQLINTEGER dodbc_ver = SQL_OV_ODBC2;	
+  SQLUINTEGER dodbc_ver = SQL_OV_ODBC2;	
   wchar_t _sqlState[6] = {L"\0"};
   void *SqlstateOut = szSqlstate;
   void *_ErrorMsg = NULL;
@@ -293,7 +296,7 @@ _iodbcdm_sqlerror (
       handleType = SQL_HANDLE_STMT;
       handle3 = hstmt;
       dhandle3 = pstmt->dhstmt;
-      perr_rec = &((STMT_t FAR*)pstmt)->err_rec;
+      perr_rec = &((STMT_t *)pstmt)->err_rec;
 #endif      
       dhstmt = pstmt->dhstmt;
       handle = 3;
@@ -311,7 +314,7 @@ _iodbcdm_sqlerror (
       handleType = SQL_HANDLE_DBC;
       handle3 = hdbc;
       dhandle3 = pdbc->dhdbc;
-      perr_rec = &((DBC_t FAR*)pdbc)->err_rec;
+      perr_rec = &((DBC_t *)pdbc)->err_rec;
 #endif      
       dhdbc = pdbc->dhdbc;
       handle = 2;
@@ -353,8 +356,8 @@ _iodbcdm_sqlerror (
   if (herr == SQL_NULL_HERR)	/* no err on drv mng */
     {
       /* call driver */
-      unicode_driver = ((ENV_t FAR *) ((DBC_t FAR *)thdbc)->henv)->unicode_driver;
-      dodbc_ver = ((ENV_t FAR *) ((DBC_t FAR *)thdbc)->henv)->dodbc_ver;
+      unicode_driver = ((ENV_t *) ((DBC_t *)thdbc)->henv)->unicode_driver;
+      dodbc_ver = ((ENV_t *) ((DBC_t *)thdbc)->henv)->dodbc_ver;
 
       if ((unicode_driver && waMode != 'W') 
           || (!unicode_driver && waMode == 'W'))
@@ -505,14 +508,14 @@ _iodbcdm_sqlerror (
           if (waMode != 'W')
             {
             /* ansi<=unicode*/
-              dm_StrCopyOut2_W2A (errorMsgOut, szErrorMsg, cbErrorMsgMax, NULL);
-              dm_StrCopyOut2_W2A (SqlstateOut, szSqlstate, 6, NULL);
+              dm_StrCopyOut2_W2A ((SQLWCHAR *)errorMsgOut, (SQLCHAR *)szErrorMsg, cbErrorMsgMax, NULL);
+              dm_StrCopyOut2_W2A ((SQLWCHAR *)SqlstateOut, (SQLCHAR *)szSqlstate, 6, NULL);
             }
           else
             {
             /* unicode<=ansi*/
-              dm_StrCopyOut2_A2W (errorMsgOut, szErrorMsg, cbErrorMsgMax, NULL);
-              dm_StrCopyOut2_A2W (SqlstateOut, szSqlstate, 6, NULL);
+              dm_StrCopyOut2_A2W ((SQLCHAR *)errorMsgOut, (SQLWCHAR *)szErrorMsg, cbErrorMsgMax, NULL);
+              dm_StrCopyOut2_A2W ((SQLCHAR *)SqlstateOut, (SQLWCHAR *)szSqlstate, 6, NULL);
             }
         }
     
@@ -526,8 +529,8 @@ _iodbcdm_sqlerror (
       int len;
 
       /* get sql state  string */
-      ststr = (char FAR *) _iodbcdm_getsqlstate (herr,
-	  (void FAR *) sqlerrmsg_tab);
+      ststr = (char *) _iodbcdm_getsqlstate (herr,
+	  (void *) sqlerrmsg_tab);
 
       if (ststr == NULL)
 	{
@@ -549,7 +552,7 @@ _iodbcdm_sqlerror (
         }
       else
         {
-          dm_StrCopyOut2_A2W (ststr, szSqlstate, 6, NULL);
+          dm_StrCopyOut2_A2W ((SQLCHAR *)ststr, (SQLWCHAR *)szSqlstate, 6, NULL);
           ((wchar_t*)szSqlstate)[len] = 0;
         }
     }
@@ -573,11 +576,11 @@ _iodbcdm_sqlerror (
       char msgbuf[256] = {'\0'};
 
       /* get sql state message */
-      errmsg = _iodbcdm_getsqlerrmsg (herr, (void FAR *) sqlerrmsg_tab);
+      errmsg = _iodbcdm_getsqlerrmsg (herr, (void *) sqlerrmsg_tab);
 
       if (errmsg == NULL)
 	{
-	  errmsg = (char FAR *) "";
+	  errmsg = (char *) "";
 	}
 
 #if defined(HAVE_SNPRINTF)
@@ -609,7 +612,7 @@ _iodbcdm_sqlerror (
       else
         {
           dm_StrCopyOut2_A2W ((SQLCHAR *) msgbuf, 
-	  	szErrorMsg, cbErrorMsgMax, pcbErrorMsg);
+	  	(SQLWCHAR *) szErrorMsg, cbErrorMsgMax, pcbErrorMsg);
         }
     }
 
@@ -641,11 +644,11 @@ SQLError (
   SQLHENV		  henv,
   SQLHDBC		  hdbc,
   SQLHSTMT		  hstmt,
-  SQLCHAR FAR		* szSqlstate,
-  SQLINTEGER FAR	* pfNativeError,
-  SQLCHAR FAR		* szErrorMsg,
+  SQLCHAR 		* szSqlstate,
+  SQLINTEGER 		* pfNativeError,
+  SQLCHAR 		* szErrorMsg,
   SQLSMALLINT		  cbErrorMsgMax,
-  SQLSMALLINT FAR	* pcbErrorMsg)
+  SQLSMALLINT 		* pcbErrorMsg)
 {
   SQLRETURN retcode = SQL_SUCCESS;
 
@@ -686,11 +689,11 @@ SQLErrorA (
   SQLHENV		  henv,
   SQLHDBC 		  hdbc,
   SQLHSTMT 		  hstmt,
-  SQLCHAR FAR		* szSqlstate,
-  SQLINTEGER FAR	* pfNativeError,
-  SQLCHAR FAR		* szErrorMsg,
+  SQLCHAR 		* szSqlstate,
+  SQLINTEGER 		* pfNativeError,
+  SQLCHAR 		* szErrorMsg,
   SQLSMALLINT		  cbErrorMsgMax,
-  SQLSMALLINT FAR	* pcbErrorMsg)
+  SQLSMALLINT 		* pcbErrorMsg)
 {
   SQLRETURN retcode = SQL_SUCCESS;
 
@@ -731,11 +734,11 @@ SQLErrorW (
   SQLHENV		  henv,
   SQLHDBC		  hdbc,
   SQLHSTMT		  hstmt,
-  SQLWCHAR FAR		* szSqlstate,
-  SQLINTEGER FAR	* pfNativeError,
-  SQLWCHAR FAR		* szErrorMsg,
+  SQLWCHAR 		* szSqlstate,
+  SQLINTEGER 		* pfNativeError,
+  SQLWCHAR 		* szErrorMsg,
   SQLSMALLINT		  cbErrorMsgMax,
-  SQLSMALLINT FAR	* pcbErrorMsg)
+  SQLSMALLINT 		* pcbErrorMsg)
 {
   SQLRETURN retcode = SQL_SUCCESS;
 
@@ -786,7 +789,7 @@ error_rec_count (HERR herr)
 static sqlerr_t *
 get_nth_error(HERR herr, int nIndex)
 {
-  sqlerr_t *err = herr;
+  sqlerr_t *err = (sqlerr_t *) herr;
   while (err && err->idx != nIndex)
       err = err->next;
   return err;
@@ -885,8 +888,8 @@ SQLGetDiagRec_Internal (
       if (Sqlstate != NULL)
 	{
 	  int len;
-	  char *ststr = (char FAR *) _iodbcdm_getsqlstate (curr_err,
-	      (void FAR *) sqlerrmsg_tab);
+	  char *ststr = (char *) _iodbcdm_getsqlstate (curr_err,
+	      (void *) sqlerrmsg_tab);
 
 	  if (ststr == NULL)
 	    {
@@ -908,7 +911,8 @@ SQLGetDiagRec_Internal (
             }
           else
             {
-              dm_StrCopyOut2_A2W ((SQLCHAR *) ststr, Sqlstate, 6, NULL);
+              dm_StrCopyOut2_A2W ((SQLCHAR *) ststr, 
+			(SQLWCHAR *) Sqlstate, 6, NULL);
               ((wchar_t*)Sqlstate)[len] = 0;
             }
 	}
@@ -928,11 +932,11 @@ SQLGetDiagRec_Internal (
 
 	  /* get sql state message */
 	  errmsg =
-	      _iodbcdm_getsqlerrmsg (curr_err, (void FAR *) sqlerrmsg_tab);
+	      _iodbcdm_getsqlerrmsg (curr_err, (void *) sqlerrmsg_tab);
 
 	  if (errmsg == NULL)
 	    {
-	      errmsg = (char FAR *) "";
+	      errmsg = (char *) "";
 	    }
 
 #if defined(HAVE_SNPRINTF)
@@ -964,7 +968,7 @@ SQLGetDiagRec_Internal (
           else
             {
               dm_StrCopyOut2_A2W ((SQLCHAR *) msgbuf, 
-		    MessageText, BufferLength, TextLengthPtr);
+		    (SQLWCHAR *) MessageText, BufferLength, TextLengthPtr);
             }
 	}
       return retcode;
@@ -977,9 +981,8 @@ SQLGetDiagRec_Internal (
 	}
       RecNumber -= nRecs;
 
-      if (((DBC_t FAR *)hdbc)->henv)
-        unicode_driver = 
-		((ENV_t FAR *) ((DBC_t FAR *)hdbc)->henv)->unicode_driver;
+      if (((DBC_t *)hdbc)->henv)
+        unicode_driver = ((ENV_t *) ((DBC_t *)hdbc)->henv)->unicode_driver;
 
       if ((unicode_driver && waMode != 'W') 
           || (!unicode_driver && waMode == 'W'))
@@ -1132,14 +1135,14 @@ SQLGetDiagRec_Internal (
           if (waMode != 'W')
             {
             /* ansi<=unicode*/
-              dm_StrCopyOut2_W2A (messageTextOut, MessageText, BufferLength, NULL);
-              dm_StrCopyOut2_W2A (SqlstateOut, Sqlstate, 6, NULL);
+              dm_StrCopyOut2_W2A ((SQLWCHAR *)messageTextOut, (SQLCHAR *)MessageText, BufferLength, NULL);
+              dm_StrCopyOut2_W2A ((SQLWCHAR *)SqlstateOut, (SQLCHAR *)Sqlstate, 6, NULL);
             }
           else
             {
             /* unicode<=ansi*/
-              dm_StrCopyOut2_A2W (messageTextOut, MessageText, BufferLength, NULL);
-              dm_StrCopyOut2_A2W ((SQLCHAR *) SqlstateOut, Sqlstate, 6, NULL);
+              dm_StrCopyOut2_A2W ((SQLCHAR *) messageTextOut, (SQLWCHAR *) MessageText, BufferLength, NULL);
+              dm_StrCopyOut2_A2W ((SQLCHAR *) SqlstateOut, (SQLWCHAR *) Sqlstate, 6, NULL);
             }
         }
     
@@ -1331,7 +1334,7 @@ SQLGetDiagField_Internal (
 	  return SQL_INVALID_HANDLE;
 	}
       err = con->herr;
-      genv = con->genv;
+      genv = (GENV_t *) con->genv;
       stmt = NULL;
       desc = NULL;
       dhandle = con->dhdbc;
@@ -1343,8 +1346,8 @@ SQLGetDiagField_Internal (
 	  return SQL_INVALID_HANDLE;
 	}
       err = stmt->herr;
-      con = stmt->hdbc;
-      genv = con->genv;
+      con = (DBC_t *) stmt->hdbc;
+      genv = (GENV_t *) con->genv;
       desc = NULL;
       dhandle = stmt->dhstmt;
       break;
@@ -1355,9 +1358,9 @@ SQLGetDiagField_Internal (
 	  return SQL_INVALID_HANDLE;
 	}
       err = desc->herr;
-      stmt = desc->hstmt;
-      con = desc->hdbc;
-      genv = con->genv;
+      stmt = (STMT_t *) desc->hstmt;
+      con = (DBC_t *) desc->hdbc;
+      genv = (GENV_t *) con->genv;
       dhandle = desc->dhdesc;
       break;
 
@@ -1365,8 +1368,8 @@ SQLGetDiagField_Internal (
       return SQL_INVALID_HANDLE;
     }
 
-  if (con != NULL)
-    unicode_driver = ((ENV_t FAR *) con->henv)->unicode_driver;
+  if (con != NULL && con->henv != SQL_NULL_HENV)
+    unicode_driver = ((ENV_t *) con->henv)->unicode_driver;
 
   switch (nRecNumber)
     {
@@ -1445,7 +1448,7 @@ SQLGetDiagField_Internal (
 	case SQL_DIAG_RETURNCODE:
 
 	  if (pDiagInfoPtr)
-	    *((SQLRETURN *) pDiagInfoPtr) = ((GENV_t FAR *) Handle)->rc;
+	    *((SQLRETURN *) pDiagInfoPtr) = ((GENV_t *) Handle)->rc;
 	  {
 	    return SQL_SUCCESS;
 	  }
@@ -1472,7 +1475,7 @@ SQLGetDiagField_Internal (
 		      (*(SQLINTEGER *) pDiagInfoPtr) += error_rec_count (err);
                     }
 		  else if (((ENV_t *) con->henv)->dodbc_ver == SQL_OV_ODBC2 &&
-		      ((GENV_t FAR *) Handle)->rc)
+		      ((GENV_t *) Handle)->rc)
 		    {		/* ODBC2 drivers can only have one error */
 		      (*(SQLINTEGER *) pDiagInfoPtr) = 1;
 		    }
@@ -1521,7 +1524,7 @@ SQLGetDiagField_Internal (
 		isInt = 0;
 
 		szval = (rec->code >= en_HY001
-		    && rec->code <= en_IM014) ? "ODBC 3.0" : "ISO 9075";
+		    && rec->code <= en_IM014) ? (char *) "ODBC 3.0" : (char *) "ISO 9075";
 		break;
 
 	      case SQL_DIAG_COLUMN_NUMBER:
@@ -1562,7 +1565,7 @@ SQLGetDiagField_Internal (
 
 		isInt = 0;
 		szval =
-		    _iodbcdm_getsqlerrmsg (rec, (void FAR *) sqlerrmsg_tab);
+		    _iodbcdm_getsqlerrmsg (rec, (void *) sqlerrmsg_tab);
 		break;
 
 	      case SQL_DIAG_NATIVE:
@@ -1598,7 +1601,7 @@ SQLGetDiagField_Internal (
 	      case SQL_DIAG_SQLSTATE:
 
 		isInt = 0;
-		szval = _iodbcdm_getsqlstate (rec, (void FAR *) sqlerrmsg_tab);
+		szval = _iodbcdm_getsqlstate (rec, (void *) sqlerrmsg_tab);
 		break;
 
 	      default:
@@ -1620,13 +1623,13 @@ SQLGetDiagField_Internal (
 		    if (pDiagInfoPtr)
 		      {
 		        STRNCPY (pDiagInfoPtr, szval, len1);
-		        *(((SQLCHAR FAR *) pDiagInfoPtr) + len1) = 0;
+		        *(((SQLCHAR *) pDiagInfoPtr) + len1) = 0;
 		      }
 		  }
 		else
 		  {
 		    dm_StrCopyOut2_A2W((SQLCHAR *) szval, 
-		    	pDiagInfoPtr, nBufferLength, pnStringLengthPtr);
+		    	(SQLWCHAR *) pDiagInfoPtr, nBufferLength, pnStringLengthPtr);
 		  }
 	      
 	      }
@@ -1697,14 +1700,16 @@ SQLGetDiagField_Internal (
                         if (waMode != 'W')
                           {
                           /* ansi<=unicode*/
-                            dm_StrCopyOut2_W2A (diagInfoPtr, pDiagInfoPtr, 
-                              nBufferLength, pnStringLengthPtr);
+                            dm_StrCopyOut2_W2A ((SQLWCHAR *) diagInfoPtr, 
+				(SQLCHAR *) pDiagInfoPtr, 
+				nBufferLength, pnStringLengthPtr);
                           }
                         else
                           {
                           /* unicode<=ansi*/
                             dm_StrCopyOut2_A2W ((SQLCHAR *)diagInfoPtr, 
-			    	pDiagInfoPtr, nBufferLength, pnStringLengthPtr);
+			    	(SQLWCHAR *) pDiagInfoPtr, 
+				nBufferLength, pnStringLengthPtr);
                           }
                       }
                   }
@@ -1753,14 +1758,14 @@ SQLGetDiagField_Internal (
 		      }
 		    if (waMode != 'W')
                       {
-		        szval = !STRNEQ (szState, "IM", 2) ? "ODBC 3.0" : "ISO 9075";
+		        szval = !STRNEQ (szState, "IM", 2) ? (char *) "ODBC 3.0" : (char *) "ISO 9075";
                       }
 		    else
                       {
                         if (szState[0] != L'I' && szState[1] != L'M')
-		          szval = "ODBC 3.0";
+		          szval = (char *) "ODBC 3.0";
                         else
-		          szval = "ISO 9075";
+		          szval = (char *) "ISO 9075";
                       }
 		    break;
 
@@ -1806,14 +1811,16 @@ SQLGetDiagField_Internal (
                         if (waMode != 'W')
                           {
                           /* ansi<=unicode*/
-                            dm_StrCopyOut2_W2A (diagInfoPtr, pDiagInfoPtr, 
-                              nBufferLength, pnStringLengthPtr);
+                            dm_StrCopyOut2_W2A ((SQLWCHAR *) diagInfoPtr, 
+				(SQLCHAR *) pDiagInfoPtr, 
+		      		nBufferLength, pnStringLengthPtr);
                           }
                         else
                           {
                           /* unicode<=ansi*/
                             dm_StrCopyOut2_A2W ((SQLCHAR *)diagInfoPtr, 
-			    	pDiagInfoPtr, nBufferLength, pnStringLengthPtr);
+			    	(SQLWCHAR *) pDiagInfoPtr, 
+				nBufferLength, pnStringLengthPtr);
                           }
                       }
 
@@ -1853,14 +1860,16 @@ SQLGetDiagField_Internal (
                         if (waMode != 'W')
                           {
                           /* ansi<=unicode*/
-                            dm_StrCopyOut2_W2A (szState, pDiagInfoPtr, 
-                              nBufferLength, pnStringLengthPtr);
+                            dm_StrCopyOut2_W2A ((SQLWCHAR *) szState, 
+				(SQLCHAR *) pDiagInfoPtr, 
+		      		nBufferLength, pnStringLengthPtr);
                           }
                         else
                           {
                           /* unicode<=ansi*/
                             dm_StrCopyOut2_A2W ((SQLCHAR *)szState, 
-			    	pDiagInfoPtr, nBufferLength, pnStringLengthPtr);
+			    	(SQLWCHAR *) pDiagInfoPtr, 
+				nBufferLength, pnStringLengthPtr);
                           }
                       }
 
@@ -1878,7 +1887,7 @@ SQLGetDiagField_Internal (
 		        if (len > nBufferLength)
 		          len = nBufferLength;
 		        if (len)
-		          strncpy (pDiagInfoPtr, szval, len);
+		          strncpy ((char *) pDiagInfoPtr, szval, len);
 		      }
 		    if (pnStringLengthPtr)
 		      *pnStringLengthPtr = strlen (szval);
@@ -1886,7 +1895,8 @@ SQLGetDiagField_Internal (
 		else
 		  {
 		    dm_StrCopyOut2_A2W((SQLCHAR *) szval, 
-		    	pDiagInfoPtr, nBufferLength, pnStringLengthPtr);
+		    	(SQLWCHAR *) pDiagInfoPtr, 
+			nBufferLength, pnStringLengthPtr);
 		  }
 	      }			/* ODBC3->ODBC2 */
 	  }			/* driver's errors */
