@@ -1,7 +1,7 @@
 /*
  *  herr.h
  *
- *  $Id: herr.h,v 1.8 2003/09/03 08:44:47 source Exp $
+ *  $Id: herr.h,v 1.10 2004/06/21 13:34:28 source Exp $
  *
  *  Error stack management functions
  *
@@ -179,14 +179,14 @@ typedef enum
   }
 sqlstcode_t;
 
-typedef void FAR *HERR;
+typedef void *HERR;
 #define SQL_NULL_HERR	((HERR)NULL)
 
 typedef struct
   {
     sqlstcode_t code;
-    char FAR *stat;
-    char FAR *msg;
+    char *stat;
+    char *msg;
   }
 sqlerrmsg_t;
 
@@ -194,7 +194,7 @@ typedef struct sqlerr
   {
     sqlstcode_t code;
     int idx;
-    char FAR *msg;
+    char *msg;
     struct sqlerr *next;
   }
 sqlerr_t;
@@ -203,7 +203,7 @@ extern void _iodbcdm_freesqlerrlist (HERR herr);
 extern HERR _iodbcdm_pushsqlerr (HERR list, sqlstcode_t code, void *sysmsg);
 
 #define	PUSHSYSERR(list, msg)	\
-	list = (HERR) _iodbcdm_pushsqlerr ((HERR)(list), 0, msg)
+	list = (HERR) _iodbcdm_pushsqlerr ((HERR)(list), en_00000, msg)
 
 #define	PUSHSQLERR(list, code)	\
 	list = (HERR) _iodbcdm_pushsqlerr ((HERR)(list), (code), NULL)
