@@ -1,7 +1,7 @@
 /*
  *  hstmt.c
  *
- *  $Id: hstmt.c,v 1.20 2004/02/19 11:24:46 source Exp $
+ *  $Id: hstmt.c,v 1.23 2004/07/06 15:26:07 source Exp $
  *
  *  Query statement object management functions
  *
@@ -104,10 +104,10 @@ static const SQLINTEGER desc_attrs[4] =
 SQLRETURN
 SQLAllocStmt_Internal (
     SQLHDBC hdbc,
-    SQLHSTMT FAR * phstmt)
+    SQLHSTMT * phstmt)
 {
   CONN (pdbc, hdbc);
-  STMT_t FAR *pstmt = NULL;
+  STMT (pstmt, NULL);
   HPROC hproc = SQL_NULL_HPROC;
   SQLRETURN retcode = SQL_SUCCESS;
   int i;
@@ -136,7 +136,7 @@ SQLAllocStmt_Internal (
       return SQL_INVALID_HANDLE;
     }
 
-  pstmt = (STMT_t FAR *) MEM_ALLOC (sizeof (STMT_t));
+  pstmt = (STMT_t *) MEM_ALLOC (sizeof (STMT_t));
 
   if (pstmt == NULL)
     {
@@ -176,8 +176,8 @@ SQLAllocStmt_Internal (
   pstmt->params_processed_ptr = NULL;
   pstmt->paramset_size = 0;
   pstmt->rows_fetched_ptr = NULL;
-  if (((ENV_t FAR *) ((DBC_t FAR *) pstmt->hdbc)->henv)->dodbc_ver == SQL_OV_ODBC2 && 
-     ((GENV_t FAR *) ((DBC_t FAR *) pstmt->hdbc)->genv)->odbc_ver == SQL_OV_ODBC3)
+  if (((ENV_t *) ((DBC_t *) pstmt->hdbc)->henv)->dodbc_ver == SQL_OV_ODBC2 && 
+     ((GENV_t *) ((DBC_t *) pstmt->hdbc)->genv)->odbc_ver == SQL_OV_ODBC3)
     {				/* if it's a odbc3 app calling odbc2 driver */
       pstmt->row_status_ptr =
 	  MEM_ALLOC (sizeof (SQLUINTEGER) * pstmt->row_array_size);
@@ -245,7 +245,7 @@ SQLAllocStmt_Internal (
        */
       for (i = 0; i < 4; i++)
 	{
-	  pstmt->imp_desc[i] = (DESC_t FAR *) MEM_ALLOC (sizeof (DESC_t));
+	  pstmt->imp_desc[i] = (DESC_t *) MEM_ALLOC (sizeof (DESC_t));
 	  if (pstmt->imp_desc[i] == NULL)
 	    {
 	      PUSHSQLERR (pdbc->herr, en_HY001);
@@ -297,7 +297,7 @@ SQLAllocStmt_Internal (
 		  break;
 		}
 
-	      pstmt->imp_desc[i] = (DESC_t FAR *) MEM_ALLOC (sizeof (DESC_t));
+	      pstmt->imp_desc[i] = (DESC_t *) MEM_ALLOC (sizeof (DESC_t));
 	      if (pstmt->imp_desc[i] == NULL)
 		{		/* memory allocation error */
 		  PUSHSQLERR (pdbc->herr, en_HY001);
@@ -324,7 +324,7 @@ SQLAllocStmt_Internal (
 #endif
 
   /* insert into list */
-  pstmt->next = pdbc->hstmt;
+  pstmt->next = (STMT_t *) pdbc->hstmt;
   pdbc->hstmt = pstmt;
 
   *phstmt = (SQLHSTMT) pstmt;
@@ -386,7 +386,7 @@ alloc_stmt_failed:
 SQLRETURN SQL_API 
 SQLAllocStmt (
     SQLHDBC hdbc,
-    SQLHSTMT FAR * phstmt)
+    SQLHSTMT * phstmt)
 {
   ENTER_HDBC (hdbc, 1,
     trace_SQLAllocStmt (TRACE_ENTER, hdbc, phstmt));
@@ -402,8 +402,8 @@ SQLRETURN
 _iodbcdm_dropstmt (HSTMT hstmt)
 {
   STMT (pstmt, hstmt);
-  STMT_t FAR *tpstmt;
-  DBC_t FAR *pdbc;
+  STMT (tpstmt, NULL);
+  CONN (pdbc, NULL);
 
   if (!IS_VALID_HSTMT (pstmt))
     {
@@ -411,9 +411,9 @@ _iodbcdm_dropstmt (HSTMT hstmt)
     }
   CLEAR_ERRORS (pstmt);
 
-  pdbc = (DBC_t FAR *) (pstmt->hdbc);
+  pdbc = (DBC_t *) (pstmt->hdbc);
 
-  for (tpstmt = (STMT_t FAR *) pdbc->hstmt;
+  for (tpstmt = (STMT_t *) pdbc->hstmt;
       tpstmt != NULL;
       tpstmt = tpstmt->next)
     {
@@ -472,12 +472,12 @@ SQLFreeStmt_Internal (
     SQLUSMALLINT fOption)
 {
   STMT (pstmt, hstmt);
-  DBC_t FAR *pdbc;
+  CONN (pdbc, NULL);
 
   HPROC hproc = SQL_NULL_HPROC;
   SQLRETURN retcode = SQL_SUCCESS;
 
-  pdbc = (DBC_t FAR *) (pstmt->hdbc);
+  pdbc = (DBC_t *) (pstmt->hdbc);
 
   /* check option */
   switch (fOption)
@@ -616,7 +616,7 @@ SQLSetStmtOption_Internal (
 {
   STMT (pstmt, hstmt);
   HPROC hproc;
-  int sqlstat = en_00000;
+  sqlstcode_t sqlstat = en_00000;
   SQLRETURN retcode;
 
 #if (ODBCVER < 0x0300)
@@ -788,9 +788,9 @@ SQLSetStmtOption_Internal (
 
 SQLRETURN SQL_API 
 SQLSetStmtOption (
-    SQLHSTMT hstmt,
-    SQLUSMALLINT fOption,
-    SQLUINTEGER vParam)
+  SQLHSTMT		  hstmt,
+  SQLUSMALLINT		  fOption,
+  SQLULEN		  vParam)
 {
   ENTER_STMT (hstmt,
     trace_SQLSetStmtOption (TRACE_ENTER, hstmt, fOption, vParam));
@@ -804,9 +804,9 @@ SQLSetStmtOption (
 
 SQLRETURN SQL_API 
 SQLSetStmtOptionA (
-    SQLHSTMT hstmt,
-    SQLUSMALLINT fOption,
-    SQLUINTEGER vParam)
+  SQLHSTMT		  hstmt,
+  SQLUSMALLINT		  fOption,
+  SQLULEN		  vParam)
 {
   ENTER_STMT (hstmt,
     trace_SQLSetStmtOption (TRACE_ENTER, hstmt, fOption, vParam));
@@ -826,7 +826,7 @@ SQLGetStmtOption_Internal (
 {
   STMT (pstmt, hstmt);
   HPROC hproc;
-  int sqlstat = en_00000;
+  sqlstcode_t sqlstat = en_00000;
   SQLRETURN retcode;
 
 #if (ODBCVER < 0x0300)
@@ -1136,10 +1136,10 @@ _iodbcdm_alloc_param(STMT_t *pstmt, int i, int size)
 
 
 wchar_t *
-_iodbcdm_conv_param_A2W(STMT_t *pstmt, int i, char *pData, int pDataLength)
+_iodbcdm_conv_param_A2W(STMT_t *pstmt, int i, SQLCHAR *pData, int pDataLength)
 {
   PARAM_t *param;
-  int size = 0;
+  size_t size = 0;
   int count_alloc = 0;
 
   if (i > STMT_PARAMS_MAX - 1)
@@ -1157,7 +1157,7 @@ _iodbcdm_conv_param_A2W(STMT_t *pstmt, int i, char *pData, int pDataLength)
     }
 
   if (pDataLength == SQL_NTS)
-    size = strlen(pData);
+    size = strlen((char *) pData);
   else
     size = pDataLength;
 
@@ -1182,15 +1182,15 @@ _iodbcdm_conv_param_A2W(STMT_t *pstmt, int i, char *pData, int pDataLength)
         }      
     }
 
-  return param->data;
+  return (wchar_t *) param->data;
 }
 
 
 char *
-_iodbcdm_conv_param_W2A(STMT_t *pstmt, int i, wchar_t *pData, int pDataLength)
+_iodbcdm_conv_param_W2A(STMT_t *pstmt, int i, SQLWCHAR *pData, int pDataLength)
 {
   PARAM_t *param;
-  int size = 0;
+  size_t size = 0;
   int count_alloc = 0;
 
   if (i > STMT_PARAMS_MAX - 1)
@@ -1233,7 +1233,7 @@ _iodbcdm_conv_param_W2A(STMT_t *pstmt, int i, wchar_t *pData, int pDataLength)
         }      
     }
 
-  return param->data;
+  return (char *) param->data;
 }
 
 
@@ -1246,7 +1246,7 @@ _iodbcdm_BindColumn (STMT_t *pstmt, BIND_t *pbind)
   /*
    *  Initialize the cell
    */
-  if ((pblst = calloc (1, sizeof (TBLST))) == NULL)
+  if ((pblst = (PBLST) calloc (1, sizeof (TBLST))) == NULL)
     {
       return SQL_ERROR;
     }
@@ -1335,10 +1335,12 @@ _iodbcdm_RemoveBind (STMT_t *pstmt)
 
 
 static void 
-_iodbcdm_bindConv_A2W(char *data, SDWORD *pInd, UDWORD size)
+_iodbcdm_bindConv_A2W(char *data, SQLLEN *pInd, UDWORD size)
 {
   wchar_t *wdata = (wchar_t *) data;
 
+  size=size; /*UNUSED*/
+
   if (*pInd != SQL_NULL_DATA)
     {
       wchar_t *buf = dm_SQL_A2W ((SQLCHAR *) data, SQL_NTS);
@@ -1360,7 +1362,7 @@ _iodbcdm_ConvBindData (STMT_t *pstmt)
   PBLST ptr;
   BIND_t *col;
   UDWORD i, size, row_size;
-  SDWORD  *pInd;
+  SQLLEN *pInd;
   char *data;
 
   /*
@@ -1376,7 +1378,7 @@ _iodbcdm_ConvBindData (STMT_t *pstmt)
       if (pstmt->bind_type == SQL_BIND_BY_COLUMN)
         {
           size = col->bn_size;
-          data = col->bn_data;
+          data = (char *) col->bn_data;
           pInd = col->bn_pInd;
           for (i = 0; i < pstmt->rowset_size; i++)
             {
@@ -1389,7 +1391,7 @@ _iodbcdm_ConvBindData (STMT_t *pstmt)
         {
           row_size = pstmt->bind_type;
           size = col->bn_size;
-          data = col->bn_data;
+          data = (char *) col->bn_data;
           pInd = col->bn_pInd;
           for (i = 0; i < pstmt->rowset_size; i++)
             {
