@@ -1,7 +1,7 @@
 /*
  *  info.c
  *
- *  $Id: info.c,v 1.26 2004/02/18 15:58:59 source Exp $
+ *  $Id: info.c,v 1.29 2004/08/16 11:04:05 source Exp $
  *
  *  Information functions
  *
@@ -122,8 +122,8 @@ stricmp (const char *s1, const char *s2)
 static int
 SectSorter (const void *p1, const void *p2)
 {
-  char **s1 = (char **) p1;
-  char **s2 = (char **) p2;
+  const char **s1 = (const char **) p1;
+  const char **s2 = (const char **) p2;
 
   return stricmp (*s1, *s2);
 }
@@ -135,10 +135,10 @@ SQLDataSources_Internal (
   SQLUSMALLINT		  fDir,
   SQLPOINTER		  szDSN,
   SQLSMALLINT		  cbDSNMax,
-  SQLSMALLINT FAR	* pcbDSN,
+  SQLSMALLINT 		* pcbDSN,
   SQLPOINTER		  szDesc,
   SQLSMALLINT		  cbDescMax,
-  SQLSMALLINT FAR	* pcbDesc,
+  SQLSMALLINT 		* pcbDesc,
   SQLCHAR		  waMode)
 {
   GENV (genv, henv);
@@ -149,6 +149,8 @@ SQLDataSources_Internal (
   static void **sect = NULL;
   SQLUSMALLINT fDirOld = fDir;
 
+  waMode = waMode; /*UNUSED*/
+
   /* check argument */
   if (cbDSNMax < 0 || cbDescMax < 0)
     {
@@ -284,12 +286,12 @@ SQLRETURN SQL_API
 SQLDataSources (
   SQLHENV		  henv,
   SQLUSMALLINT		  fDir,
-  SQLCHAR FAR		* szDSN,
+  SQLCHAR 		* szDSN,
   SQLSMALLINT		  cbDSNMax,
-  SQLSMALLINT FAR	* pcbDSN,
-  SQLCHAR FAR		* szDesc,
+  SQLSMALLINT 		* pcbDSN,
+  SQLCHAR 		* szDesc,
   SQLSMALLINT		  cbDescMax,
-  SQLSMALLINT FAR 	* pcbDesc)
+  SQLSMALLINT 		* pcbDesc)
 {
   ENTER_HENV (henv,
     trace_SQLDataSources (TRACE_ENTER,
@@ -318,12 +320,12 @@ SQLRETURN SQL_API
 SQLDataSourcesA (
   SQLHENV		  henv,
   SQLUSMALLINT		  fDir,
-  SQLCHAR FAR		* szDSN,
+  SQLCHAR 		* szDSN,
   SQLSMALLINT		  cbDSNMax,
-  SQLSMALLINT FAR	* pcbDSN,
-  SQLCHAR FAR		* szDesc,
+  SQLSMALLINT 		* pcbDSN,
+  SQLCHAR 		* szDesc,
   SQLSMALLINT		  cbDescMax,
-  SQLSMALLINT FAR 	* pcbDesc)
+  SQLSMALLINT		* pcbDesc)
 {
   ENTER_HENV (henv,
     trace_SQLDataSources (TRACE_ENTER,
@@ -352,12 +354,12 @@ SQLRETURN SQL_API
 SQLDataSourcesW (
   SQLHENV		  henv,
   SQLUSMALLINT		  fDir,
-  SQLWCHAR FAR		* szDSN,
+  SQLWCHAR 		* szDSN,
   SQLSMALLINT		  cbDSNMax,
-  SQLSMALLINT FAR	* pcbDSN,
-  SQLWCHAR FAR		* szDesc,
+  SQLSMALLINT 		* pcbDSN,
+  SQLWCHAR 		* szDesc,
   SQLSMALLINT		  cbDescMax,
-  SQLSMALLINT FAR	* pcbDesc)
+  SQLSMALLINT 		* pcbDesc)
 {
   SQLCHAR *_DSN = NULL;  
   SQLCHAR *_Desc = NULL;
@@ -371,7 +373,7 @@ SQLDataSourcesW (
 
   if (cbDSNMax > 0)
     {
-      if ((_DSN = malloc (cbDSNMax * UTF8_MAX_CHAR_LEN + 1)) == NULL)
+      if ((_DSN = (SQLCHAR *) malloc (cbDSNMax * UTF8_MAX_CHAR_LEN + 1)) == NULL)
 	{
 	  PUSHSQLERR (genv->herr, en_S1001);
 	  return SQL_ERROR;
@@ -380,7 +382,7 @@ SQLDataSourcesW (
 
   if (cbDescMax > 0)
     {
-      if ((_Desc = malloc (cbDescMax * UTF8_MAX_CHAR_LEN + 1)) == NULL)
+      if ((_Desc = (SQLCHAR *) malloc (cbDescMax * UTF8_MAX_CHAR_LEN + 1)) == NULL)
 	{
 	  PUSHSQLERR (genv->herr, en_S1001);
 	  return SQL_ERROR;
@@ -418,10 +420,10 @@ SQLDrivers_Internal (
   SQLUSMALLINT		  fDir,
   SQLPOINTER		  szDrvDesc,
   SQLSMALLINT		  cbDrvDescMax,
-  SQLSMALLINT FAR	* pcbDrvDesc,
+  SQLSMALLINT 		* pcbDrvDesc,
   SQLPOINTER		  szDrvAttr,
   SQLSMALLINT		  cbDrvAttrMax,
-  SQLSMALLINT FAR	* pcbDrvAttr,
+  SQLSMALLINT 		* pcbDrvAttr,
   SQLCHAR		  waMode)
 {
   GENV (genv, henv);
@@ -432,6 +434,8 @@ SQLDrivers_Internal (
   static void **sect = NULL;
   SQLUSMALLINT fDirOld = fDir;
 
+  waMode = waMode; /*UNUSED*/
+
   /* check argument */
   if (cbDrvDescMax < 0 || cbDrvAttrMax < 0)
     {
@@ -569,12 +573,12 @@ SQLRETURN SQL_API
 SQLDrivers (
   SQLHENV		  henv,
   SQLUSMALLINT		  fDir,
-  SQLCHAR FAR		* szDrvDesc,
+  SQLCHAR 		* szDrvDesc,
   SQLSMALLINT		  cbDrvDescMax,
-  SQLSMALLINT FAR	* pcbDrvDesc,
-  SQLCHAR FAR		* szDrvAttr,
+  SQLSMALLINT 		* pcbDrvDesc,
+  SQLCHAR 		* szDrvAttr,
   SQLSMALLINT		  cbDrvAttrMax,
-  SQLSMALLINT FAR	* pcbDrvAttr)
+  SQLSMALLINT 		* pcbDrvAttr)
 {
   ENTER_HENV (henv,
     trace_SQLDrivers (TRACE_ENTER,
@@ -603,12 +607,12 @@ SQLRETURN SQL_API
 SQLDriversA (
   SQLHENV		  henv,
   SQLUSMALLINT		  fDir,
-  SQLCHAR FAR 		* szDrvDesc,
+  SQLCHAR  		* szDrvDesc,
   SQLSMALLINT		  cbDrvDescMax,
-  SQLSMALLINT FAR 	* pcbDrvDesc,
-  SQLCHAR FAR 		* szDrvAttr,
+  SQLSMALLINT 	 	* pcbDrvDesc,
+  SQLCHAR  		* szDrvAttr,
   SQLSMALLINT		  cbDrvAttrMax,
-  SQLSMALLINT FAR 	* pcbDrvAttr)
+  SQLSMALLINT 	 	* pcbDrvAttr)
 {
   ENTER_HENV (henv,
     trace_SQLDrivers (TRACE_ENTER,
@@ -635,13 +639,13 @@ SQLDriversA (
 
 SQLRETURN SQL_API
 SQLDriversW (SQLHENV henv,
-    SQLUSMALLINT fDir,
-    SQLWCHAR FAR * szDrvDesc,
-    SQLSMALLINT cbDrvDescMax,
-    SQLSMALLINT FAR * pcbDrvDesc,
-    SQLWCHAR FAR * szDrvAttr,
-    SQLSMALLINT cbDrvAttrMax,
-    SQLSMALLINT FAR * pcbDrvAttr)
+    SQLUSMALLINT 	  fDir,
+    SQLWCHAR		* szDrvDesc,
+    SQLSMALLINT		  cbDrvDescMax,
+    SQLSMALLINT		* pcbDrvDesc,
+    SQLWCHAR		* szDrvAttr,
+    SQLSMALLINT		  cbDrvAttrMax,
+    SQLSMALLINT		* pcbDrvAttr)
 {
   SQLCHAR *_Driver = NULL;  
   SQLCHAR *_Attrs = NULL;
@@ -655,7 +659,7 @@ SQLDriversW (SQLHENV henv,
 
   if (cbDrvDescMax > 0)
     {
-      if ((_Driver = malloc (cbDrvDescMax * UTF8_MAX_CHAR_LEN + 1)) == NULL)
+      if ((_Driver = (SQLCHAR *) malloc (cbDrvDescMax * UTF8_MAX_CHAR_LEN + 1)) == NULL)
 	{
 	  PUSHSQLERR (genv->herr, en_S1001);
 	  return SQL_ERROR;
@@ -664,7 +668,7 @@ SQLDriversW (SQLHENV henv,
 
   if (cbDrvAttrMax > 0)
     {
-      if ((_Attrs = malloc (cbDrvAttrMax * UTF8_MAX_CHAR_LEN + 1)) == NULL)
+      if ((_Attrs = (SQLCHAR *) malloc (cbDrvAttrMax * UTF8_MAX_CHAR_LEN + 1)) == NULL)
 	{
 	  PUSHSQLERR (genv->herr, en_S1001);
 	  return SQL_ERROR;
@@ -698,17 +702,17 @@ SQLDriversW (SQLHENV henv,
 
 SQLRETURN SQL_API
 SQLGetInfo_Internal (
-    SQLHDBC hdbc,
-    SQLUSMALLINT fInfoType,
-    SQLPOINTER rgbInfoValue,
-    SQLSMALLINT cbInfoValueMax,
-    SQLSMALLINT FAR * pcbInfoValue,
-    SQLCHAR waMode)
+    SQLHDBC		  hdbc,
+    SQLUSMALLINT	  fInfoType,
+    SQLPOINTER		  rgbInfoValue,
+    SQLSMALLINT		  cbInfoValueMax,
+    SQLSMALLINT		* pcbInfoValue,
+    SQLCHAR		  waMode)
 {
   CONN (pdbc, hdbc);
-  ENV_t FAR *penv = pdbc->henv;
-  STMT_t FAR *pstmt = NULL;
-  STMT_t FAR *tpstmt;
+  ENVR (penv, pdbc->henv);
+  STMT (pstmt, NULL);
+  STMT (tpstmt, NULL);
   HPROC hproc = SQL_NULL_HPROC;
   SQLRETURN retcode = SQL_SUCCESS;
   void * _InfoValue = NULL;
@@ -774,12 +778,12 @@ SQLGetInfo_Internal (
 	  if (waMode != 'W')
 	    {
 	      STRNCPY (rgbInfoValue, buf, len);
-	      ((char FAR *) rgbInfoValue)[len] = '\0';
+	      ((char *) rgbInfoValue)[len] = '\0';
 	    }
 	  else
 	    {
 	      WCSNCPY (rgbInfoValue, buf, len);
-	      ((wchar_t FAR *) rgbInfoValue)[len] = L'\0';
+	      ((wchar_t *) rgbInfoValue)[len] = L'\0';
 	    }
 	}
 
@@ -806,13 +810,13 @@ SQLGetInfo_Internal (
       break;
 
     case SQL_DRIVER_HENV:
-      penv = (ENV_t FAR *) (pdbc->henv);
+      penv = (ENV_t *) (pdbc->henv);
       dword = (DWORD) (penv->dhenv);
       size = sizeof (dword);
       break;
 
     case SQL_DRIVER_HLIB:
-      penv = (ENV_t FAR *) (pdbc->henv);
+      penv = (ENV_t *) (pdbc->henv);
       dword = (DWORD) (penv->hdll);
       size = sizeof (dword);
       break;
@@ -820,10 +824,10 @@ SQLGetInfo_Internal (
     case SQL_DRIVER_HSTMT:
       if (rgbInfoValue != NULL)
 	{
-	  pstmt = *((STMT_t FAR **) rgbInfoValue);
+	  pstmt = *((STMT_t **) rgbInfoValue);
 	}
 
-      for (tpstmt = (STMT_t FAR *) (pdbc->hstmt);
+      for (tpstmt = (STMT_t *) (pdbc->hstmt);
 	  tpstmt != NULL;
 	  tpstmt = tpstmt->next)
 	{
@@ -878,7 +882,7 @@ SQLGetInfo_Internal (
   /*
    *  This was a temp value in ODBC 2
    */
-  if (((ENV_t FAR *) pdbc->henv)->dodbc_ver == SQL_OV_ODBC2 && 
+  if (((ENV_t *) pdbc->henv)->dodbc_ver == SQL_OV_ODBC2 && 
 	  fInfoType == SQL_OJ_CAPABILITIES)
       fInfoType = 65003;
 #endif /* ODBCVER >= 0x0300 */
@@ -982,7 +986,7 @@ SQLGetInfo_Internal (
                 }
 
 	      STRNCPY (rgbInfoValue, buf, len);
-	      ((char FAR *) rgbInfoValue)[len] = '\0';
+	      ((char *) rgbInfoValue)[len] = '\0';
 	    }
 
           if (pcbInfoValue != NULL)
@@ -990,8 +994,9 @@ SQLGetInfo_Internal (
         }
       else
         {
-          ret = dm_StrCopyOut2_A2W ((SQLCHAR *) "01.00", rgbInfoValue, 
-            cbInfoValueMax / sizeof(wchar_t), pcbInfoValue);
+          ret = dm_StrCopyOut2_A2W ((SQLCHAR *) "01.00",  
+		(SQLWCHAR *) rgbInfoValue, 
+    		cbInfoValueMax / sizeof(wchar_t), pcbInfoValue);
           if (pcbInfoValue)
             *pcbInfoValue = *pcbInfoValue * sizeof(wchar_t);
         }
@@ -1055,14 +1060,16 @@ SQLGetInfo_Internal (
           if (waMode != 'W')
             {
             /* ansi<=unicode*/
-              ret = dm_StrCopyOut2_W2A (infoValueOut, rgbInfoValue, 
+              ret = dm_StrCopyOut2_W2A ((SQLWCHAR *) infoValueOut, 
+		(SQLCHAR *) rgbInfoValue, 
                 cbInfoValueMax / sizeof(wchar_t), pcbInfoValue);
             }
           else
             {
             /* unicode<=ansi*/
-              ret = dm_StrCopyOut2_A2W (infoValueOut, rgbInfoValue, cbInfoValueMax, 
-                pcbInfoValue);
+              ret = dm_StrCopyOut2_A2W ((SQLCHAR *) infoValueOut, 
+		(SQLWCHAR *) rgbInfoValue, 
+		cbInfoValueMax, pcbInfoValue);
               if (pcbInfoValue)
                 *pcbInfoValue = *pcbInfoValue * sizeof(wchar_t);
             }
@@ -1086,7 +1093,7 @@ SQLGetInfo (SQLHDBC hdbc,
   SQLUSMALLINT		  fInfoType,
   SQLPOINTER		  rgbInfoValue,
   SQLSMALLINT		  cbInfoValueMax,
-  SQLSMALLINT FAR	* pcbInfoValue)
+  SQLSMALLINT 		* pcbInfoValue)
 {
   ENTER_HDBC (hdbc, 0,
     trace_SQLGetInfo (TRACE_ENTER,
@@ -1113,7 +1120,7 @@ SQLGetInfoA (SQLHDBC hdbc,
   SQLUSMALLINT		  fInfoType,
   SQLPOINTER		  rgbInfoValue,
   SQLSMALLINT		  cbInfoValueMax,
-  SQLSMALLINT FAR	* pcbInfoValue)
+  SQLSMALLINT 		* pcbInfoValue)
 {
   ENTER_HDBC (hdbc, 0,
     trace_SQLGetInfo (TRACE_ENTER,
@@ -1141,7 +1148,7 @@ SQLGetInfoW (
   SQLUSMALLINT		  fInfoType,
   SQLPOINTER		  rgbInfoValue,
   SQLSMALLINT		  cbInfoValueMax,
-  SQLSMALLINT FAR	* pcbInfoValue)
+  SQLSMALLINT 		* pcbInfoValue)
 {
   ENTER_HDBC (hdbc, 0,
     trace_SQLGetInfoW (TRACE_ENTER,
@@ -1186,7 +1193,7 @@ static SQLRETURN
 SQLGetFunctions_Internal (
   SQLHDBC		  hdbc,
   SQLUSMALLINT		  fFunc,
-  SQLUSMALLINT FAR	* pfExists)
+  SQLUSMALLINT		* pfExists)
 {
   CONN (pdbc, hdbc);
   HPROC hproc;
@@ -1242,7 +1249,7 @@ SQLGetFunctions_Internal (
    *  mapped by the driver manager.
    */
 #if (ODBCVER >= 0x0300)
-  if (((ENV_t FAR *) pdbc->henv)->dodbc_ver == SQL_OV_ODBC2)
+  if (((ENV_t *) pdbc->henv)->dodbc_ver == SQL_OV_ODBC2)
     {
       switch (fFunc)
 	{
@@ -1362,7 +1369,7 @@ SQLRETURN SQL_API
 SQLGetFunctions (
   SQLHDBC		  hdbc,
   SQLUSMALLINT		  fFunc,
-  SQLUSMALLINT FAR	* pfExists)
+  SQLUSMALLINT	 	* pfExists)
 {
   ENTER_HDBC (hdbc, 0,
     trace_SQLGetFunctions (TRACE_ENTER,
@@ -1376,7 +1383,7 @@ SQLGetFunctions (
 	pfExists);
 
   LEAVE_HDBC (hdbc, 0,
-    trace_SQLGetFunctions (TRACE_ENTER,
+    trace_SQLGetFunctions (TRACE_LEAVE,
     	hdbc,
 	fFunc,
 	pfExists));
