@@ -2,7 +2,7 @@
 #
 #  install_libodbc.sh
 #
-#  $Id: install_libodbc.sh,v 1.4 2004/07/07 21:55:21 source Exp $
+#  $Id: install_libodbc.sh,v 1.5 2004/12/15 14:38:21 source Exp $
 #
 #  The iODBC driver manager.
 #  
@@ -82,14 +82,14 @@ then
   exit 1
 fi
 
-if test ! -d "$PREFIX/lib"
+if test ! -d "$PREFIX"
 then
-   echo "**ERROR: installation directory [$PREFIX/lib] does not exist"
+   echo "**ERROR: installation directory [$PREFIX] does not exist"
    exit 1
 fi
 
 
-cd "$PREFIX"/lib
+cd "$PREFIX"
 
 
 #
