@@ -1,7 +1,7 @@
 /*
  *  odbc3.c
  *
- *  $Id: odbc3.c,v 1.19 2004/07/06 15:34:07 source Exp $
+ *  $Id: odbc3.c,v 1.22 2005/02/01 14:48:30 source Exp $
  *
  *  ODBC 3.x functions
  *
@@ -219,6 +219,13 @@ SQLAllocHandle (
 
   if (handleType == SQL_HANDLE_ENV)
     {
+      /* 
+       *  One time initialization
+       */
+      Init_iODBC();
+
+      ODBC_LOCK ();
+
       retcode = SQLAllocEnv_Internal (outputHandlePtr, 0);
 
       /*
@@ -230,6 +237,7 @@ SQLAllocHandle (
       TRACE (trace_SQLAllocHandle (TRACE_LEAVE,
 	    handleType, inputHandle, outputHandlePtr));
 
+      ODBC_UNLOCK ();
 
       return retcode;
     }
@@ -261,6 +269,13 @@ SQLAllocHandleStd (
 
   if (handleType == SQL_HANDLE_ENV)
     {
+      /* 
+       *  One time initialization
+       */
+      Init_iODBC();
+
+      ODBC_LOCK ();
+
       retcode = SQLAllocEnv_Internal (outputHandlePtr, SQL_OV_ODBC3);
 
       /*
@@ -272,6 +287,7 @@ SQLAllocHandleStd (
       TRACE (trace_SQLAllocHandle (TRACE_LEAVE,
 	    handleType, inputHandle, outputHandlePtr));
 
+      ODBC_UNLOCK ();
 
       return retcode;
     }
@@ -295,22 +311,37 @@ SQLAllocHandleStd (
 
 /**** SQLFreeHandle ****/
 
+extern unsigned long _iodbc_env_counter;
+
 static RETCODE
 _SQLFreeHandle_ENV (
   SQLSMALLINT		  handleType,
   SQLHANDLE		  handle)
 {
-  ENTER_HENV ((SQLHENV) handle,
-      trace_SQLFreeHandle (TRACE_ENTER, handleType, handle));
+  int retcode = SQL_SUCCESS;
+
+  ODBC_LOCK ();
+
+  TRACE (trace_SQLFreeHandle (TRACE_ENTER, handleType, handle));
 
   retcode = SQLFreeEnv_Internal ((SQLHENV) handle);
 
-  LEAVE_HENV ((SQLHENV) handle,
-      trace_SQLFreeHandle (TRACE_LEAVE, handleType, handle);
-      MEM_FREE (handle);
-  );
+  TRACE (trace_SQLFreeHandle (TRACE_LEAVE, handleType, handle));
+
+  MEM_FREE (handle);
+
+  /*
+   *  Close trace after last environment handle is freed
+   */
+  if (--_iodbc_env_counter == 0)
+    trace_stop();
+
+  ODBC_UNLOCK ();
+
+  return retcode;
 }
 
+
 static RETCODE
 _SQLFreeHandle_DBC (
   SQLSMALLINT		  handleType,
