@@ -1,7 +1,7 @@
 /*
  *  prepare.c
  *
- *  $Id: prepare.c,v 1.15 2003/09/02 14:44:22 source Exp $
+ *  $Id: prepare.c,v 1.20 2004/07/06 15:34:24 source Exp $
  *
  *  Prepare a query
  *
@@ -97,10 +97,10 @@ SQLPrepare_Internal (
 {
   STMT (pstmt, hstmt);
   CONN (pdbc, pstmt->hdbc);
-  ENV_t FAR *penv = pdbc->henv;
+  ENVR (penv, pdbc->henv);
   HPROC hproc = SQL_NULL_HPROC;
   SQLRETURN retcode = SQL_SUCCESS;
-  int sqlstat = en_00000;
+  sqlstcode_t sqlstat = en_00000;
   void * _SqlStr = NULL;
 
   /* check state */
@@ -157,12 +157,12 @@ SQLPrepare_Internal (
       if (waMode != 'W')
         {
         /* ansi=>unicode*/
-          _SqlStr = _iodbcdm_conv_param_A2W(pstmt, 0, szSqlStr, cbSqlStr);
+          _SqlStr = _iodbcdm_conv_param_A2W(pstmt, 0, (SQLCHAR *) szSqlStr, cbSqlStr);
         }
       else
         {
         /* unicode=>ansi*/
-          _SqlStr = _iodbcdm_conv_param_W2A(pstmt, 0, szSqlStr, cbSqlStr);
+          _SqlStr = _iodbcdm_conv_param_W2A(pstmt, 0, (SQLWCHAR *) szSqlStr, cbSqlStr);
         }
       szSqlStr = _SqlStr;
       cbSqlStr = SQL_NTS;
@@ -237,7 +237,7 @@ SQLPrepare_Internal (
 
 SQLRETURN SQL_API
 SQLPrepare (SQLHSTMT hstmt,
-    SQLCHAR FAR * szSqlStr,
+    SQLCHAR * szSqlStr,
     SQLINTEGER cbSqlStr)
 {
   ENTER_STMT (hstmt,
@@ -252,7 +252,7 @@ SQLPrepare (SQLHSTMT hstmt,
 
 SQLRETURN SQL_API
 SQLPrepareA (SQLHSTMT hstmt,
-    SQLCHAR FAR * szSqlStr,
+    SQLCHAR * szSqlStr,
     SQLINTEGER cbSqlStr)
 {
   ENTER_STMT (hstmt,
@@ -267,7 +267,7 @@ SQLPrepareA (SQLHSTMT hstmt,
 
 SQLRETURN SQL_API
 SQLPrepareW (SQLHSTMT hstmt,
-    SQLWCHAR FAR * szSqlStr,
+    SQLWCHAR * szSqlStr,
     SQLINTEGER cbSqlStr)
 {
   ENTER_STMT (hstmt,
@@ -289,10 +289,10 @@ SQLSetCursorName_Internal (
 {
   STMT (pstmt, hstmt);
   CONN (pdbc, pstmt->hdbc);
-  ENV_t FAR *penv = pdbc->henv;
+  ENVR (penv, pdbc->henv);
   HPROC hproc = SQL_NULL_HPROC;
   SQLRETURN retcode = SQL_SUCCESS;
-  int sqlstat = en_00000;
+  sqlstcode_t sqlstat = en_00000;
   void * _Cursor = NULL;
 
   if (szCursor == NULL)
@@ -350,12 +350,12 @@ SQLSetCursorName_Internal (
       if (waMode != 'W')
         {
         /* ansi=>unicode*/
-          _Cursor = dm_SQL_A2W(szCursor, cbCursor);
+          _Cursor = dm_SQL_A2W ((SQLCHAR *) szCursor, cbCursor);
         }
       else
         {
         /* unicode=>ansi*/
-          _Cursor = dm_SQL_W2A(szCursor, cbCursor);
+          _Cursor = dm_SQL_W2A ((SQLWCHAR *) szCursor, cbCursor);
         }
       szCursor = _Cursor;
       cbCursor = SQL_NTS;
@@ -386,9 +386,10 @@ SQLSetCursorName_Internal (
 
 
 SQLRETURN SQL_API
-SQLSetCursorName (SQLHSTMT hstmt,
-    SQLCHAR FAR * szCursor,
-    SQLSMALLINT cbCursor)
+SQLSetCursorName (
+    SQLHSTMT		  hstmt,
+    SQLCHAR		* szCursor,
+    SQLSMALLINT		  cbCursor)
 {
   ENTER_STMT (hstmt,
     trace_SQLSetCursorName (TRACE_ENTER, hstmt, szCursor, cbCursor));
@@ -401,9 +402,10 @@ SQLSetCursorName (SQLHSTMT hstmt,
 
 
 SQLRETURN SQL_API
-SQLSetCursorNameA (SQLHSTMT hstmt,
-    SQLCHAR FAR * szCursor,
-    SQLSMALLINT cbCursor)
+SQLSetCursorNameA (
+    SQLHSTMT		  hstmt,
+    SQLCHAR		* szCursor,
+    SQLSMALLINT		  cbCursor)
 {
   ENTER_STMT (hstmt,
     trace_SQLSetCursorName (TRACE_ENTER, hstmt, szCursor, cbCursor));
@@ -418,7 +420,7 @@ SQLSetCursorNameA (SQLHSTMT hstmt,
 SQLRETURN SQL_API
 SQLSetCursorNameW (
   SQLHSTMT		  hstmt,
-  SQLWCHAR FAR		* szCursor,
+  SQLWCHAR 		* szCursor,
   SQLSMALLINT		  cbCursor)
 {
   ENTER_STMT (hstmt,
@@ -433,25 +435,25 @@ SQLSetCursorNameW (
 
 static SQLRETURN
 SQLBindParameter_Internal (
-    SQLHSTMT hstmt,
-    SQLUSMALLINT ipar,
-    SQLSMALLINT fParamType,
-    SQLSMALLINT fCType,
-    SQLSMALLINT fSqlType,
-    SQLUINTEGER cbColDef,
-    SQLSMALLINT ibScale,
-    SQLPOINTER rgbValue,
-    SQLINTEGER cbValueMax,
-    SQLINTEGER FAR * pcbValue)
+    SQLHSTMT		  hstmt,
+    SQLUSMALLINT	  ipar,
+    SQLSMALLINT		  fParamType,
+    SQLSMALLINT		  fCType,
+    SQLSMALLINT		  fSqlType,
+    SQLULEN		  cbColDef,
+    SQLSMALLINT		  ibScale,
+    SQLPOINTER		  rgbValue,
+    SQLLEN		  cbValueMax,
+    SQLLEN		* pcbValue)
 {
   STMT (pstmt, hstmt);
   CONN (pdbc, pstmt->hdbc);
-  ENV_t FAR *penv = pdbc->henv;
+  ENVR (penv, pdbc->henv);
   HPROC hproc = SQL_NULL_HPROC;
   SQLSMALLINT nCType;
   SQLSMALLINT nSqlType;
 
-  int sqlstat = en_00000;
+  sqlstcode_t sqlstat = en_00000;
   SQLRETURN retcode = SQL_SUCCESS;
 
 #if (ODBCVER >= 0x0300)
@@ -603,16 +605,16 @@ SQLBindParameter_Internal (
 
 SQLRETURN SQL_API
 SQLBindParameter (
-    SQLHSTMT hstmt,
-    SQLUSMALLINT ipar,
-    SQLSMALLINT fParamType,
-    SQLSMALLINT fCType,
-    SQLSMALLINT fSqlType,
-    SQLUINTEGER cbColDef,
-    SQLSMALLINT ibScale,
-    SQLPOINTER rgbValue,
-    SQLINTEGER cbValueMax,
-    SQLINTEGER FAR * pcbValue)
+    SQLHSTMT		  hstmt,
+    SQLUSMALLINT	  ipar,
+    SQLSMALLINT		  fParamType,
+    SQLSMALLINT		  fCType,
+    SQLSMALLINT		  fSqlType,
+    SQLULEN		  cbColDef,
+    SQLSMALLINT		  ibScale,
+    SQLPOINTER		  rgbValue,
+    SQLLEN		  cbValueMax,
+    SQLLEN		* pcbValue)
 {
   ENTER_STMT (hstmt,
     trace_SQLBindParameter (TRACE_ENTER,
@@ -633,14 +635,14 @@ SQLBindParameter (
 static SQLRETURN 
 SQLParamOptions_Internal (
   SQLHSTMT		  hstmt,
-  SQLUINTEGER		  crow,
-  SQLUINTEGER FAR	* pirow)
+  SQLULEN		  crow,
+  SQLULEN 		* pirow)
 {
   STMT (pstmt, hstmt);
   HPROC hproc = SQL_NULL_HPROC;
   SQLRETURN retcode;
 
-  if (crow == (UDWORD) 0UL)
+  if (crow == (SQLULEN) 0UL)
     {
       PUSHSQLERR (pstmt->herr, en_S1107);
 
@@ -692,8 +694,8 @@ SQLParamOptions_Internal (
 SQLRETURN SQL_API
 SQLParamOptions(
   SQLHSTMT		  hstmt,
-  SQLUINTEGER		  crow,
-  SQLUINTEGER FAR	* pirow)
+  SQLULEN		  crow,
+  SQLULEN 		* pirow)
 {
   ENTER_STMT (hstmt,
     trace_SQLParamOptions (TRACE_ENTER, hstmt, crow, pirow));
@@ -709,13 +711,14 @@ static SQLRETURN
 SQLSetScrollOptions_Internal (
   SQLHSTMT		  hstmt,
   SQLUSMALLINT		  fConcurrency,
-  SQLINTEGER		  crowKeyset,
+  SQLLEN		  crowKeyset,
   SQLUSMALLINT		  crowRowset)
 {
   STMT (pstmt, hstmt);
+  CONN (pdbc, pstmt->hdbc);
   HPROC hproc = SQL_NULL_HPROC;
-  int sqlstat = en_00000;
-  SQLRETURN retcode;
+  sqlstcode_t sqlstat = en_00000;
+  SQLRETURN retcode = SQL_SUCCESS;
 
   for (;;)
     {
@@ -762,13 +765,19 @@ SQLSetScrollOptions_Internal (
 
       hproc = _iodbcdm_getproc (pstmt->hdbc, en_SetScrollOptions);
 
-      if (hproc == SQL_NULL_HPROC)
-	{
+      if (hproc != SQL_NULL_HPROC)
+        {
+	  CALL_DRIVER (pstmt->hdbc, pstmt, retcode, hproc, en_SetScrollOptions,
+	      (pstmt->dhstmt, fConcurrency, crowKeyset, crowRowset));
+	}
+      else
+        {
 #if (ODBCVER >= 0x0300)
 	  SQLINTEGER InfoValue, InfoType, Value;
 	  HPROC hproc1 = _iodbcdm_getproc (pstmt->hdbc, en_SetStmtAttr);
+	  HPROC hproc2 = _iodbcdm_getproc (pstmt->hdbc, en_GetInfo);
 
-	  if (hproc1 == SQL_NULL_HPROC)
+	  if (hproc1 == SQL_NULL_HPROC || hproc2 == SQL_NULL_HPROC)
 	    {
 	      PUSHSQLERR (pstmt->herr, en_IM001);
 	      return SQL_ERROR;
@@ -798,7 +807,9 @@ SQLSetScrollOptions_Internal (
 	      break;
 	    }
 
-	  retcode = SQLGetInfo (pstmt->hdbc, InfoType, &InfoValue, 0, NULL);
+	  CALL_DRIVER (pstmt->hdbc, pdbc, retcode, hproc2, en_GetInfo,
+	      (pdbc->dhdbc, InfoType, &InfoValue, 0, NULL));
+
 	  if (retcode != SQL_SUCCESS)
 	    {
 	      return retcode;
@@ -838,6 +849,7 @@ SQLSetScrollOptions_Internal (
 		}
 	      break;
 	    }
+
 	  CALL_DRIVER (pstmt->hdbc, pstmt, retcode, hproc1, en_SetStmtAttr,
 	      (pstmt->dhstmt, SQL_ATTR_CURSOR_TYPE, Value, 0));
 
@@ -882,9 +894,6 @@ SQLSetScrollOptions_Internal (
       return SQL_ERROR;
     }
 
-  CALL_DRIVER (pstmt->hdbc, pstmt, retcode, hproc, en_SetScrollOptions,
-      (pstmt->dhstmt, fConcurrency, crowKeyset, crowRowset));
-
   return retcode;
 }
 
@@ -893,7 +902,7 @@ SQLRETURN SQL_API
 SQLSetScrollOptions (
   SQLHSTMT		  hstmt,
   SQLUSMALLINT		  fConcurrency,
-  SQLINTEGER		  crowKeyset,
+  SQLLEN		  crowKeyset,
   SQLUSMALLINT		  crowRowset)
 {
   ENTER_STMT (hstmt,
@@ -920,14 +929,14 @@ SQLSetScrollOptions (
 
 SQLRETURN SQL_API
 SQLSetParam (
-    SQLHSTMT hstmt,
-    SQLUSMALLINT ipar,
-    SQLSMALLINT fCType,
-    SQLSMALLINT fSqlType,
-    SQLUINTEGER cbColDef,
-    SQLSMALLINT ibScale,
-    SQLPOINTER rgbValue,
-    SQLINTEGER FAR * pcbValue)
+  SQLHSTMT		  hstmt,
+  SQLUSMALLINT		  ipar,
+  SQLSMALLINT		  fCType,
+  SQLSMALLINT		  fSqlType,
+  SQLULEN		  cbColDef,
+  SQLSMALLINT		  ibScale,
+  SQLPOINTER		  rgbValue,
+  SQLLEN 		* pcbValue)
 {
   return SQLBindParameter (hstmt,
       ipar,
