@@ -1,7 +1,7 @@
 /*
  *  result.c
  *
- *  $Id: result.c,v 1.18 2003/09/03 08:44:47 source Exp $
+ *  $Id: result.c,v 1.21 2004/07/06 15:26:07 source Exp $
  *
  *  Prepare for getting query result
  *
@@ -94,12 +94,12 @@ SQLBindCol_Internal (
     SQLUSMALLINT icol,
     SQLSMALLINT fCType,
     SQLPOINTER rgbValue,
-    SQLINTEGER cbValueMax,
-    SQLINTEGER FAR * pcbValue)
+    SQLLEN cbValueMax,
+    SQLLEN *pcbValue)
 {
   STMT(pstmt, hstmt);
   CONN (pdbc, pstmt->hdbc);
-  ENV_t FAR *penv = pdbc->henv;
+  ENVR (penv, pdbc->henv);
   HPROC hproc = SQL_NULL_HPROC;
   SQLSMALLINT nCType;
   SQLRETURN retcode;
@@ -221,8 +221,8 @@ SQLBindCol (
     SQLUSMALLINT icol,
     SQLSMALLINT fCType,
     SQLPOINTER rgbValue,
-    SQLINTEGER cbValueMax,
-    SQLINTEGER FAR * pcbValue)
+    SQLLEN cbValueMax,
+    SQLLEN *pcbValue)
 {
   ENTER_STMT (hstmt,
       trace_SQLBindCol (TRACE_ENTER,
@@ -240,14 +240,14 @@ SQLBindCol (
 SQLRETURN SQL_API
 SQLGetCursorName_Internal (
   SQLHSTMT 		  hstmt,
-  SQLCHAR FAR 		* szCursor,
+  SQLCHAR 		* szCursor,
   SQLSMALLINT 		  cbCursorMax,
-  SQLSMALLINT FAR 	* pcbCursor,
+  SQLSMALLINT 	 	* pcbCursor,
   char			  waMode)
 {
   STMT(pstmt, hstmt);
   CONN (pdbc, pstmt->hdbc);
-  ENV_t FAR *penv = pdbc->henv;
+  ENVR (penv, pdbc->henv);
   HPROC hproc = SQL_NULL_HPROC;
   SQLRETURN retcode = SQL_SUCCESS;
   void * cursorOut = szCursor;
@@ -327,13 +327,12 @@ SQLGetCursorName_Internal (
       if (waMode != 'W')
         {
         /* ansi<=unicode*/
-          dm_StrCopyOut2_W2A (cursorOut, szCursor, cbCursorMax, NULL);
+          dm_StrCopyOut2_W2A ((SQLWCHAR *) cursorOut, (SQLCHAR *) szCursor, cbCursorMax, NULL);
         }
       else
         {
         /* unicode<=ansi*/
-          dm_StrCopyOut2_A2W (cursorOut, 
-	  	(SQLWCHAR *) szCursor, cbCursorMax, NULL);
+          dm_StrCopyOut2_A2W ((SQLCHAR *) cursorOut, (SQLWCHAR *) szCursor, cbCursorMax, NULL);
         }
     }
 
@@ -346,9 +345,9 @@ SQLGetCursorName_Internal (
 SQLRETURN SQL_API
 SQLGetCursorName (
   SQLHSTMT 		  hstmt,
-  SQLCHAR FAR 		* szCursor,
+  SQLCHAR  		* szCursor,
   SQLSMALLINT 		  cbCursorMax,
-  SQLSMALLINT FAR 	* pcbCursor)
+  SQLSMALLINT 	 	* pcbCursor)
 {
   ENTER_STMT (hstmt,
     trace_SQLGetCursorName (TRACE_ENTER,
@@ -370,9 +369,9 @@ SQLGetCursorName (
 SQLRETURN SQL_API
 SQLGetCursorNameA (
   SQLHSTMT 		  hstmt,
-  SQLCHAR FAR 		* szCursor,
+  SQLCHAR  		* szCursor,
   SQLSMALLINT 		  cbCursorMax,
-  SQLSMALLINT FAR 	* pcbCursor)
+  SQLSMALLINT 		* pcbCursor)
 {
   ENTER_STMT (hstmt,
     trace_SQLGetCursorName (TRACE_ENTER,
@@ -393,9 +392,9 @@ SQLGetCursorNameA (
 
 SQLRETURN SQL_API
 SQLGetCursorNameW (SQLHSTMT hstmt,
-    SQLWCHAR FAR * szCursor,
-    SQLSMALLINT cbCursorMax,
-    SQLSMALLINT FAR * pcbCursor)
+    SQLWCHAR		* szCursor,
+    SQLSMALLINT		  cbCursorMax,
+    SQLSMALLINT 	* pcbCursor)
 {
   ENTER_STMT (hstmt,
     trace_SQLGetCursorNameW (TRACE_ENTER,
@@ -417,7 +416,7 @@ SQLGetCursorNameW (SQLHSTMT hstmt,
 static SQLRETURN 
 SQLRowCount_Internal (
   SQLHSTMT		  hstmt,
-  SQLINTEGER FAR	* pcrow)
+  SQLLEN		* pcrow)
 {
   STMT(pstmt, hstmt);
   HPROC hproc;
@@ -453,7 +452,7 @@ SQLRowCount_Internal (
 SQLRETURN SQL_API
 SQLRowCount (
   SQLHSTMT		  hstmt,
-  SQLINTEGER FAR	* pcrow)
+  SQLLEN 		* pcrow)
 {
   ENTER_STMT (hstmt,
     trace_SQLRowCount (TRACE_ENTER, hstmt, pcrow));
@@ -467,8 +466,8 @@ SQLRowCount (
 
 SQLRETURN SQL_API
 _iodbcdm_NumResultCols (
-    SQLHSTMT hstmt,
-    SQLSMALLINT FAR * pccol)
+    SQLHSTMT		  hstmt,
+    SQLSMALLINT		* pccol)
 {
   STMT (pstmt, hstmt);
   HPROC hproc;
@@ -549,7 +548,7 @@ _iodbcdm_NumResultCols (
 SQLRETURN SQL_API
 SQLNumResultCols (
   SQLHSTMT		  hstmt,
-  SQLSMALLINT FAR	* pccol)
+  SQLSMALLINT 		* pccol)
 {
   ENTER_STMT (hstmt,
     trace_SQLNumResultCols (TRACE_ENTER, hstmt, pccol));
@@ -562,7 +561,7 @@ SQLNumResultCols (
 
 
 SQLSMALLINT
-_iodbcdm_map_sql_type (type, odbcver)
+_iodbcdm_map_sql_type (int type, int odbcver)
 {
   switch (type)
     {
@@ -584,7 +583,7 @@ _iodbcdm_map_sql_type (type, odbcver)
 
 
 SQLSMALLINT
-_iodbcdm_map_c_type (type, odbcver)
+_iodbcdm_map_c_type (int type, int odbcver)
 {
   switch (type)
     {
@@ -607,26 +606,26 @@ _iodbcdm_map_c_type (type, odbcver)
 
 SQLRETURN SQL_API
 SQLDescribeCol_Internal (
-    SQLHSTMT hstmt,
-    SQLUSMALLINT icol,
-    SQLPOINTER szColName,
-    SQLSMALLINT cbColNameMax,
-    SQLSMALLINT FAR * pcbColName,
-    SQLSMALLINT FAR * pfSqlType,
-    SQLUINTEGER FAR * pcbColDef,
-    SQLSMALLINT FAR * pibScale,
-    SQLSMALLINT FAR * pfNullable,
-    SQLCHAR waMode)
+    SQLHSTMT		  hstmt,
+    SQLUSMALLINT	  icol,
+    SQLPOINTER		  szColName,
+    SQLSMALLINT		  cbColNameMax,
+    SQLSMALLINT 	* pcbColName,
+    SQLSMALLINT 	* pfSqlType,
+    SQLULEN	 	* pcbColDef,
+    SQLSMALLINT 	* pibScale,
+    SQLSMALLINT 	* pfNullable,
+    SQLCHAR		  waMode)
 {
   STMT(pstmt, hstmt);
   CONN (pdbc, pstmt->hdbc);
-  ENV_t FAR *penv = pdbc->henv;
-  GENV_t FAR *genv = pdbc->genv;
+  ENVR (penv, pdbc->henv);
+  GENV (genv, pdbc->genv);
   HPROC hproc = SQL_NULL_HPROC;
   SQLRETURN retcode = SQL_SUCCESS;
   void * _ColName = NULL;
   void * colNameOut = szColName;
-  int sqlstat = en_00000;
+  sqlstcode_t sqlstat = en_00000;
 
   /* check arguments */
   if (icol == 0)
@@ -728,12 +727,12 @@ SQLDescribeCol_Internal (
       if (waMode != 'W')
         {
         /* ansi<=unicode*/
-          dm_StrCopyOut2_W2A (colNameOut, szColName, cbColNameMax, NULL);
+          dm_StrCopyOut2_W2A ((SQLWCHAR *) colNameOut, (SQLCHAR *) szColName, cbColNameMax, NULL);
         }
       else
         {
         /* unicode<=ansi*/
-          dm_StrCopyOut2_A2W (colNameOut, szColName, cbColNameMax, NULL);
+          dm_StrCopyOut2_A2W ((SQLCHAR *) colNameOut, (SQLWCHAR *) szColName, cbColNameMax, NULL);
         }
     }
 
@@ -778,14 +777,14 @@ SQLDescribeCol_Internal (
 
 SQLRETURN SQL_API
 SQLDescribeCol (SQLHSTMT hstmt,
-    SQLUSMALLINT icol,
-    SQLCHAR FAR * szColName,
-    SQLSMALLINT cbColNameMax,
-    SQLSMALLINT FAR * pcbColName,
-    SQLSMALLINT FAR * pfSqlType,
-    SQLUINTEGER FAR * pcbColDef,
-    SQLSMALLINT FAR * pibScale,
-    SQLSMALLINT FAR * pfNullable)
+    SQLUSMALLINT	  icol,
+    SQLCHAR		* szColName,
+    SQLSMALLINT		  cbColNameMax,
+    SQLSMALLINT		* pcbColName,
+    SQLSMALLINT		* pfSqlType,
+    SQLULEN		* pcbColDef,
+    SQLSMALLINT		* pibScale,
+    SQLSMALLINT		* pfNullable)
 {
   ENTER_STMT (hstmt,
     trace_SQLDescribeCol (TRACE_ENTER, 
@@ -821,14 +820,14 @@ SQLDescribeCol (SQLHSTMT hstmt,
 
 SQLRETURN SQL_API
 SQLDescribeColA (SQLHSTMT hstmt,
-    SQLUSMALLINT icol,
-    SQLCHAR FAR * szColName,
-    SQLSMALLINT cbColNameMax,
-    SQLSMALLINT FAR * pcbColName,
-    SQLSMALLINT FAR * pfSqlType,
-    SQLUINTEGER FAR * pcbColDef,
-    SQLSMALLINT FAR * pibScale,
-    SQLSMALLINT FAR * pfNullable)
+    SQLUSMALLINT	  icol,
+    SQLCHAR		* szColName,
+    SQLSMALLINT		  cbColNameMax,
+    SQLSMALLINT		* pcbColName,
+    SQLSMALLINT		* pfSqlType,
+    SQLULEN		* pcbColDef,
+    SQLSMALLINT		* pibScale,
+    SQLSMALLINT		* pfNullable)
 {
   ENTER_STMT (hstmt,
     trace_SQLDescribeCol (TRACE_ENTER, 
@@ -866,13 +865,13 @@ SQLRETURN SQL_API
 SQLDescribeColW (
   SQLHSTMT		  hstmt,
   SQLUSMALLINT		  icol,
-  SQLWCHAR FAR		* szColName,
+  SQLWCHAR		* szColName,
   SQLSMALLINT		  cbColNameMax,
-  SQLSMALLINT FAR	* pcbColName,
-  SQLSMALLINT FAR	* pfSqlType,
-  SQLUINTEGER FAR	* pcbColDef,
-  SQLSMALLINT FAR	* pibScale,
-  SQLSMALLINT FAR	* pfNullable)
+  SQLSMALLINT		* pcbColName,
+  SQLSMALLINT		* pfSqlType,
+  SQLULEN		* pcbColDef,
+  SQLSMALLINT		* pibScale,
+  SQLSMALLINT		* pfNullable)
 {
   ENTER_STMT (hstmt,
     trace_SQLDescribeColW (TRACE_ENTER, 
@@ -908,23 +907,23 @@ SQLDescribeColW (
 
 SQLRETURN SQL_API
 SQLColAttributes_Internal (
-    SQLHSTMT hstmt,
-    SQLUSMALLINT icol,
-    SQLUSMALLINT fDescType,
-    SQLPOINTER rgbDesc,
-    SQLSMALLINT cbDescMax,
-    SQLSMALLINT FAR * pcbDesc,
-    SQLINTEGER FAR * pfDesc,
-    SQLCHAR waMode)
+    SQLHSTMT		  hstmt,
+    SQLUSMALLINT	  icol,
+    SQLUSMALLINT	  fDescType,
+    SQLPOINTER		  rgbDesc,
+    SQLSMALLINT		  cbDescMax,
+    SQLSMALLINT	  	* pcbDesc,
+    SQLLEN 		* pfDesc,
+    SQLCHAR		  waMode)
 {
   STMT(pstmt, hstmt);
   CONN (pdbc, pstmt->hdbc);
-  ENV_t FAR *penv = pdbc->henv;
+  ENVR (penv, pdbc->henv);
   HPROC hproc = SQL_NULL_HPROC;
   SQLRETURN retcode = SQL_SUCCESS;
   void * _Desc = NULL;
   void * descOut = rgbDesc;
-  int sqlstat = en_00000;
+  sqlstcode_t sqlstat = en_00000;
   SQLUSMALLINT new_attr = fDescType;
 
   /* check arguments */
@@ -1141,12 +1140,12 @@ SQLColAttributes_Internal (
           if (waMode != 'W')
             {
             /* ansi<=unicode*/
-              dm_StrCopyOut2_W2A (descOut, rgbDesc, cbDescMax / sizeof(wchar_t), pcbDesc);
+              dm_StrCopyOut2_W2A ((SQLWCHAR *) descOut, (SQLCHAR *) rgbDesc, cbDescMax / sizeof(wchar_t), pcbDesc);
             }
           else
             {
             /* unicode<=ansi*/
-              dm_StrCopyOut2_A2W (descOut, rgbDesc, cbDescMax, pcbDesc);
+              dm_StrCopyOut2_A2W ((SQLCHAR *) descOut, (SQLWCHAR *) rgbDesc, cbDescMax, pcbDesc);
               if (pcbDesc)
                 *pcbDesc = *pcbDesc * sizeof(wchar_t);
             }
@@ -1199,8 +1198,8 @@ SQLColAttributes (
   SQLUSMALLINT		  fDescType,
   SQLPOINTER		  rgbDesc,
   SQLSMALLINT		  cbDescMax,
-  SQLSMALLINT FAR	* pcbDesc,
-  SQLINTEGER FAR	* pfDesc)
+  SQLSMALLINT 		* pcbDesc,
+  SQLLEN 		* pfDesc)
 {
   ENTER_STMT (statementHandle,
     trace_SQLColAttributes (TRACE_ENTER,
@@ -1235,8 +1234,8 @@ SQLColAttributesA (
   SQLUSMALLINT		  fDescType,
   SQLPOINTER		  rgbDesc,
   SQLSMALLINT		  cbDescMax,
-  SQLSMALLINT FAR	* pcbDesc,
-  SQLINTEGER FAR	* pfDesc)
+  SQLSMALLINT 		* pcbDesc,
+  SQLLEN		* pfDesc)
 {
   ENTER_STMT (statementHandle,
     trace_SQLColAttributes (TRACE_ENTER,
@@ -1271,8 +1270,8 @@ SQLColAttributesW (
   SQLUSMALLINT		  fDescType,
   SQLPOINTER		  rgbDesc,
   SQLSMALLINT		  cbDescMax,
-  SQLSMALLINT FAR	* pcbDesc,
-  SQLINTEGER FAR	* pfDesc)
+  SQLSMALLINT 		* pcbDesc,
+  SQLLEN		* pfDesc)
 {
   ENTER_STMT (statementHandle,
     trace_SQLColAttributesW (TRACE_ENTER,
