@@ -1,7 +1,7 @@
 /*
  *  FreeEnv.c
  *
- *  $Id: FreeEnv.c,v 1.2 2003/08/22 14:28:41 source Exp $
+ *  $Id: FreeEnv.c,v 1.3 2005/02/01 14:22:09 source Exp $
  *
  *  SQLFreeEnv trace functions
  *
@@ -81,7 +81,4 @@ trace_SQLFreeEnv(int trace_leave, int retcode,
 
   /* Trace Arguments */
   _trace_handle (SQL_HANDLE_ENV, henv);
-
-  if (trace_leave)
-    trace_stop ();
 }
