@@ -1,7 +1,7 @@
 /*
  *  SetConnectOption.c
  *
- *  $Id: SetConnectOption.c,v 1.2 2003/08/22 14:28:41 source Exp $
+ *  $Id: SetConnectOption.c,v 1.4 2004/07/06 15:26:07 source Exp $
  *
  *  SQLSetConnectOption trace functions
  *
@@ -76,7 +76,7 @@ void
 trace_SQLSetConnectOption (int trace_leave, int retcode,
   SQLHDBC		  hdbc,
   SQLUSMALLINT		  fOption,
-  SQLUINTEGER		  vParam)
+  SQLULEN	  vParam)
 {
   /* Trace function */
   _trace_print_function (en_SetConnectOption, trace_leave, retcode);
@@ -84,7 +84,7 @@ trace_SQLSetConnectOption (int trace_leave, int retcode,
   /* Trace Arguments */
   _trace_handle (SQL_HANDLE_DBC, hdbc);
   _trace_connopt_type (fOption);
-  _trace_uinteger (vParam);
+  _trace_ulen (vParam);
 }
 
 
@@ -92,7 +92,7 @@ void
 trace_SQLSetConnectOptionW (int trace_leave, int retcode,
   SQLHDBC		  hdbc,
   SQLUSMALLINT		  fOption,
-  SQLUINTEGER		  vParam)
+  SQLULEN		  vParam)
 {
   /* Trace function */
   _trace_print_function (en_SetConnectOptionW, trace_leave, retcode);
@@ -100,5 +100,5 @@ trace_SQLSetConnectOptionW (int trace_leave, int retcode,
   /* Trace Arguments */
   _trace_handle (SQL_HANDLE_DBC, hdbc);
   _trace_connopt_type (fOption);
-  _trace_uinteger (vParam);
+  _trace_ulen (vParam);
 }
