@@ -1,7 +1,7 @@
 /*
  *  SetPos.c
  *
- *  $Id: SetPos.c,v 1.2 2003/08/22 14:28:41 source Exp $
+ *  $Id: SetPos.c,v 1.4 2004/07/06 15:26:07 source Exp $
  *
  *  SQLSetPos trace functions
  *
@@ -72,6 +72,17 @@
 #include "trace.h"
 
 
+void
+_trace_setpos_irow (SQLSETPOSIROW i)
+{
+#ifdef _WIN64
+  trace_emit ("\t\t%-15.15s   %I64d\n", "SQLSETPOSIROW", (INT64) i);
+#else
+  trace_emit ("\t\t%-15.15s   %ld\n", "SQLSETPOSIROW", (long) i);
+#endif
+}
+
+
 void
 _trace_setpos_oper (SQLUSMALLINT type)
 {
@@ -112,7 +123,7 @@ _trace_setpos_lock (SQLUSMALLINT type)
 void
 trace_SQLSetPos (int trace_leave, int retcode,
   SQLHSTMT		  hstmt,
-  SQLUSMALLINT		  irow,
+  SQLSETPOSIROW		  irow,
   SQLUSMALLINT		  fOption,
   SQLUSMALLINT		  fLock)
 {
@@ -121,7 +132,7 @@ trace_SQLSetPos (int trace_leave, int retcode,
 
   /* Trace Arguments */
   _trace_handle (SQL_HANDLE_STMT, hstmt);
-  _trace_usmallint (irow);
+  _trace_setpos_irow (irow);
   _trace_setpos_oper (fOption);
   _trace_setpos_lock (fLock);
 }
