@@ -1,7 +1,7 @@
 /*
  *  trace.c
  *
- *  $Id: trace.c,v 1.7 2004/07/06 15:26:07 source Exp $
+ *  $Id: trace.c,v 1.12 2005/02/01 01:11:43 source Exp $
  *
  *  Trace functions
  *
@@ -76,6 +76,7 @@
 #include <pwd.h>
 #include <unistd.h>
 #include <time.h>
+#include <fcntl.h>
 
 #include <sql.h>
 #include <sqlext.h>
@@ -131,82 +132,126 @@ trace_get_filename (void)
 void
 trace_set_filename (char *fname)
 {
-  char buf[255];
   char *s, *p;
   struct passwd *pwd;
-  size_t i;
-  MEM_FREE (trace_fname);
+  char *buf;
+  size_t buf_len, buf_pos;
+  char tmp[255];
 
-  memset (buf, '\0', sizeof (buf));
-  for (s = fname, i = 0; i < sizeof (buf) && *s;)
+  /*  Initialize */
+  MEM_FREE (trace_fname);
+  trace_fname = NULL;
+  buf = (char *) malloc (buf_len = strlen (fname) + sizeof (tmp) + 1);
+  if (!buf)
+    return;			/* No more memory */
+  buf_pos = 0;
+  buf[0] = '\0';
+
+  for (s = fname; *s;)
     {
-      if (*s == '$')
+      /*
+       *  Make sure we can fit at least 1 more tmp buffer inside
+       */
+      if (buf_len - buf_pos < sizeof (tmp))
+	buf = realloc (buf, buf_len += sizeof (tmp) + 1);
+      if (!buf)
+	return;			/* No more memory */
+
+      if (*s != '$')
 	{
+	  buf[buf_pos++] = *s++;
+	}
+      else
+	{
+	  /* Handle Escape sequences */
 	  switch (*(s + 1))
 	    {
+	    case '$':
+	      {
+		buf[buf_pos++] = '$';
+		break;
+	      }
+
 	    case 'p':
 	    case 'P':
-	      sprintf (buf, "%s%ld", buf, (long) getpid());
-	      i = strlen (buf);
-	      s += 2;
-	      break;
+	      {
+#if defined (HAVE_SNPRINTF)
+		snprintf (tmp, sizeof (tmp), "%ld", (long) getpid ());
+#else
+		sprintf (tmp, "%ld", (long) getpid ());
+#endif
+		strcpy (&buf[buf_pos], tmp);
+		buf_pos += strlen (tmp);
+		break;
+	      }
 
 	    case 'u':
 	    case 'U':
-	      sprintf (buf, "%s%ld", buf, (long) geteuid());
-	      i = strlen (buf);
-	      s += 2;
-	      break;
+	      {
+		if ((pwd = getpwuid (getuid ())) != NULL)
+		  {
+#if defined (HAVE_SNPRINTF)
+		    snprintf (tmp, sizeof (tmp), "%s", pwd->pw_name);
+#else
+		    sprintf (tmp, "%s", pwd->pw_name);
+#endif
+		    strcpy (&buf[buf_pos], tmp);
+		    buf_pos += strlen (tmp);
+		  }
+		break;
+	      }
 
 	    case 'h':
 	    case 'H':
-	      p = NULL;
-	      if ((p = getenv ("HOME")) == NULL)
-		{
-		  if ((pwd = getpwuid (getuid ())) != NULL)
-		    p = pwd->pw_dir;
-		}
-
-	      if (p)
-		{
-#if defined (HAVE_SNPRINTF)
-		  snprintf (buf, sizeof (buf), "%s%s", buf, p);
-#else
-		  sprintf (buf, "%s%s", buf, p);
-#endif
-		  i = strlen(buf);
-		  s += 2;
-		  continue;
-		}
-
-	      case 't':
-	      case 'T':
-	        {
-		  char tmp[30];
-		  time_t now;
-		  struct tm *timeNow;
-
-		  tzset ();
-		  time (&now);
-		  timeNow = localtime (&now);
-
-		  strftime (tmp, sizeof (tmp), "%Y%m%d%H%M%S", timeNow);
-		  sprintf (buf, "%s%s", buf, tmp);
-		  i = strlen (buf);
-		  s += 2;
-		  continue;
+	      {
+		p = NULL;
+		if ((p = getenv ("HOME")) == NULL)
+		  {
+		    if ((pwd = getpwuid (getuid ())) != NULL)
+		      p = pwd->pw_dir;
 		  }
 
+		if (p)
+		  {
+#if defined (HAVE_SNPRINTF)
+		    snprintf (tmp, sizeof (tmp), "%s", p);
+#else
+		    sprintf (tmp, "%s", p);
+#endif
+		    strcpy (&buf[buf_pos], tmp);
+		    buf_pos += strlen (tmp);
+		  }
+		break;
+	      }
+
+	    case 't':
+	    case 'T':
+	      {
+		time_t now;
+		struct tm *timeNow;
+
+		tzset ();
+		time (&now);
+		timeNow = localtime (&now);
+
+		strftime (tmp, sizeof (tmp), "%Y%m%d-%H%M%S", timeNow);
+		strcpy (&buf[buf_pos], tmp);
+		buf_pos += strlen (tmp);
+		break;
+	      }
 
 	    default:
-	       buf[i++] = *s++;
+	      /* Skip unknown escapes */
+	      break;
 	    }
+	  s += 2;
 	}
-      else
-       buf[i++] = *s++;
     }
 
-  trace_fname = STRDUP (buf);
+  buf[buf_pos] = '\0';
+  trace_fname = buf;
+
+  return;
 }
 
 
@@ -218,14 +263,6 @@ trace_start(void)
    */
   trace_stop ();
 
-#if defined (UNIX)
-  /*
-   *  Root is not allowed to trace for security reasons
-   */
-  if (geteuid () == 0)
-    return;
-#endif
-
   /*
    *  If no trace filename is specified, use the default
    */
@@ -239,8 +276,29 @@ trace_start(void)
     }
 #endif
 
-  else if ((trace_fp = fopen (trace_fname, "w")) != NULL)
+  else
     {
+      int fd;
+      int fd_flags = O_WRONLY | O_CREAT | O_TRUNC;
+      int fd_mode = 0644;
+
+
+#if defined (unix)
+      /*
+       *  As this is a security risk, we do not allow root to overwrite a file
+       */
+      if (geteuid () == 0)
+	{
+	  fd_flags |= O_EXCL;
+	}
+#endif
+
+      fd = open (trace_fname, fd_flags, fd_mode);
+      if (fd < 0 || (trace_fp = fdopen (fd, "w")) == NULL)
+	{
+	  return;		/* no tracing */
+	}
+
       trace_fp_close = 1;
 
       /*
@@ -262,14 +320,26 @@ trace_start(void)
       time_t now;
       struct tm *timeNow;
 
+      trace_emit ("** iODBC Trace file\n");
+
+      /*
+       *  Show start time
+       */
       tzset ();
       time (&now);
       timeNow = localtime (&now);
-      strftime (mesgBuf, sizeof (mesgBuf), "** started on %a %b %d, %H:%M **",
+      strftime (mesgBuf,
+	  sizeof (mesgBuf), "** Trace started on %a %b %d %H:%M:%S %Y",
 	  timeNow);
+      trace_emit ("%s\n", mesgBuf);
 
-      trace_emit ("** iODBC Trace file **\n");
-      trace_emit ("%s\n\n", mesgBuf);
+      /*
+       *  Show Driver Manager version similar to SQLGetInfo (SQL_DM_VER)
+       */
+      sprintf ((char *) mesgBuf, "%02d.%02d.%04d.%04d",
+	  SQL_SPEC_MAJOR,
+	  SQL_SPEC_MINOR, IODBC_BUILD / 10000, IODBC_BUILD % 10000);
+      trace_emit ("** Driver Manager: %s\n\n", mesgBuf);
     }
 
 #if defined (linux)
@@ -311,10 +381,29 @@ trace_start(void)
 void
 trace_stop(void)
 {
-  ODBCSharedTraceFlag = SQL_OPT_TRACE_OFF;
+  char mesgBuf[200];
+  time_t now;
+  struct tm *timeNow;
 
-  if (trace_fp_close && trace_fp)
-    fclose (trace_fp);
+  if (trace_fp)
+    {
+      /*
+       * Show end time
+       */
+      tzset ();
+      time (&now);
+      timeNow = localtime (&now);
+      strftime (mesgBuf,
+	  sizeof (mesgBuf), "** Trace finished on %a %b %d %H:%M:%S %Y",
+	  timeNow);
+
+      trace_emit ("\n%s\n", mesgBuf);
+
+      if (trace_fp_close)
+	fclose (trace_fp);
+    }
+
+  ODBCSharedTraceFlag = SQL_OPT_TRACE_OFF;
   trace_fp = NULL;
   trace_fp_close = 0;
 }
@@ -435,10 +524,10 @@ trace_emit_string (SQLCHAR *str, int len, int is_utf8)
       else
         {
 	  /*
-	   *  Skip this bogus UTF8 character sequence and emit a single # 
+	   *  Skip this bogus UTF8 character sequence and emit a single #
 	   */
 	  for (bytes = 1, ptr++; (*ptr & 0xC0) == 0x80; bytes++)
-	    ptr++;	
+	    ptr++;
 	  trace_emitc ('#');
 	}
 
