@@ -1,17 +1,17 @@
 /*
  *  confirm.c
  *
- *  $Id: confirm.c,v 1.2 2002/03/14 20:50:24 source Exp $
+ *  $Id: confirm.c,v 1.3 2004/06/22 11:25:48 source Exp $
  *
  *  The iODBC driver manager.
- *  
+ *
  *  Copyright (C) 1999-2002 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
  *  licenses:
  *
- *      - GNU Library General Public License (see LICENSE.LGPL) 
+ *      - GNU Library General Public License (see LICENSE.LGPL)
  *      - The BSD License (see LICENSE.BSD).
  *
  *  While not mandated by the BSD license, any patches you make to the
@@ -71,6 +71,7 @@
 #include "gui.h"
 #include "question.xpm"
 
+
 static void
 confirm_yes_clicked (GtkWidget *widget, TCONFIRM *confirm_t)
 {
@@ -86,7 +87,6 @@ confirm_yes_clicked (GtkWidget *widget, TCONFIRM *confirm_t)
 }
 
 
-
 static void
 confirm_no_clicked (GtkWidget *widget, TCONFIRM *confirm_t)
 {
@@ -125,7 +125,7 @@ create_confirm (HWND hwnd, LPCSTR dsn, LPCSTR text)
   TCONFIRM confirm_t;
 
   if (hwnd == NULL || !GTK_IS_WIDGET (hwnd))
-    return;
+    return FALSE;
 
   accel_group = gtk_accel_group_new ();
 
