@@ -1,17 +1,17 @@
 /*
  *  filedsn.c
  *
- *  $Id: filedsn.c,v 1.2 2002/03/14 20:52:40 source Exp $
+ *  $Id: filedsn.c,v 1.3 2004/06/22 11:23:47 source Exp $
  *
  *  The iODBC driver manager.
- *  
+ *
  *  Copyright (C) 1999-2002 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
  *  licenses:
  *
- *      - GNU Library General Public License (see LICENSE.LGPL) 
+ *      - GNU Library General Public License (see LICENSE.LGPL)
  *      - The BSD License (see LICENSE.BSD).
  *
  *  While not mandated by the BSD license, any patches you make to the
@@ -70,6 +70,7 @@
 
 #include "gui.h"
 
+
 static void
 filedsn_finish_clicked (GtkWidget *widget, TFILEDSN *filedsn_t)
 {
@@ -126,7 +127,7 @@ create_filedsn (HWND hwnd)
   TFILEDSN filedsn_t;
 
   if (hwnd == NULL || !GTK_IS_WIDGET (hwnd))
-    return;
+    return NULL;
 
   accel_group = gtk_accel_group_new ();
 
