@@ -1,17 +1,17 @@
 /*
  *  iodbcadm.h
  *
- *  $Id: iodbcadm.h,v 1.4 2003/08/22 14:28:42 source Exp $
+ *  $Id: iodbcadm.h,v 1.6 2004/06/22 11:23:47 source Exp $
  *
  *  The iODBC driver manager.
- *  
+ *
  *  Copyright (C) 1999-2002 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
  *  licenses:
  *
- *      - GNU Library General Public License (see LICENSE.LGPL) 
+ *      - GNU Library General Public License (see LICENSE.LGPL)
  *      - The BSD License (see LICENSE.BSD).
  *
  *  While not mandated by the BSD license, any patches you make to the
@@ -83,14 +83,16 @@
 #define FILE_DSN		2
 
 SQLRETURN SQL_API iodbcdm_drvconn_dialbox (HWND hwnd, LPSTR szInOutConnStr,
-    DWORD cbInOutConnStr, int FAR * sqlStat, SQLUSMALLINT fDriverCompletion, UWORD *config);
+    DWORD cbInOutConnStr, int *sqlStat, SQLUSMALLINT fDriverCompletion,
+    UWORD * config);
 SQLRETURN SQL_API iodbcdm_drvconn_dialboxw (HWND hwnd, LPWSTR szInOutConnStr,
-    DWORD cbInOutConnStr, int FAR * sqlStat, SQLUSMALLINT fDriverCompletion, UWORD *config);
+    DWORD cbInOutConnStr, int *sqlStat, SQLUSMALLINT fDriverCompletion,
+    UWORD * config);
 
 SQLRETURN SQL_API _iodbcdm_drvchoose_dialbox (HWND hwnd, LPSTR szInOutDrvStr,
-    DWORD cbInOutDrvStr, int FAR * sqlStat);
+    DWORD cbInOutDrvStr, int *sqlStat);
 SQLRETURN SQL_API _iodbcdm_trschoose_dialbox (HWND hwnd, LPSTR szInOutDrvStr,
-    DWORD cbInOutDrvStr, int FAR * sqlStat);
+    DWORD cbInOutDrvStr, int *sqlStat);
 
 void SQL_API _iodbcdm_errorbox (HWND hwnd, LPCSTR szDSN, LPCSTR szText);
 void SQL_API _iodbcdm_messagebox (HWND hwnd, LPCSTR szDSN, LPCSTR szText);
@@ -101,8 +103,8 @@ SQLRETURN SQL_API _iodbcdm_admin_dialbox (HWND hwnd);
 
 typedef SQLRETURN SQL_API (*pAdminBoxFunc) (HWND hwnd);
 typedef SQLRETURN SQL_API (*pTrsChooseFunc) (HWND hwnd, LPSTR szInOutDrvStr,
-    DWORD cbInOutDrvStr, int FAR * sqlStat);
+    DWORD cbInOutDrvStr, int *sqlStat);
 typedef SQLRETURN SQL_API (*pDrvConnFunc) (HWND hwnd, LPSTR szInOutConnStr,
-    DWORD cbInOutConnStr, int FAR * sqlStat, SQLUSMALLINT fDriverCompletion, UWORD *config);
-
+    DWORD cbInOutConnStr, int *sqlStat, SQLUSMALLINT fDriverCompletion,
+    UWORD * config);
 #endif
