@@ -1,20 +1,20 @@
 /*
  *  SQLConfigDriver.c
  *
- *  $Id: SQLConfigDriver.c,v 1.4 2004/02/18 15:57:50 source Exp $
+ *  $Id: SQLConfigDriver.c,v 1.6 2004/06/22 11:19:20 source Exp $
  *
  *  Load the appropriate driver setup DLL and calls the ConfigDriver
  *  function.
  *
  *  The iODBC driver manager.
- *  
+ *
  *  Copyright (C) 1999-2002 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
  *  licenses:
  *
- *      - GNU Library General Public License (see LICENSE.LGPL) 
+ *      - GNU Library General Public License (see LICENSE.LGPL)
  *      - The BSD License (see LICENSE.BSD).
  *
  *  While not mandated by the BSD license, any patches you make to the
@@ -70,8 +70,6 @@
  *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
-
-
 #include <iodbc.h>
 #include <iodbcinst.h>
 
@@ -84,6 +82,7 @@
 #include "misc.h"
 #include "iodbc_error.h"
 
+
 #ifndef WIN32
 #include <unistd.h>
 #define CALL_CONFIG_DRIVER(driverpath) \
@@ -109,9 +108,10 @@
 	}
 #endif
 
+
 BOOL INSTAPI
 SQLConfigDriver (HWND hwndParent, WORD fRequest, LPCSTR lpszDriver,
-    LPCSTR lpszArgs, LPSTR lpszMsg, WORD cbMsgMax, WORD FAR *pcbMsgOut)
+    LPCSTR lpszArgs, LPSTR lpszMsg, WORD cbMsgMax, WORD *pcbMsgOut)
 {
   PCONFIG pCfg;
   BOOL retcode = FALSE;
