@@ -1,21 +1,21 @@
 /*
  *  SQLCreateDataSource.c
  *
- *  $Id: SQLCreateDataSource.c,v 1.6 2004/02/18 15:57:50 source Exp $
+ *  $Id: SQLCreateDataSource.c,v 1.7 2004/06/22 11:19:20 source Exp $
  *
  *  Add, modify or delete datasources
  *
  *  The iODBC driver manager.
  *
  *  The iODBC driver manager.
- *  
+ *
  *  Copyright (C) 1999-2002 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
  *  licenses:
  *
- *      - GNU Library General Public License (see LICENSE.LGPL) 
+ *      - GNU Library General Public License (see LICENSE.LGPL)
  *      - The BSD License (see LICENSE.BSD).
  *
  *  While not mandated by the BSD license, any patches you make to the
@@ -94,7 +94,9 @@ extern BOOL ValidDSN (LPCSTR lpszDSN);
 		DLL_CLOSE(handle); \
 	}
 
-BOOL CreateDataSource (HWND parent, LPCSTR lpszDSN)
+
+BOOL
+CreateDataSource (HWND parent, LPCSTR lpszDSN)
 {
   char dsn[1024] = { 0 };
   UWORD config = ODBC_USER_DSN;
