@@ -1,19 +1,19 @@
 /*
  *  SQLGetAvailableDrivers.c
  *
- *  $Id: SQLGetAvailableDrivers.c,v 1.3 2002/04/26 11:27:40 source Exp $
+ *  $Id: SQLGetAvailableDrivers.c,v 1.5 2004/06/22 11:19:20 source Exp $
  *
  *  Get a list of all available drivers
  *
  *  The iODBC driver manager.
- *  
+ *
  *  Copyright (C) 1999-2002 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
  *  licenses:
  *
- *      - GNU Library General Public License (see LICENSE.LGPL) 
+ *      - GNU Library General Public License (see LICENSE.LGPL)
  *      - The BSD License (see LICENSE.BSD).
  *
  *  While not mandated by the BSD license, any patches you make to the
@@ -77,9 +77,10 @@
 #include "inifile.h"
 #include "iodbc_error.h"
 
+
 BOOL
 GetAvailableDrivers (LPCSTR lpszInfFile, LPSTR lpszBuf, WORD cbBufMax,
-    WORD FAR *pcbBufOut, BOOL infFile)
+    WORD *pcbBufOut, BOOL infFile)
 {
   int sect_len = 0;
   WORD curr = 0;
@@ -163,7 +164,7 @@ quit:
 
 BOOL INSTAPI
 SQLGetAvailableDrivers (LPCSTR lpszInfFile, LPSTR lpszBuf, WORD cbBufMax,
-    WORD FAR *pcbBufOut)
+    WORD *pcbBufOut)
 {
   BOOL retcode = FALSE;
   WORD lenBufOut;
