@@ -1,19 +1,19 @@
 /*
  *  SQLGetInstalledDrivers.c
  *
- *  $Id: SQLGetInstalledDrivers.c,v 1.2 2002/03/14 20:53:44 source Exp $
+ *  $Id: SQLGetInstalledDrivers.c,v 1.4 2004/06/22 11:19:20 source Exp $
  *
  *  Get a list of installed drivers
  *
  *  The iODBC driver manager.
- *  
+ *
  *  Copyright (C) 1999-2002 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
  *  licenses:
  *
- *      - GNU Library General Public License (see LICENSE.LGPL) 
+ *      - GNU Library General Public License (see LICENSE.LGPL)
  *      - The BSD License (see LICENSE.BSD).
  *
  *  While not mandated by the BSD license, any patches you make to the
@@ -77,10 +77,10 @@
 #include "iodbc_error.h"
 
 extern BOOL GetAvailableDrivers ( LPCSTR lpszInfFile, LPSTR lpszBuf,
-    WORD cbBufMax,WORD FAR *pcbBufOut,BOOL infFile);
+    WORD cbBufMax,WORD *pcbBufOut,BOOL infFile);
 
 BOOL INSTAPI
-SQLGetInstalledDrivers (LPSTR lpszBuf, WORD cbBufMax, WORD FAR *pcbBufOut)
+SQLGetInstalledDrivers (LPSTR lpszBuf, WORD cbBufMax, WORD *pcbBufOut)
 {
   char path[1024] = { 0 };
 
