@@ -1,17 +1,17 @@
 /*
  *  SQLGetProfileString.c
  *
- *  $Id: SQLGetPrivateProfileString.c,v 1.2 2002/03/14 20:53:44 source Exp $
+ *  $Id: SQLGetPrivateProfileString.c,v 1.4 2004/07/06 15:01:32 source Exp $
  *
  *  The iODBC driver manager.
- *  
+ *
  *  Copyright (C) 1999-2002 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
  *  licenses:
  *
- *      - GNU Library General Public License (see LICENSE.LGPL) 
+ *      - GNU Library General Public License (see LICENSE.LGPL)
  *      - The BSD License (see LICENSE.BSD).
  *
  *  While not mandated by the BSD license, any patches you make to the
@@ -75,6 +75,7 @@
 #include "iodbc_error.h"
 #include "misc.h"
 
+
 #ifndef WIN32
 int
 GetPrivateProfileString (LPCSTR lpszSection, LPCSTR lpszEntry,
@@ -85,7 +86,7 @@ GetPrivateProfileString (LPCSTR lpszSection, LPCSTR lpszEntry,
   int len = 0;
   PCONFIG pCfg;
 
-  lpszRetBuffer[cbRetBuffer - 1] = 0;
+  lpszRetBuffer[0] = 0;
 
   /* If error during reading the file */
   if (_iodbcdm_cfg_search_init (&pCfg, lpszFilename, FALSE))
