@@ -1,19 +1,19 @@
 /*
  *  SQLGetTranslator.c
  *
- *  $Id: SQLGetTranslator.c,v 1.6 2004/02/18 15:57:50 source Exp $
+ *  $Id: SQLGetTranslator.c,v 1.8 2004/06/22 11:19:20 source Exp $
  *
  *  These functions intentionally left blank
  *
  *  The iODBC driver manager.
- *  
+ *
  *  Copyright (C) 1999-2002 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
  *  licenses:
  *
- *      - GNU Library General Public License (see LICENSE.LGPL) 
+ *      - GNU Library General Public License (see LICENSE.LGPL)
  *      - The BSD License (see LICENSE.BSD).
  *
  *  While not mandated by the BSD license, any patches you make to the
@@ -83,6 +83,7 @@
 #include <Carbon/Carbon.h>
 #endif
 
+
 #ifndef WIN32
 #include <unistd.h>
 #define CALL_CONFIG_TRANSLATOR(path) \
@@ -118,11 +119,13 @@
 	else ret = SQL_NO_DATA;
 #endif
 
-extern SQLRETURN _iodbcdm_trschoose_dialbox(HWND, LPSTR, DWORD, int FAR*);
+
+extern SQLRETURN _iodbcdm_trschoose_dialbox(HWND, LPSTR, DWORD, int *);
+
 
 BOOL INSTAPI GetTranslator (HWND hwndParent, LPSTR lpszName, WORD cbNameMax,
-    WORD FAR *pcbNameOut, LPSTR lpszPath, WORD cbPathMax,
-    WORD FAR *pcbPathOut, DWORD FAR *pvOption)
+    WORD *pcbNameOut, LPSTR lpszPath, WORD cbPathMax,
+    WORD *pcbPathOut, DWORD *pvOption)
 {
   pConfigTranslatorFunc pConfigTranslator;
   pTrsChooseFunc pTrsChoose;
@@ -145,23 +148,23 @@ BOOL INSTAPI GetTranslator (HWND hwndParent, LPSTR lpszName, WORD cbNameMax,
 #ifdef __APPLE__
       bundle = CFBundleGetBundleWithIdentifier (CFSTR ("org.iodbc.adm"));
       if (bundle)
-        {
-          /* Search for the drvproxy library */
-          liburl = CFBundleCopyExecutableURL (bundle);
-          if (liburl
+	{
+	  /* Search for the drvproxy library */
+	  liburl = CFBundleCopyExecutableURL (bundle);
+	  if (liburl
 	      && (libname =
-	          CFURLCopyFileSystemPath (liburl, kCFURLPOSIXPathStyle)))
+		  CFURLCopyFileSystemPath (liburl, kCFURLPOSIXPathStyle)))
 	    {
 	      CFStringGetCString (libname, name, sizeof (name),
-	          kCFStringEncodingASCII);
+		  kCFStringEncodingASCII);
 	      CALL_TRSCHOOSE_DIALBOX (name);
 	    }
-          if (liburl)
+	  if (liburl)
 	    CFRelease (liburl);
-          if (libname)
+	  if (libname)
 	    CFRelease (libname);
-          CFRelease (bundle);
-        }
+	  CFRelease (bundle);
+	}
 #else
       CALL_TRSCHOOSE_DIALBOX ("libiodbcadm.so");
 #endif
@@ -249,11 +252,11 @@ SQLGetTranslator (
     HWND hwnd,
     LPSTR lpszName,
     WORD cbNameMax,
-    WORD FAR * pcbNameOut,
+    WORD * pcbNameOut,
     LPSTR lpszPath,
     WORD cbPathMax,
-    WORD FAR * pcbPathOut,
-    DWORD FAR * pvOption)
+    WORD * pcbPathOut,
+    DWORD * pvOption)
 {
   BOOL retcode = FALSE;
 
