@@ -1,19 +1,19 @@
 /*
  *  SQLInstallDriver.c
  *
- *  $Id: SQLInstallDriver.c,v 1.3 2002/04/26 11:27:40 source Exp $
+ *  $Id: SQLInstallDriver.c,v 1.5 2004/06/22 11:19:20 source Exp $
  *
  *  Install a driver
  *
  *  The iODBC driver manager.
- *  
+ *
  *  Copyright (C) 1999-2002 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
  *  licenses:
  *
- *      - GNU Library General Public License (see LICENSE.LGPL) 
+ *      - GNU Library General Public License (see LICENSE.LGPL)
  *      - The BSD License (see LICENSE.BSD).
  *
  *  While not mandated by the BSD license, any patches you make to the
@@ -91,7 +91,7 @@
 
 
 BOOL
-InstallDriverPath (LPSTR lpszPath, WORD cbPathMax, WORD FAR *pcbPathOut,
+InstallDriverPath (LPSTR lpszPath, WORD cbPathMax, WORD *pcbPathOut,
     LPSTR envname)
 {
 #ifdef _MAC
@@ -228,7 +228,7 @@ quit:
 
 BOOL INSTAPI
 SQLInstallDriver (LPCSTR lpszInfFile, LPCSTR lpszDriver, LPSTR lpszPath,
-    WORD cbPathMax, WORD FAR *pcbPathOut)
+    WORD cbPathMax, WORD *pcbPathOut)
 {
   PCONFIG pCfg = NULL, pOdbcCfg = NULL;
   BOOL retcode = FALSE;
