@@ -1,19 +1,19 @@
 /*
  *  SQLInstallDriverEx.c
  *
- *  $Id: SQLInstallDriverEx.c,v 1.4 2004/02/18 15:57:50 source Exp $
+ *  $Id: SQLInstallDriverEx.c,v 1.6 2004/06/22 11:19:20 source Exp $
  *
  *  These functions intentionally left blank
  *
  *  The iODBC driver manager.
- *  
+ *
  *  Copyright (C) 1999-2002 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
  *  licenses:
  *
- *      - GNU Library General Public License (see LICENSE.LGPL) 
+ *      - GNU Library General Public License (see LICENSE.LGPL)
  *      - The BSD License (see LICENSE.BSD).
  *
  *  While not mandated by the BSD license, any patches you make to the
@@ -90,11 +90,11 @@
 #endif
 
 extern BOOL InstallDriverPath ( LPSTR lpszPath,WORD cbPathMax,
-    WORD FAR * pcbPathOut,LPSTR envname);
+    WORD * pcbPathOut,LPSTR envname);
 
 
 BOOL
-InstallDriverPathLength (WORD FAR *pcbPathOut, LPSTR envname)
+InstallDriverPathLength (WORD *pcbPathOut, LPSTR envname)
 {
 #ifdef _MAC
   OSErr result;
@@ -123,7 +123,7 @@ InstallDriverPathLength (WORD FAR *pcbPathOut, LPSTR envname)
   goto done;
 #else
   /*
-     *  On Windows, there is only one place to look
+   *  On Windows, there is only one place to look
    */
   len = GetWindowsDirectory (path, sizeof (path));
   goto done;
