@@ -1,19 +1,19 @@
 /*
  *  SQLInstallDriverManager.c
  *
- *  $Id: SQLInstallDriverManager.c,v 1.2 2002/03/14 20:53:44 source Exp $
+ *  $Id: SQLInstallDriverManager.c,v 1.4 2004/06/22 11:19:20 source Exp $
  *
  *  These functions intentionally left blank
  *
  *  The iODBC driver manager.
- *  
+ *
  *  Copyright (C) 1999-2002 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
  *  licenses:
  *
- *      - GNU Library General Public License (see LICENSE.LGPL) 
+ *      - GNU Library General Public License (see LICENSE.LGPL)
  *      - The BSD License (see LICENSE.BSD).
  *
  *  While not mandated by the BSD license, any patches you make to the
@@ -76,10 +76,11 @@
 #include "iodbc_error.h"
 
 extern BOOL InstallDriverPath ( LPSTR lpszPath, WORD cbPathMax,
-    WORD FAR * pcbPathOut,LPSTR envname);
+    WORD * pcbPathOut,LPSTR envname);
+
 
 BOOL INSTAPI
-SQLInstallDriverManager (LPSTR lpszPath, WORD cbPathMax, WORD FAR *pcbPathOut)
+SQLInstallDriverManager (LPSTR lpszPath, WORD cbPathMax, WORD *pcbPathOut)
 {
   BOOL retcode = FALSE;
 
@@ -91,7 +92,8 @@ SQLInstallDriverManager (LPSTR lpszPath, WORD cbPathMax, WORD FAR *pcbPathOut)
       goto quit;
     }
 
-  retcode = InstallDriverPath (lpszPath, cbPathMax, pcbPathOut, "ODBCMANAGER");
+  retcode =
+      InstallDriverPath (lpszPath, cbPathMax, pcbPathOut, "ODBCMANAGER");
 
 quit:
   return retcode;
