@@ -1,19 +1,19 @@
 /*
  *  SQLInstallTranslator.c
  *
- *  $Id: SQLInstallTranslator.c,v 1.3 2002/04/26 11:27:40 source Exp $
+ *  $Id: SQLInstallTranslator.c,v 1.5 2004/06/22 11:19:20 source Exp $
  *
  *  These functions intentionally left blank
  *
  *  The iODBC driver manager.
- *  
+ *
  *  Copyright (C) 1999-2002 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
  *  licenses:
  *
- *      - GNU Library General Public License (see LICENSE.LGPL) 
+ *      - GNU Library General Public License (see LICENSE.LGPL)
  *      - The BSD License (see LICENSE.BSD).
  *
  *  While not mandated by the BSD license, any patches you make to the
@@ -83,15 +83,16 @@
 # define UNIX_PWD
 #endif
 
+
 extern BOOL InstallDriverPath (LPSTR lpszPath, WORD cbPathMax,
-    WORD FAR *pcbPathOut,LPSTR envname);
-extern BOOL InstallDriverPathLength (WORD FAR * pcbPathOut,LPSTR envname);
+    WORD *pcbPathOut,LPSTR envname);
+extern BOOL InstallDriverPathLength (WORD * pcbPathOut,LPSTR envname);
 
 
 BOOL INSTAPI
 SQLInstallTranslator (LPCSTR lpszInfFile, LPCSTR lpszTranslator,
     LPCSTR lpszPathIn, LPSTR lpszPathOut, WORD cbPathOutMax,
-    WORD FAR *pcbPathOut, WORD fRequest, LPDWORD lpdwUsageCount)
+    WORD *pcbPathOut, WORD fRequest, LPDWORD lpdwUsageCount)
 {
   PCONFIG pCfg = NULL, pOdbcCfg = NULL;
   BOOL retcode = FALSE;
