@@ -1,19 +1,19 @@
 /*
  *  SQLInstallTranslatorEx.c
  *
- *  $Id: SQLInstallTranslatorEx.c,v 1.3 2002/04/26 11:27:40 source Exp $
+ *  $Id: SQLInstallTranslatorEx.c,v 1.5 2004/06/22 11:19:20 source Exp $
  *
  *  These functions intentionally left blank
  *
  *  The iODBC driver manager.
- *  
+ *
  *  Copyright (C) 1999-2002 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
  *  licenses:
  *
- *      - GNU Library General Public License (see LICENSE.LGPL) 
+ *      - GNU Library General Public License (see LICENSE.LGPL)
  *      - The BSD License (see LICENSE.BSD).
  *
  *  While not mandated by the BSD license, any patches you make to the
@@ -84,8 +84,8 @@
 #endif
 
 extern BOOL InstallDriverPath ( LPSTR lpszPath,WORD cbPathMax,
-    WORD FAR *pcbPathOut,LPSTR envname);
-extern BOOL InstallDriverPathLength (WORD FAR * pcbPathOut,LPSTR envname);
+    WORD *pcbPathOut,LPSTR envname);
+extern BOOL InstallDriverPathLength (WORD * pcbPathOut,LPSTR envname);
 
 
 BOOL INSTAPI
