@@ -1,19 +1,19 @@
 /*
  *  inifile.c
  *
- *  $Id: inifile.c,v 1.2 2002/03/14 20:53:44 source Exp $
+ *  $Id: inifile.c,v 1.4 2004/07/13 13:11:31 source Exp $
  *
  *  Configuration File Management
  *
  *  The iODBC driver manager.
- *  
+ *
  *  Copyright (C) 1999-2002 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
  *  licenses:
  *
- *      - GNU Library General Public License (see LICENSE.LGPL) 
+ *      - GNU Library General Public License (see LICENSE.LGPL)
  *      - The BSD License (see LICENSE.BSD).
  *
  *  While not mandated by the BSD license, any patches you make to the
@@ -955,8 +955,6 @@ _iodbcdm_cfg_commit (PCONFIG pconfig)
 int
 _iodbcdm_cfg_next_section(PCONFIG pconfig)
 {
-  PCFGENTRY e;
-
   do
     if (0 != _iodbcdm_cfg_nextentry (pconfig))
       return -1;
@@ -971,8 +969,6 @@ _iodbcdm_cfg_search_init(PCONFIG *ppconf, const char *filename, int doCreate)
 {
   char pathbuf[1024];
 
-  /*if (access(filename, R_OK) == 0)
-     return _iodbcdm_cfg_init (ppconf, filename, doCreate); */
   if (strstr (filename, "odbc.ini") || strstr (filename, "ODBC.INI"))
     return _iodbcdm_cfg_init (ppconf, _iodbcadm_getinifile (pathbuf,
 	    sizeof (pathbuf), FALSE, doCreate), doCreate);
@@ -980,6 +976,8 @@ _iodbcdm_cfg_search_init(PCONFIG *ppconf, const char *filename, int doCreate)
       || strstr (filename, "ODBCINST.INI"))
     return _iodbcdm_cfg_init (ppconf, _iodbcadm_getinifile (pathbuf,
 	    sizeof (pathbuf), TRUE, doCreate), doCreate);
+  else if (access(filename, R_OK) == 0)
+     return _iodbcdm_cfg_init (ppconf, filename, doCreate);
   else
     return -1;
 }
